@@ -31,14 +31,14 @@
 from copy import deepcopy
 from typing import Any
 from typing import Callable
+from typing import Dict
+from typing import List
 from typing import Mapping
 from typing import Optional
 from typing import Sequence
 from typing import Union
 
 from ansible.module_utils.common.dict_transformations import camel_dict_to_snake_dict
-from ansible.module_utils.six import integer_types
-from ansible.module_utils.six import string_types
 
 from .botocore import normalize_boto3_result
 from .tagging import boto3_tag_list_to_ansible_dict
@@ -76,9 +76,9 @@ def ansible_dict_to_boto3_filter_list(filters_dict):
         filter_dict = {"Name": k}
         if isinstance(v, bool):
             filter_dict["Values"] = [str(v).lower()]
-        elif isinstance(v, integer_types):
+        elif isinstance(v, int):
             filter_dict["Values"] = [str(v)]
-        elif isinstance(v, string_types):
+        elif isinstance(v, str):
             filter_dict["Values"] = [v]
         else:
             filter_dict["Values"] = v
@@ -229,3 +229,24 @@ def boto3_resource_list_to_ansible_dict(
         boto3_resource_to_ansible_dict(resource, transform_tags, force_tags, normalize, ignore_list, nested_transforms)
         for resource in resource_list
     ]
+
+
+def sanitize_filters_to_boto3_filter_list(
+    filters: Dict[str, Any], ignore_keys: Optional[List[str]] = None
+) -> Dict[str, Any]:
+    """
+    Replace filter key underscores with dashes, for compatibility and transform ansible dict
+    into boto3 filter list.
+
+    :param filters: Ansible module params filters.
+    :param ignore_keys: A list of keys to ignore.
+    :return: Sanitized filters
+    """
+    sanitized_filters = deepcopy(filters)
+    for k, v in filters.items():
+        if ignore_keys and any((k.startswith(x) for x in ignore_keys)):
+            continue
+        if "_" in k:
+            sanitized_filters[k.replace("_", "-")] = v
+            del sanitized_filters[k]
+    return ansible_dict_to_boto3_filter_list(sanitized_filters)
