@@ -1,9 +1,11 @@
 # 2017 Red Hat Inc.
 # (c) 2017 Ansible Project
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 DOCUMENTATION = """
@@ -23,6 +25,7 @@ from ansible.module_utils.connection import Connection as SocketConnection
 from ansible.plugins.connection import ConnectionBase
 from ansible.utils.display import Display
 
+
 display = Display()
 
 
@@ -33,9 +36,7 @@ class Connection(ConnectionBase):
     has_pipelining = False
 
     def __init__(self, play_context, new_stdin, *args, **kwargs):
-        super(Connection, self).__init__(
-            play_context, new_stdin, *args, **kwargs
-        )
+        super(Connection, self).__init__(play_context, new_stdin, *args, **kwargs)
         self._task_uuid = to_text(kwargs.get("task_uuid", ""))
 
     def _connect(self):
@@ -71,14 +72,13 @@ class Connection(ConnectionBase):
             "starting connection from persistent connection plugin",
             host=self._play_context.remote_addr,
         )
-        variables = {
-            "ansible_command_timeout": self.get_option(
-                "persistent_command_timeout"
-            )
-        }
-        socket_path = start_connection(
-            self._play_context, variables, self._task_uuid
+        display.deprecated(
+            msg="support for connection local has been deprecated",
+            date="2027-01-01",
+            collection_name="ansible.netcommon",
         )
+        variables = {"ansible_command_timeout": self.get_option("persistent_command_timeout")}
+        socket_path = start_connection(self._play_context, variables, self._task_uuid)
         display.vvvv(
             "local domain socket path is %s" % socket_path,
             host=self._play_context.remote_addr,
