@@ -76,6 +76,8 @@ DOCUMENTATION = """
             type: str
             description: type of filter. example ipaddr, ipv4, ipv6, ipwrap
     notes:
+    requirements:
+        - netaddr>=0.10.1
 """
 
 EXAMPLES = r"""
