@@ -46,11 +46,11 @@ author:
 '''
 
 EXAMPLES = '''
-  - name: Get instance of DevTest Lab Artifact Source
-    azure_rm_devtestlabartifactsource_info:
-      resource_group: myResourceGroup
-      lab_name: myLab
-      name: myArtifactSource
+- name: Get instance of DevTest Lab Artifact Source
+  azure_rm_devtestlabartifactsource_info:
+    resource_group: myResourceGroup
+    lab_name: myLab
+    name: myArtifactSource
 '''
 
 RETURN = '''
@@ -131,16 +131,15 @@ artifactsources:
             description:
                 - The tags of the resource.
             returned: always
-            type: complex
+            type: dict
             sample: "{ 'MyTag': 'MyValue' }"
 '''
 
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
 
 try:
-    from msrestazure.azure_exceptions import CloudError
+    from azure.core.exceptions import ResourceNotFoundError
     from azure.mgmt.devtestlabs import DevTestLabsClient
-    from msrest.serialization import Model
 except ImportError:
     # This is handled in azure_rm_common
     pass
@@ -178,10 +177,6 @@ class AzureRMDtlArtifactSourceInfo(AzureRMModuleBase):
         super(AzureRMDtlArtifactSourceInfo, self).__init__(self.module_arg_spec, supports_check_mode=True, supports_tags=False, facts_module=True)
 
     def exec_module(self, **kwargs):
-        is_old_facts = self.module._name == 'azure_rm_devtestlabartifactsource_facts'
-        if is_old_facts:
-            self.module.deprecate("The 'azure_rm_devtestlabartifactsource_facts' module has been renamed to 'azure_rm_devtestlabartifactsource_info'",
-                                  version=(2.9, ))
 
         for key in self.module_arg_spec:
             setattr(self, key, kwargs[key])
@@ -203,7 +198,7 @@ class AzureRMDtlArtifactSourceInfo(AzureRMModuleBase):
                                                              lab_name=self.lab_name,
                                                              name=self.name)
             self.log("Response : {0}".format(response))
-        except CloudError as e:
+        except ResourceNotFoundError as e:
             self.fail('Could not get facts for Artifact Source.')
 
         if response and self.has_tags(response.tags, self.tags):
@@ -218,7 +213,7 @@ class AzureRMDtlArtifactSourceInfo(AzureRMModuleBase):
             response = self.mgmt_client.artifact_sources.list(resource_group_name=self.resource_group,
                                                               lab_name=self.lab_name)
             self.log("Response : {0}".format(response))
-        except CloudError as e:
+        except Exception as e:
             self.fail('Could not get facts for Artifact Source.')
 
         if response is not None:
