@@ -331,10 +331,6 @@ class AzureRMTrafficManagerProfileInfo(AzureRMModuleBase):
         )
 
     def exec_module(self, **kwargs):
-        is_old_facts = self.module._name == 'azure_rm_trafficmanagerprofile_facts'
-        if is_old_facts:
-            self.module.deprecate("The 'azure_rm_trafficmanagerprofile_facts' module has been renamed to 'azure_rm_trafficmanagerprofile_info'",
-                                  version=(2.9, ))
 
         for key in self.module_args:
             setattr(self, key, kwargs[key])
