@@ -35,8 +35,8 @@ argument_spec.update(
         dataVlanName=dict(type="str"),
         voiceVlanName=dict(type="str"),
         nativeVlanId=dict(type="float"),
-        offset=dict(type="float"),
-        limit=dict(type="float"),
+        offset=dict(type="int"),
+        limit=dict(type="int"),
         headers=dict(type="dict"),
     )
 )
