@@ -95,6 +95,15 @@ options:
         description: Determines the mode of the file. Set to True for 'append' mode. Set to False for 'write' mode.
         type: bool
         default: True
+    dnac_api_task_timeout:
+      description:  Defines the timeout in seconds for API calls to retrieve task details. If the task details
+          are not received within this period, the process will end, and a timeout notification will be logged.
+      type: int
+      default: 1200
+    dnac_task_poll_interval:
+      description: Specifies the interval in seconds between successive calls to the API to retrieve task details.
+      type: int
+      default: 2
     validate_response_schema:
         description:
           - Flag for Cisco DNA Center SDK to enable the validation of request bodies against a JSON schema.
