@@ -4,13 +4,14 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-
 DOCUMENTATION = r"""
 ---
 module: discovery_range_info
-short_description: Information module for Discovery Range Info
+short_description: Information module for Discovery
+  Range
 description:
-- This module represents an alias of the module discovery_range_v1_info
+  - Get all Discovery Range.
+  - Returns the discoveries by specified range.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,31 +22,33 @@ options:
     type: dict
   startIndex:
     description:
-    - StartIndex path parameter. Starting index for the records.
+      - StartIndex path parameter. Starting index for
+        the records.
     type: int
   recordsToReturn:
     description:
-    - RecordsToReturn path parameter. Number of records to fetch from the starting index.
+      - RecordsToReturn path parameter. Number of records
+        to fetch from the starting index.
     type: int
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Discovery GetDiscoveriesByRangeV1
-  description: Complete reference of the GetDiscoveriesByRangeV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-discoveries-by-range
+  - name: Cisco DNA Center documentation for Discovery
+      GetDiscoveriesByRange
+    description: Complete reference of the GetDiscoveriesByRange
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-discoveries-by-range
 notes:
   - SDK Method used are
-    discovery.Discovery.get_discoveries_by_range_v1,
-
+    discovery.Discovery.get_discoveries_by_range,
   - Paths used are
     get /dna/intent/api/v1/discovery/{startIndex}/{recordsToReturn},
-  - It should be noted that this module is an alias of discovery_range_v1_info
-
 """
 
 EXAMPLES = r"""
-- name: Get all Discovery Range Info
+---
+- name: Get all Discovery Range
   cisco.dnac.discovery_range_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -58,7 +61,6 @@ EXAMPLES = r"""
     startIndex: 0
     recordsToReturn: 0
   register: result
-
 """
 RETURN = r"""
 dnac_response:
@@ -126,7 +128,7 @@ dnac_response:
           "snmpRwCommunity": "string",
           "snmpRwCommunityDesc": "string",
           "snmpUserName": "string",
-          "timeOut": 0,
+          "timeout": 0,
           "updateMgmtIp": true,
           "userNameList": "string"
         }
