@@ -7,10 +7,11 @@
 DOCUMENTATION = r"""
 ---
 module: event_subscription_count_info
-short_description: Information module for Event Subscription Count
+short_description: Information module for Event Subscription
+  Count
 description:
-- Get all Event Subscription Count.
-- Returns the Count of EventSubscriptions.
+  - Get all Event Subscription Count.
+  - Returns the Count of EventSubscriptions.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,25 +22,27 @@ options:
     type: dict
   eventIds:
     description:
-    - EventIds query parameter. List of subscriptions related to the respective eventIds.
+      - EventIds query parameter. List of subscriptions
+        related to the respective eventIds.
     type: str
 requirements:
-- dnacentersdk >= 2.7.2
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Event Management CountOfEventSubscriptions
-  description: Complete reference of the CountOfEventSubscriptions API.
-  link: https://developer.cisco.com/docs/dna-center/#!count-of-event-subscriptions
+  - name: Cisco DNA Center documentation for Event Management
+      CountOfEventSubscriptions
+    description: Complete reference of the CountOfEventSubscriptions
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!count-of-event-subscriptions
 notes:
   - SDK Method used are
     event_management.EventManagement.count_of_event_subscriptions,
-
   - Paths used are
     get /dna/intent/api/v1/event/subscription/count,
-
 """
 
 EXAMPLES = r"""
+---
 - name: Get all Event Subscription Count
   cisco.dnac.event_subscription_count_info:
     dnac_host: "{{dnac_host}}"
@@ -52,7 +55,6 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     eventIds: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
