@@ -1,13 +1,19 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: floors_settings
 short_description: Resource module for Floors Settings
 description:
-  - This module represents an alias of the module floors_settings_v2
+  - Manage operations create, update and delete of the
+    resource Floors Settings.
+  - Updates UI user preference for floor unit system.
+    Unit sytem change will effect for all floors across
+    all sites.
 version_added: '6.15.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -17,18 +23,23 @@ options:
     description: Floor units of measure.
     type: str
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Site Design UpdatesFloorSettingsV2
-    description: Complete reference of the UpdatesFloorSettingsV2 API.
-    link: https://developer.cisco.com/docs/dna-center/#!updates-floor-settings
+  - name: Cisco DNA Center documentation for Site Design
+      UpdatesFloorSettingsV2
+    description: Complete reference of the UpdatesFloorSettingsV2
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!updates-floor-settings-v-2
 notes:
-  - SDK Method used are site_design.SiteDesign.updates_floor_settings_v2,
-  - Paths used are put /dna/intent/api/v2/floors/settings,
-  - It should be noted that this module is an alias of floors_settings_v2
+  - SDK Method used are
+    site_design.SiteDesign.updates_floor_settings_v2,
+  - Paths used are
+    put /dna/intent/api/v2/floors/settings,
 """
+
 EXAMPLES = r"""
+---
 - name: Update all
   cisco.dnac.floors_settings:
     dnac_host: "{{dnac_host}}"
