@@ -4,13 +4,18 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-
 DOCUMENTATION = r"""
 ---
 module: lan_automation_log_info
-short_description: Information module for Lan Automation Log Info
+short_description: Information module for Lan Automation
+  Log
 description:
-- This module represents an alias of the module lan_automation_log_v1_info
+  - Get all Lan Automation Log.
+  - Get Lan Automation Log by id.
+  - Invoke this API to get the LAN Automation session
+    logs based on the given LAN Automation session id.
+  - Invoke this API to get the LAN Automation session
+    logs.
 version_added: '6.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,40 +26,45 @@ options:
     type: dict
   offset:
     description:
-    - Offset query parameter. Starting index of the LAN Automation session. Minimum value is 1.
-    type: float
+      - Offset query parameter. Starting index of the
+        LAN Automation session. Minimum value is 1.
+    type: int
   limit:
     description:
-    - Limit query parameter. Number of LAN Automation sessions to be retrieved. Limit value can range between 1 to 10.
-    type: float
+      - Limit query parameter. Number of LAN Automation
+        sessions to be retrieved. Limit value can range
+        between 1 to 10.
+    type: int
   id:
     description:
-    - Id path parameter. LAN Automation session identifier.
+      - Id path parameter. LAN Automation session identifier.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for LAN Automation LANAutomationLogByIdV1
-  description: Complete reference of the LANAutomationLogByIdV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!l-an-automation-log-by-id
-- name: Cisco DNA Center documentation for LAN Automation LANAutomationLogV1
-  description: Complete reference of the LANAutomationLogV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!l-an-automation-log
+  - name: Cisco DNA Center documentation for LAN Automation
+      LANAutomationLog
+    description: Complete reference of the LANAutomationLog
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!l-an-automation-log
+  - name: Cisco DNA Center documentation for LAN Automation
+      LANAutomationLogById
+    description: Complete reference of the LANAutomationLogById
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!l-an-automation-log-by-id
 notes:
   - SDK Method used are
-    lan_automation.LanAutomation.lan_automation_log_by_id_v1,
-    lan_automation.LanAutomation.lan_automation_log_v1,
-
+    lan_automation.LanAutomation.lan_automation_log,
+    lan_automation.LanAutomation.lan_automation_log_by_id,
   - Paths used are
     get /dna/intent/api/v1/lan-automation/log,
     get /dna/intent/api/v1/lan-automation/log/{id},
-  - It should be noted that this module is an alias of lan_automation_log_v1_info
-
 """
 
 EXAMPLES = r"""
-- name: Get all Lan Automation Log Info
+---
+- name: Get all Lan Automation Log
   cisco.dnac.lan_automation_log_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -67,8 +77,7 @@ EXAMPLES = r"""
     offset: 0
     limit: 0
   register: result
-
-- name: Get Lan Automation Log Info by id
+- name: Get Lan Automation Log by id
   cisco.dnac.lan_automation_log_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -80,7 +89,6 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     id: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
