@@ -1,13 +1,22 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: lan_automation_status_info
-short_description: Information module for Lan Automation Status Info
+short_description: Information module for Lan Automation
+  Status
 description:
-  - This module represents an alias of the module lan_automation_status_v1_info
+  - Get all Lan Automation Status.
+  - Get Lan Automation Status by id.
+  - Invoke this API to get the LAN Automation session
+    status based on the given Lan Automation session
+    id.
+  - Invoke this API to get the LAN Automation session
+    status.
 version_added: '6.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -18,36 +27,45 @@ options:
     type: dict
   offset:
     description:
-      - Offset query parameter. Starting index of the LAN Automation session. Minimum
-        value is 1.
-    type: float
+      - Offset query parameter. Starting index of the
+        LAN Automation session. Minimum value is 1.
+    type: int
   limit:
     description:
-      - Limit query parameter. Number of LAN Automation sessions to be retrieved.
-        Limit value can range between 1 to 10.
-    type: float
+      - Limit query parameter. Number of LAN Automation
+        sessions to be retrieved. Limit value can range
+        between 1 to 10.
+    type: int
   id:
     description:
       - Id path parameter. LAN Automation session identifier.
     type: str
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for LAN Automation LANAutomationStatusByIdV1
-    description: Complete reference of the LANAutomationStatusByIdV1 API.
-    link: https://developer.cisco.com/docs/dna-center/#!l-an-automation-status-by-id
-  - name: Cisco DNA Center documentation for LAN Automation LANAutomationStatusV1
-    description: Complete reference of the LANAutomationStatusV1 API.
+  - name: Cisco DNA Center documentation for LAN Automation
+      LANAutomationStatus
+    description: Complete reference of the LANAutomationStatus
+      API.
     link: https://developer.cisco.com/docs/dna-center/#!l-an-automation-status
+  - name: Cisco DNA Center documentation for LAN Automation
+      LANAutomationStatusById
+    description: Complete reference of the LANAutomationStatusById
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!l-an-automation-status-by-id
 notes:
-  - SDK Method used are lan_automation.LanAutomation.lan_automation_status_by_id_v1,
-    lan_automation.LanAutomation.lan_automation_status_v1,
-  - Paths used are get /dna/intent/api/v1/lan-automation/status, get /dna/intent/api/v1/lan-automation/status/{id},
-  - It should be noted that this module is an alias of lan_automation_status_v1_info
+  - SDK Method used are
+    lan_automation.LanAutomation.lan_automation_status,
+    lan_automation.LanAutomation.lan_automation_status_by_id,
+  - Paths used are
+    get /dna/intent/api/v1/lan-automation/status,
+    get /dna/intent/api/v1/lan-automation/status/{id},
 """
+
 EXAMPLES = r"""
-- name: Get all Lan Automation Status Info
+---
+- name: Get all Lan Automation Status
   cisco.dnac.lan_automation_status_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -60,7 +78,7 @@ EXAMPLES = r"""
     offset: 0
     limit: 0
   register: result
-- name: Get Lan Automation Status Info by id
+- name: Get Lan Automation Status by id
   cisco.dnac.lan_automation_status_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
@@ -113,8 +131,20 @@ dnac_response:
           "discoveryLevel": 0,
           "discoveryTimeout": 0,
           "discoveryDevices": [
-            {}
-          ]
+            {
+              "deviceSerialNumber": "string",
+              "deviceHostName": "string",
+              "deviceManagementIPAddress": "string",
+              "deviceSiteId": "string",
+              "deviceSiteNameHierarchy": "string",
+              "isDeviceDiscovered": true,
+              "isIPAllocated": true,
+              "isIPAssigned": true,
+              "pnpDeviceId": "string"
+            }
+          ],
+          "hostNamePrefix": "string",
+          "hostNameFileId": "string"
         }
       ],
       "version": "string"
