@@ -7,10 +7,11 @@
 DOCUMENTATION = r"""
 ---
 module: network_device_by_serial_number_info
-short_description: Information module for Network Device By Serial Number
+short_description: Information module for Network Device
+  By Serial Number
 description:
-- Get Network Device By Serial Number by id.
-- Returns the network device with given serial number.
+  - Get Network Device By Serial Number by id.
+  - Returns the network device with given serial number.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,25 +22,26 @@ options:
     type: dict
   serialNumber:
     description:
-    - SerialNumber path parameter. Device serial number.
+      - SerialNumber path parameter. Device serial number.
     type: str
 requirements:
-- dnacentersdk >= 2.5.5
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Devices GetDeviceBySerialNumber
-  description: Complete reference of the GetDeviceBySerialNumber API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-device-by-serial-number
+  - name: Cisco DNA Center documentation for Devices
+      GetDeviceBySerialNumber
+    description: Complete reference of the GetDeviceBySerialNumber
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-device-by-serial-number
 notes:
   - SDK Method used are
     devices.Devices.get_device_by_serial_number,
-
   - Paths used are
     get /dna/intent/api/v1/network-device/serial-number/{serialNumber},
-
 """
 
 EXAMPLES = r"""
+---
 - name: Get Network Device By Serial Number by id
   cisco.dnac.network_device_by_serial_number_info:
     dnac_host: "{{dnac_host}}"
@@ -52,9 +54,7 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     serialNumber: string
   register: result
-
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
@@ -101,7 +101,19 @@ dnac_response:
         "tunnelUdpPort": "string",
         "type": "string",
         "upTime": "string",
-        "waasDeviceMode": "string"
+        "waasDeviceMode": "string",
+        "dnsResolvedManagementAddress": "string",
+        "apEthernetMacAddress": "string",
+        "vendor": "string",
+        "reasonsForPendingSyncRequests": "string",
+        "pendingSyncRequestsCount": "string",
+        "reasonsForDeviceResync": "string",
+        "lastDeviceResyncStartTime": "string",
+        "uptimeSeconds": 0,
+        "managedAtleastOnce": true,
+        "deviceSupportLevel": "string",
+        "managementState": "string",
+        "description": "string"
       },
       "version": "string"
     }
