@@ -4,13 +4,17 @@
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
-
 DOCUMENTATION = r"""
 ---
 module: network_device_custom_prompt
-short_description: Resource module for Network Device Custom Prompt
+short_description: Resource module for Network Device
+  Custom Prompt
 description:
-- This module represents an alias of the module network_device_custom_prompt_v1
+  - Manage operation create of the resource Network
+    Device Custom Prompt. - > Save custom prompt added
+    by user in Catalyst Center. API will always override
+    the existing prompts. User should provide all the
+    custom prompt in case of any update.
 version_added: '6.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -23,23 +27,23 @@ options:
     description: Username for Custom Prompt.
     type: str
 requirements:
-- dnacentersdk >= 2.4.9
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for System Settings CustomPromptPOSTAPIV1
-  description: Complete reference of the CustomPromptPOSTAPIV1 API.
-  link: https://developer.cisco.com/docs/dna-center/#!custom-prompt-postapi
+  - name: Cisco DNA Center documentation for System
+      Settings CustomPromptPOSTAPI
+    description: Complete reference of the CustomPromptPOSTAPI
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!custom-prompt-postapi
 notes:
   - SDK Method used are
-    system_settings.SystemSettings.custom_prompt_post_api_v1,
-
+    system_settings.SystemSettings.custom_prompt_post_api,
   - Paths used are
     post /dna/intent/api/v1/network-device/custom-prompt,
-  - It should be noted that this module is an alias of network_device_custom_prompt_v1
-
 """
 
 EXAMPLES = r"""
+---
 - name: Create
   cisco.dnac.network_device_custom_prompt:
     dnac_host: "{{dnac_host}}"
@@ -51,7 +55,6 @@ EXAMPLES = r"""
     dnac_debug: "{{dnac_debug}}"
     passwordPrompt: string
     usernamePrompt: string
-
 """
 RETURN = r"""
 dnac_response:
