@@ -1,13 +1,17 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 # Copyright (c) 2021, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
+
 DOCUMENTATION = r"""
 ---
 module: tag_member_count_info
-short_description: Information module for Tag Member Count Info
+short_description: Information module for Tag Member
+  Count
 description:
-  - This module represents an alias of the module tag_member_count_v1_info
+  - Get all Tag Member Count.
+  - Returns the number of members in a given tag.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -29,19 +33,23 @@ options:
       - MemberAssociationType query parameter.
     type: str
 requirements:
-  - dnacentersdk >= 2.4.9
+  - dnacentersdk >= 2.10.1
   - python >= 3.5
 seealso:
-  - name: Cisco DNA Center documentation for Tag GetTagMemberCountV1
-    description: Complete reference of the GetTagMemberCountV1 API.
+  - name: Cisco DNA Center documentation for Tag GetTagMemberCount
+    description: Complete reference of the GetTagMemberCount
+      API.
     link: https://developer.cisco.com/docs/dna-center/#!get-tag-member-count
 notes:
-  - SDK Method used are tag.Tag.get_tag_member_count_v1,
-  - Paths used are get /dna/intent/api/v1/tag/{id}/member/count,
-  - It should be noted that this module is an alias of tag_member_count_v1_info
+  - SDK Method used are
+    tag.Tag.get_tag_member_count,
+  - Paths used are
+    get /dna/intent/api/v1/tag/{id}/member/count,
 """
+
 EXAMPLES = r"""
-- name: Get all Tag Member Count Info
+---
+- name: Get all Tag Member Count
   cisco.dnac.tag_member_count_info:
     dnac_host: "{{dnac_host}}"
     dnac_username: "{{dnac_username}}"
