@@ -15,35 +15,22 @@ for a given resource, parsed, and the facts tree is populated
 based on the configuration.
 """
 
-from copy import deepcopy
-
-from ansible.module_utils.six import iteritems
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common import utils
 
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.argspec.ospf_interfaces.ospf_interfaces import (
-    Ospf_InterfacesArgs,
+    Ospf_interfacesArgs,
 )
 from ansible_collections.cisco.ios.plugins.module_utils.network.ios.rm_templates.ospf_interfaces import (
-    Ospf_InterfacesTemplate,
+    Ospf_interfacesTemplate,
 )
 
 
-class Ospf_InterfacesFacts(object):
+class Ospf_interfacesFacts(object):
     """The cisco.ios ospf_interfaces facts class"""
 
     def __init__(self, module, subspec="config", options="options"):
         self._module = module
-        self.argument_spec = Ospf_InterfacesArgs.argument_spec
-        spec = deepcopy(self.argument_spec)
-        if subspec:
-            if options:
-                facts_argument_spec = spec[subspec][options]
-            else:
-                facts_argument_spec = spec[subspec]
-        else:
-            facts_argument_spec = spec
-
-        self.generated_spec = utils.generate_dict(facts_argument_spec)
+        self.argument_spec = Ospf_interfacesArgs.argument_spec
 
     def get_ospf_interfaces_data(self, connection):
         return connection.get("show running-config | section ^interface")
@@ -65,14 +52,15 @@ class Ospf_InterfacesFacts(object):
             data = self.get_ospf_interfaces_data(connection)
 
         # parse native config using the Ospf_interfaces template
-        ospf_interfaces_parser = Ospf_InterfacesTemplate(
+        ospf_interfaces_parser = Ospf_interfacesTemplate(
             lines=data.splitlines(),
             module=self._module,
         )
 
         objs = ospf_interfaces_parser.parse()
         final_objs = []
-        for key, value in iteritems(objs):
+
+        for key, value in objs.items():
             temp_af = []
             if value["address_family"].get("ip"):
                 temp_af.append(value["address_family"].get("ip"))
@@ -83,6 +71,7 @@ class Ospf_InterfacesFacts(object):
             if value:
                 value = utils.remove_empties(value)
                 final_objs.append(value)
+
         ansible_facts["ansible_network_resources"].pop("ospf_interfaces", None)
 
         params = utils.remove_empties(
@@ -93,7 +82,7 @@ class Ospf_InterfacesFacts(object):
             ),
         )
 
-        facts["ospf_interfaces"] = params["config"]
+        facts["ospf_interfaces"] = params.get("config", [])
         ansible_facts["ansible_network_resources"].update(facts)
 
         return ansible_facts
