@@ -20,15 +20,15 @@ __metaclass__ = type
 import platform
 import re
 
-from ansible.module_utils.six import iteritems
-from ansible.module_utils.six.moves import zip
-
 from ansible_collections.cisco.iosxr.plugins.module_utils.network.iosxr.iosxr import (
     get_capabilities,
     run_commands,
 )
 
 
+# Python 3 has zip built-in, no need to import
+
+
 class FactsBase(object):
     COMMANDS = frozenset()
 
@@ -150,7 +150,7 @@ class Interfaces(FactsBase):
 
     def populate_interfaces(self, interfaces):
         facts = dict()
-        for key, value in iteritems(interfaces):
+        for key, value in interfaces.items():
             intf = dict()
             intf["description"] = self.parse_description(value)
             intf["macaddress"] = self.parse_macaddress(value)
@@ -171,7 +171,7 @@ class Interfaces(FactsBase):
         return facts
 
     def populate_ipv6_interfaces(self, data):
-        for key, value in iteritems(data):
+        for key, value in data.items():
             if key in ["No", "RPF"] or key.startswith("IP"):
                 continue
             self.facts["interfaces"][key]["ipv6"] = list()
@@ -308,7 +308,7 @@ class Interfaces(FactsBase):
             return match.group(1)
 
     def parse_cdp_intf_port(self, data):
-        match = re.search(r"^Interface: (.+),  Port ID \(outgoing port\): (.+)$", data, re.M)
+        match = re.search(r"^Interface: (.+)[,\n]\s*Port ID \(outgoing port\): (.+)$", data, re.M)
         if match:
             return match.group(1), match.group(2)
 
@@ -323,6 +323,6 @@ class Interfaces(FactsBase):
             return match.group(1)
 
     def parse_cdp_ip(self, data):
-        match = re.search(r"^  IP address: (.+)$", data, re.M)
+        match = re.search(r"^  IP(?:v4)? address: (.+)$", data, re.M)
         if match:
             return match.group(1)
