@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Based on local.py (c) 2012, Michael DeHaan <michael.dehaan@gmail.com>
 # and chroot.py     (c) 2013, Maykel Moya <mmoya@speedyrails.com>
 # and jail.py       (c) 2013, Michael Scherer <misc@zarb.org>
@@ -31,9 +30,9 @@ import os
 import os.path
 import subprocess
 import traceback
+from shlex import quote as shlex_quote
 
 from ansible.errors import AnsibleError
-from ansible.module_utils.six.moves import shlex_quote
 from ansible.module_utils.common.process import get_bin_path
 from ansible.module_utils.common.text.converters import to_bytes
 from ansible.plugins.connection import ConnectionBase, BUFSIZE
@@ -43,22 +42,22 @@ display = Display()
 
 
 class Connection(ConnectionBase):
-    """ Local zone based connections """
+    """Local zone based connections"""
 
-    transport = 'community.general.zone'
+    transport = "community.general.zone"
     has_pipelining = True
     has_tty = False
 
     def __init__(self, play_context, new_stdin, *args, **kwargs):
-        super(Connection, self).__init__(play_context, new_stdin, *args, **kwargs)
+        super().__init__(play_context, new_stdin, *args, **kwargs)
 
         self.zone = self._play_context.remote_addr
 
         if os.geteuid() != 0:
             raise AnsibleError("zone connection requires running as root")
 
-        self.zoneadm_cmd = to_bytes(self._search_executable('zoneadm'))
-        self.zlogin_cmd = to_bytes(self._search_executable('zlogin'))
+        self.zoneadm_cmd = to_bytes(self._search_executable("zoneadm"))
+        self.zlogin_cmd = to_bytes(self._search_executable("zlogin"))
 
         if self.zone not in self.list_zones():
             raise AnsibleError(f"incorrect zone name {self.zone}")
@@ -71,15 +70,15 @@ class Connection(ConnectionBase):
             raise AnsibleError(f"{executable} command not found in PATH")
 
     def list_zones(self):
-        process = subprocess.Popen([self.zoneadm_cmd, 'list', '-ip'],
-                                   stdin=subprocess.PIPE,
-                                   stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        process = subprocess.Popen(
+            [self.zoneadm_cmd, "list", "-ip"], stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE
+        )
 
         zones = []
         for line in process.stdout.readlines():
             # 1:work:running:/zones/work:3126dc59-9a07-4829-cde9-a816e4c5040e:native:shared
-            s = line.split(':')
-            if s[1] != 'global':
+            s = line.split(":")
+            if s[1] != "global":
                 zones.append(s[1])
 
         return zones
@@ -87,23 +86,26 @@ class Connection(ConnectionBase):
     def get_zone_path(self):
         # solaris10vm# zoneadm -z cswbuild list -p
         # -:cswbuild:installed:/zones/cswbuild:479f3c4b-d0c6-e97b-cd04-fd58f2c0238e:native:shared
-        process = subprocess.Popen([self.zoneadm_cmd, '-z', to_bytes(self.zone), 'list', '-p'],
-                                   stdin=subprocess.PIPE,
-                                   stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        process = subprocess.Popen(
+            [self.zoneadm_cmd, "-z", to_bytes(self.zone), "list", "-p"],
+            stdin=subprocess.PIPE,
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+        )
 
         # stdout, stderr = p.communicate()
-        path = process.stdout.readlines()[0].split(':')[3]
+        path = process.stdout.readlines()[0].split(":")[3]
         return f"{path}/root"
 
     def _connect(self):
-        """ connect to the zone; nothing to do here """
-        super(Connection, self)._connect()
+        """connect to the zone; nothing to do here"""
+        super()._connect()
         if not self._connected:
             display.vvv("THIS IS A LOCAL ZONE DIR", host=self.zone)
             self._connected = True
 
     def _buffered_exec_command(self, cmd, stdin=subprocess.PIPE):
-        """ run a command on the zone.  This is only needed for implementing
+        """run a command on the zone.  This is only needed for implementing
         put_file() get_file() so that we don't have to read the whole file
         into memory.
 
@@ -117,14 +119,13 @@ class Connection(ConnectionBase):
         local_cmd = map(to_bytes, local_cmd)
 
         display.vvv(f"EXEC {local_cmd}", host=self.zone)
-        p = subprocess.Popen(local_cmd, shell=False, stdin=stdin,
-                             stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+        p = subprocess.Popen(local_cmd, shell=False, stdin=stdin, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
 
         return p
 
     def exec_command(self, cmd, in_data=None, sudoable=False):
-        """ run a command on the zone """
-        super(Connection, self).exec_command(cmd, in_data=in_data, sudoable=sudoable)
+        """run a command on the zone"""
+        super().exec_command(cmd, in_data=in_data, sudoable=sudoable)
 
         p = self._buffered_exec_command(cmd)
 
@@ -132,33 +133,33 @@ class Connection(ConnectionBase):
         return p.returncode, stdout, stderr
 
     def _prefix_login_path(self, remote_path):
-        """ Make sure that we put files into a standard path
+        """Make sure that we put files into a standard path
 
-            If a path is relative, then we need to choose where to put it.
-            ssh chooses $HOME but we aren't guaranteed that a home dir will
-            exist in any given chroot.  So for now we're choosing "/" instead.
-            This also happens to be the former default.
+        If a path is relative, then we need to choose where to put it.
+        ssh chooses $HOME but we aren't guaranteed that a home dir will
+        exist in any given chroot.  So for now we're choosing "/" instead.
+        This also happens to be the former default.
 
-            Can revisit using $HOME instead if it is a problem
+        Can revisit using $HOME instead if it is a problem
         """
         if not remote_path.startswith(os.path.sep):
             remote_path = os.path.join(os.path.sep, remote_path)
         return os.path.normpath(remote_path)
 
     def put_file(self, in_path, out_path):
-        """ transfer a file from local to zone """
-        super(Connection, self).put_file(in_path, out_path)
+        """transfer a file from local to zone"""
+        super().put_file(in_path, out_path)
         display.vvv(f"PUT {in_path} TO {out_path}", host=self.zone)
 
         out_path = shlex_quote(self._prefix_login_path(out_path))
         try:
-            with open(in_path, 'rb') as in_file:
+            with open(in_path, "rb") as in_file:
                 if not os.fstat(in_file.fileno()).st_size:
-                    count = ' count=0'
+                    count = " count=0"
                 else:
-                    count = ''
+                    count = ""
                 try:
-                    p = self._buffered_exec_command(f'dd of={out_path} bs={BUFSIZE}{count}', stdin=in_file)
+                    p = self._buffered_exec_command(f"dd of={out_path} bs={BUFSIZE}{count}", stdin=in_file)
                 except OSError:
                     raise AnsibleError("jail connection requires dd command in the jail")
                 try:
@@ -172,17 +173,17 @@ class Connection(ConnectionBase):
             raise AnsibleError(f"file or module does not exist at: {in_path}")
 
     def fetch_file(self, in_path, out_path):
-        """ fetch a file from zone to local """
-        super(Connection, self).fetch_file(in_path, out_path)
+        """fetch a file from zone to local"""
+        super().fetch_file(in_path, out_path)
         display.vvv(f"FETCH {in_path} TO {out_path}", host=self.zone)
 
         in_path = shlex_quote(self._prefix_login_path(in_path))
         try:
-            p = self._buffered_exec_command(f'dd if={in_path} bs={BUFSIZE}')
+            p = self._buffered_exec_command(f"dd if={in_path} bs={BUFSIZE}")
         except OSError:
             raise AnsibleError("zone connection requires dd command in the zone")
 
-        with open(out_path, 'wb+') as out_file:
+        with open(out_path, "wb+") as out_file:
             try:
                 chunk = p.stdout.read(BUFSIZE)
                 while chunk:
@@ -196,6 +197,6 @@ class Connection(ConnectionBase):
                 raise AnsibleError(f"failed to transfer file {in_path} to {out_path}:\n{stdout}\n{stderr}")
 
     def close(self):
-        """ terminate the connection; nothing to do here """
-        super(Connection, self).close()
+        """terminate the connection; nothing to do here"""
+        super().close()
         self._connected = False
