@@ -1,21 +1,23 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright (c) 2016, Dimension Data
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 # Authors:
 #   - Adam Friedman  <tintoy@tintoy.io>
 
+#
+# DEPRECATED
+#
+# This doc fragment is deprecated and will be removed in community.general 13.0.0
+#
 
-class ModuleDocFragment(object):
 
+class ModuleDocFragment:
     # Dimension Data ("wait-for-completion" parameters) doc fragment
-    DOCUMENTATION = r'''
-
+    DOCUMENTATION = r"""
 options:
   wait:
     description:
@@ -34,4 +36,4 @@ options:
       - Only applicable if O(wait=true).
     type: int
     default: 2
-    '''
+"""
