@@ -1,14 +1,11 @@
-# -*- coding: utf-8 -*-
-
 # Copyright (c) 2018, www.privaz.io Valletech AB
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 
-class ModuleDocFragment(object):
+class ModuleDocFragment:
     # OpenNebula common documentation
     DOCUMENTATION = r"""
 options:
