@@ -1,17 +1,13 @@
-# -*- coding: utf-8 -*-
-
 # Copyright (c) 2021, Phillipe Smith <phsmithcc@gmail.com>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 
-class ModuleDocFragment(object):
-
+class ModuleDocFragment:
     # Standard files documentation fragment
-    DOCUMENTATION = r'''
+    DOCUMENTATION = r"""
 options:
   url:
     type: str
@@ -29,4 +25,4 @@ options:
     description:
       - Rundeck User API Token.
     required: true
-'''
+"""
