@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (C) 2021 Eric Lavarde <elavarde@redhat.com>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
@@ -38,14 +37,12 @@ from ansible_collections.community.general.plugins.module_utils.version import L
 
 
 def version_sort(value, reverse=False):
-    '''Sort a list according to loose versions so that e.g. 2.9 is smaller than 2.10'''
+    """Sort a list according to loose versions so that e.g. 2.9 is smaller than 2.10"""
     return sorted(value, key=LooseVersion, reverse=reverse)
 
 
-class FilterModule(object):
-    ''' Version sort filter '''
+class FilterModule:
+    """Version sort filter"""
 
     def filters(self):
-        return {
-            'version_sort': version_sort
-        }
+        return {"version_sort": version_sort}
