@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
 # Copyright (c) 2022, Alexei Znamensky <russoz@gmail.com>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 
 import os
@@ -17,9 +15,9 @@ _PUPPET_PATH_PREFIX = ["/opt/puppetlabs/bin"]
 
 def get_facter_dir():
     if os.getuid() == 0:
-        return '/etc/facter/facts.d'
+        return "/etc/facter/facts.d"
     else:
-        return os.path.expanduser('~/.facter/facts.d')
+        return os.path.expanduser("~/.facter/facts.d")
 
 
 def _puppet_cmd(module):
@@ -34,23 +32,19 @@ def ensure_agent_enabled(module):
         command="puppet",
         path_prefix=_PUPPET_PATH_PREFIX,
         arg_formats=dict(
-            _agent_disabled=cmd_runner_fmt.as_fixed(['config', 'print', 'agent_disabled_lockfile']),
+            _agent_disabled=cmd_runner_fmt.as_fixed(["config", "print", "agent_disabled_lockfile"]),
         ),
         check_rc=False,
     )
 
     rc, stdout, stderr = runner("_agent_disabled").run()
     if os.path.exists(stdout.strip()):
-        module.fail_json(
-            msg="Puppet agent is administratively disabled.",
-            disabled=True)
+        module.fail_json(msg="Puppet agent is administratively disabled.", disabled=True)
     elif rc != 0:
-        module.fail_json(
-            msg="Puppet agent state could not be determined.")
+        module.fail_json(msg="Puppet agent state could not be determined.")
 
 
 def puppet_runner(module):
-
     # Keeping backward compatibility, allow for running with the `timeout` CLI command.
     # If this can be replaced with ansible `timeout` parameter in playbook,
     # then this function could be removed.
@@ -82,10 +76,19 @@ def puppet_runner(module):
         command=_prepare_base_cmd(),
         path_prefix=_PUPPET_PATH_PREFIX,
         arg_formats=dict(
-            _agent_fixed=cmd_runner_fmt.as_fixed([
-                "agent", "--onetime", "--no-daemonize", "--no-usecacheonfailure",
-                "--no-splay", "--detailed-exitcodes", "--verbose", "--color", "0",
-            ]),
+            _agent_fixed=cmd_runner_fmt.as_fixed(
+                [
+                    "agent",
+                    "--onetime",
+                    "--no-daemonize",
+                    "--no-usecacheonfailure",
+                    "--no-splay",
+                    "--detailed-exitcodes",
+                    "--verbose",
+                    "--color",
+                    "0",
+                ]
+            ),
             _apply_fixed=cmd_runner_fmt.as_fixed(["apply", "--detailed-exitcodes"]),
             puppetmaster=cmd_runner_fmt.as_opt_val("--server"),
             show_diff=cmd_runner_fmt.as_bool("--show-diff"),
