@@ -1,11 +1,9 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 # Copyright (c) 2017, Dag Wieers <dag@wieers.com>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 
 DOCUMENTATION = r"""
@@ -57,8 +55,8 @@ options:
     description:
       - When used instead of O(path), sets the content of the API requests directly.
       - This may be convenient to template simple requests, for anything complex use the M(ansible.builtin.template) module.
-      - You can collate multiple IMC XML fragments and they will be processed sequentially in a single stream, the Cisco IMC
-        output is subsequently merged.
+      - You can collate multiple IMC XML fragments and they are processed sequentially in a single stream, the Cisco IMC output
+        is subsequently merged.
       - Parameter O(content) is mutual exclusive with parameter O(path).
     type: str
   protocol:
@@ -71,12 +69,12 @@ options:
     description:
       - The socket level timeout in seconds.
       - This is the time that every single connection (every fragment) can spend. If this O(timeout) is reached, the module
-        will fail with a C(Connection failure) indicating that C(The read operation timed out).
+        fails with a C(Connection failure) indicating that C(The read operation timed out).
     default: 60
     type: int
   validate_certs:
     description:
-      - If V(false), SSL certificates will not be validated.
+      - If V(false), SSL certificates are not validated.
       - This should only set to V(false) used on personally controlled sites using self-signed certificates.
     type: bool
     default: true
@@ -84,8 +82,8 @@ notes:
   - The XML fragments do not need an authentication cookie, this is injected by the module automatically.
   - The Cisco IMC XML output is being translated to JSON using the Cobra convention.
   - Any configConfMo change requested has a return status of C(modified), even if there was no actual change from the previous
-    configuration. As a result, this module will always report a change on subsequent runs. In case this behaviour is fixed
-    in a future update to Cisco IMC, this module will automatically adapt.
+    configuration. As a result, this module always reports a change on subsequent runs. In case this behaviour is fixed in
+    a future update to Cisco IMC, this module is meant to automatically adapt.
   - If you get a C(Connection failure) related to C(The read operation timed out) increase the O(timeout) parameter. Some
     XML fragments can take longer than the default timeout.
   - More information about the IMC REST API is available from
@@ -268,10 +266,12 @@ output:
 
 import os
 import traceback
+from itertools import zip_longest
 
 LXML_ETREE_IMP_ERR = None
 try:
     import lxml.etree
+
     HAS_LXML_ETREE = True
 except ImportError:
     LXML_ETREE_IMP_ERR = traceback.format_exc()
@@ -280,13 +280,13 @@ except ImportError:
 XMLJSON_COBRA_IMP_ERR = None
 try:
     from xmljson import cobra
+
     HAS_XMLJSON_COBRA = True
 except ImportError:
     XMLJSON_COBRA_IMP_ERR = traceback.format_exc()
     HAS_XMLJSON_COBRA = False
 
 from ansible.module_utils.basic import AnsibleModule, missing_required_lib
-from ansible.module_utils.six.moves import zip_longest
 from ansible.module_utils.urls import fetch_url
 
 from ansible_collections.community.general.plugins.module_utils.datetime import (
@@ -294,31 +294,31 @@ from ansible_collections.community.general.plugins.module_utils.datetime import
 )
 
 
-def imc_response(module, rawoutput, rawinput=''):
-    ''' Handle IMC returned data '''
+def imc_response(module, rawoutput, rawinput=""):
+    """Handle IMC returned data"""
     xmloutput = lxml.etree.fromstring(rawoutput)
     result = cobra.data(xmloutput)
 
     # Handle errors
-    if xmloutput.get('errorCode') and xmloutput.get('errorDescr'):
+    if xmloutput.get("errorCode") and xmloutput.get("errorDescr"):
         if rawinput:
-            result['input'] = rawinput
-        result['output'] = rawoutput
-        result['error_code'] = xmloutput.get('errorCode')
-        result['error_text'] = xmloutput.get('errorDescr')
-        module.fail_json(msg='Request failed: %(error_text)s' % result, **result)
+            result["input"] = rawinput
+        result["output"] = rawoutput
+        result["error_code"] = xmloutput.get("errorCode")
+        result["error_text"] = xmloutput.get("errorDescr")
+        module.fail_json(msg=f"Request failed: {result['error_text']}", **result)
 
     return result
 
 
 def logout(module, url, cookie, timeout):
-    ''' Perform a logout, if needed '''
-    data = '<aaaLogout cookie="%s" inCookie="%s"/>' % (cookie, cookie)
+    """Perform a logout, if needed"""
+    data = f'<aaaLogout cookie="{cookie}" inCookie="{cookie}"/>'
     resp, auth = fetch_url(module, url, data=data, method="POST", timeout=timeout)
 
 
 def merge(one, two):
-    ''' Merge two complex nested datastructures into one'''
+    """Merge two complex nested datastructures into one"""
     if isinstance(one, dict) and isinstance(two, dict):
         copy = dict(one)
         copy.update({key: merge(one.get(key, None), two[key]) for key in two})
@@ -333,34 +333,34 @@ def merge(one, two):
 def main():
     module = AnsibleModule(
         argument_spec=dict(
-            hostname=dict(type='str', required=True, aliases=['host', 'ip']),
-            username=dict(type='str', default='admin', aliases=['user']),
-            password=dict(type='str', default='password', no_log=True),
-            content=dict(type='str'),
-            path=dict(type='path', aliases=['config_file', 'src']),
-            protocol=dict(type='str', default='https', choices=['http', 'https']),
-            timeout=dict(type='int', default=60),
-            validate_certs=dict(type='bool', default=True),
+            hostname=dict(type="str", required=True, aliases=["host", "ip"]),
+            username=dict(type="str", default="admin", aliases=["user"]),
+            password=dict(type="str", default="password", no_log=True),
+            content=dict(type="str"),
+            path=dict(type="path", aliases=["config_file", "src"]),
+            protocol=dict(type="str", default="https", choices=["http", "https"]),
+            timeout=dict(type="int", default=60),
+            validate_certs=dict(type="bool", default=True),
         ),
         supports_check_mode=True,
-        mutually_exclusive=[['content', 'path']],
+        mutually_exclusive=[["content", "path"]],
     )
 
     if not HAS_LXML_ETREE:
-        module.fail_json(msg=missing_required_lib('lxml'), exception=LXML_ETREE_IMP_ERR)
+        module.fail_json(msg=missing_required_lib("lxml"), exception=LXML_ETREE_IMP_ERR)
 
     if not HAS_XMLJSON_COBRA:
-        module.fail_json(msg=missing_required_lib('xmljson >= 0.1.8'), exception=XMLJSON_COBRA_IMP_ERR)
+        module.fail_json(msg=missing_required_lib("xmljson >= 0.1.8"), exception=XMLJSON_COBRA_IMP_ERR)
 
-    hostname = module.params['hostname']
-    username = module.params['username']
-    password = module.params['password']
+    hostname = module.params["hostname"]
+    username = module.params["username"]
+    password = module.params["password"]
 
-    content = module.params['content']
-    path = module.params['path']
+    content = module.params["content"]
+    path = module.params["path"]
 
-    protocol = module.params['protocol']
-    timeout = module.params['timeout']
+    protocol = module.params["protocol"]
+    timeout = module.params["timeout"]
 
     result = dict(
         failed=False,
@@ -373,69 +373,69 @@ def main():
         if os.path.isfile(path):
             file_exists = True
         else:
-            module.fail_json(msg='Cannot find/access path:\n%s' % path)
+            module.fail_json(msg=f"Cannot find/access path:\n{path}")
 
     start = now()
 
     # Perform login first
-    url = '%s://%s/nuova' % (protocol, hostname)
-    data = '<aaaLogin inName="%s" inPassword="%s"/>' % (username, password)
-    resp, auth = fetch_url(module, url, data=data, method='POST', timeout=timeout)
-    if resp is None or auth['status'] != 200:
-        result['elapsed'] = (now() - start).seconds
-        module.fail_json(msg='Task failed with error %(status)s: %(msg)s' % auth, **result)
+    url = f"{protocol}://{hostname}/nuova"
+    data = f'<aaaLogin inName="{username}" inPassword="{password}"/>'
+    resp, auth = fetch_url(module, url, data=data, method="POST", timeout=timeout)
+    if resp is None or auth["status"] != 200:
+        result["elapsed"] = (now() - start).seconds
+        module.fail_json(msg=f"Task failed with error {auth['status']}: {auth['msg']}", **result)
     result.update(imc_response(module, resp.read()))
 
     # Store cookie for future requests
-    cookie = ''
+    cookie = ""
     try:
-        cookie = result['aaaLogin']['attributes']['outCookie']
+        cookie = result["aaaLogin"]["attributes"]["outCookie"]
     except Exception:
-        module.fail_json(msg='Could not find cookie in output', **result)
+        module.fail_json(msg="Could not find cookie in output", **result)
 
     try:
         # Prepare request data
         if content:
             rawdata = content
         elif file_exists:
-            with open(path, 'r') as config_object:
+            with open(path, "r") as config_object:
                 rawdata = config_object.read()
 
         # Wrap the XML documents in a <root> element
-        xmldata = lxml.etree.fromstring('<root>%s</root>' % rawdata.replace('\n', ''))
+        xmldata = lxml.etree.fromstring("<root>%s</root>" % rawdata.replace("\n", ""))
 
         # Handle each XML document separately in the same session
         for xmldoc in list(xmldata):
             if xmldoc.tag is lxml.etree.Comment:
                 continue
             # Add cookie to XML
-            xmldoc.set('cookie', cookie)
+            xmldoc.set("cookie", cookie)
             data = lxml.etree.tostring(xmldoc)
 
             # Perform actual request
-            resp, info = fetch_url(module, url, data=data, method='POST', timeout=timeout)
-            if resp is None or info['status'] != 200:
-                result['elapsed'] = (now() - start).seconds
-                module.fail_json(msg='Task failed with error %(status)s: %(msg)s' % info, **result)
+            resp, info = fetch_url(module, url, data=data, method="POST", timeout=timeout)
+            if resp is None or info["status"] != 200:
+                result["elapsed"] = (now() - start).seconds
+                module.fail_json(msg=f"Task failed with error {info['status']}: {info['msg']}", **result)
 
             # Merge results with previous results
             rawoutput = resp.read()
             result = merge(result, imc_response(module, rawoutput, rawinput=data))
-            result['response'] = info['msg']
-            result['status'] = info['status']
+            result["response"] = info["msg"]
+            result["status"] = info["status"]
 
             # Check for any changes
             # NOTE: Unfortunately IMC API always report status as 'modified'
             xmloutput = lxml.etree.fromstring(rawoutput)
-            results = xmloutput.xpath('/configConfMo/outConfig/*/@status')
-            result['changed'] = ('modified' in results)
+            results = xmloutput.xpath("/configConfMo/outConfig/*/@status")
+            result["changed"] = "modified" in results
 
         # Report success
-        result['elapsed'] = (now() - start).seconds
+        result["elapsed"] = (now() - start).seconds
         module.exit_json(**result)
     finally:
         logout(module, url, cookie, timeout)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
