@@ -1,12 +1,10 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 
 # Copyright (c) 2016-2017, Hewlett Packard Enterprise Development LP
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 module: oneview_logical_interconnect_group_info
@@ -97,20 +95,19 @@ from ansible_collections.community.general.plugins.module_utils.oneview import O
 
 class LogicalInterconnectGroupInfoModule(OneViewModuleBase):
     def __init__(self):
-
         argument_spec = dict(
-            name=dict(type='str'),
-            params=dict(type='dict'),
+            name=dict(type="str"),
+            params=dict(type="dict"),
         )
 
-        super(LogicalInterconnectGroupInfoModule, self).__init__(
+        super().__init__(
             additional_arg_spec=argument_spec,
             supports_check_mode=True,
         )
 
     def execute_module(self):
-        if self.module.params.get('name'):
-            ligs = self.oneview_client.logical_interconnect_groups.get_by('name', self.module.params['name'])
+        if self.module.params.get("name"):
+            ligs = self.oneview_client.logical_interconnect_groups.get_by("name", self.module.params["name"])
         else:
             ligs = self.oneview_client.logical_interconnect_groups.get_all(**self.facts_params)
 
@@ -121,5 +118,5 @@ def main():
     LogicalInterconnectGroupInfoModule().run()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
