@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 
 # Copyright (c) 2014, GeekChimp - Franck Nijhof <franck@geekchimp.com> (DO NOT CONTACT!)
 # Copyright (c) 2019, Ansible project
@@ -7,8 +6,7 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-__metaclass__ = type
+from __future__ import annotations
 
 DOCUMENTATION = r"""
 module: osx_defaults
@@ -69,7 +67,7 @@ options:
   state:
     description:
       - The state of the user defaults.
-      - If set to V(list) will query the given parameter specified by O(key). Returns V(null) is nothing found or mis-spelled.
+      - If set to V(list) it queries the given parameter specified by O(key). Returns V(null) is nothing found or misspelled.
     type: str
     choices: [absent, list, present]
     default: present
@@ -140,7 +138,6 @@ from datetime import datetime
 import re
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils.six import binary_type, text_type
 
 
 # exceptions --------------------------------------------------------------- {{{
@@ -151,38 +148,39 @@ class OSXDefaultsException(Exception):
 
 # /exceptions -------------------------------------------------------------- }}}
 
+
 # class MacDefaults -------------------------------------------------------- {{{
-class OSXDefaults(object):
-    """ Class to manage Mac OS user defaults """
+class OSXDefaults:
+    """Class to manage Mac OS user defaults"""
 
     # init ---------------------------------------------------------------- {{{
     def __init__(self, module):
-        """ Initialize this module. Finds 'defaults' executable and preps the parameters """
+        """Initialize this module. Finds 'defaults' executable and preps the parameters"""
         # Initial var for storing current defaults value
         self.current_value = None
         self.module = module
-        self.domain = module.params['domain']
-        self.host = module.params['host']
-        self.key = module.params['key']
-        self.check_type = module.params['check_type']
-        self.type = module.params['type']
-        self.array_add = module.params['array_add']
-        self.value = module.params['value']
-        self.state = module.params['state']
-        self.path = module.params['path']
+        self.domain = module.params["domain"]
+        self.host = module.params["host"]
+        self.key = module.params["key"]
+        self.check_type = module.params["check_type"]
+        self.type = module.params["type"]
+        self.array_add = module.params["array_add"]
+        self.value = module.params["value"]
+        self.state = module.params["state"]
+        self.path = module.params["path"]
 
         # Try to find the defaults executable
         self.executable = self.module.get_bin_path(
-            'defaults',
+            "defaults",
             required=False,
-            opt_dirs=self.path.split(':'),
+            opt_dirs=self.path.split(":"),
         )
 
         if not self.executable:
             raise OSXDefaultsException("Unable to locate defaults executable.")
 
         # Ensure the value is the correct type
-        if self.state != 'absent':
+        if self.state != "absent":
             self.value = self._convert_type(self.type, self.value)
 
     # /init --------------------------------------------------------------- }}}
@@ -191,64 +189,62 @@ class OSXDefaults(object):
     @staticmethod
     def is_int(value):
         as_str = str(value)
-        if (as_str.startswith("-")):
+        if as_str.startswith("-"):
             return as_str[1:].isdigit()
         else:
             return as_str.isdigit()
 
     @staticmethod
     def _convert_type(data_type, value):
-        """ Converts value to given type """
+        """Converts value to given type"""
         if data_type == "string":
             return str(value)
         elif data_type in ["bool", "boolean"]:
-            if isinstance(value, (binary_type, text_type)):
+            if isinstance(value, (bytes, str)):
                 value = value.lower()
             if value in [True, 1, "true", "1", "yes"]:
                 return True
             elif value in [False, 0, "false", "0", "no"]:
                 return False
-            raise OSXDefaultsException("Invalid boolean value: {0}".format(repr(value)))
+            raise OSXDefaultsException(f"Invalid boolean value: {value!r}")
         elif data_type == "date":
             try:
                 return datetime.strptime(value.split("+")[0].strip(), "%Y-%m-%d %H:%M:%S")
             except ValueError:
-                raise OSXDefaultsException(
-                    "Invalid date value: {0}. Required format yyy-mm-dd hh:mm:ss.".format(repr(value))
-                )
+                raise OSXDefaultsException(f"Invalid date value: {value!r}. Required format yyy-mm-dd hh:mm:ss.")
         elif data_type in ["int", "integer"]:
             if not OSXDefaults.is_int(value):
-                raise OSXDefaultsException("Invalid integer value: {0}".format(repr(value)))
+                raise OSXDefaultsException(f"Invalid integer value: {value!r}")
             return int(value)
         elif data_type == "float":
             try:
                 value = float(value)
             except ValueError:
-                raise OSXDefaultsException("Invalid float value: {0}".format(repr(value)))
+                raise OSXDefaultsException(f"Invalid float value: {value!r}")
             return value
         elif data_type == "array":
             if not isinstance(value, list):
                 raise OSXDefaultsException("Invalid value. Expected value to be an array")
             return value
 
-        raise OSXDefaultsException('Type is not supported: {0}'.format(data_type))
+        raise OSXDefaultsException(f"Type is not supported: {data_type}")
 
     def _host_args(self):
-        """ Returns a normalized list of commandline arguments based on the "host" attribute """
+        """Returns a normalized list of commandline arguments based on the "host" attribute"""
         if self.host is None:
             return []
-        elif self.host == 'currentHost':
-            return ['-currentHost']
+        elif self.host == "currentHost":
+            return ["-currentHost"]
         else:
-            return ['-host', self.host]
+            return ["-host", self.host]
 
     def _base_command(self):
-        """ Returns a list containing the "defaults" executable and any common base arguments """
+        """Returns a list containing the "defaults" executable and any common base arguments"""
         return [self.executable] + self._host_args()
 
     @staticmethod
     def _convert_defaults_str_to_list(value):
-        """ Converts array output from defaults to an list """
+        """Converts array output from defaults to an list"""
         # Split output of defaults. Every line contains a value
         value = value.splitlines()
 
@@ -257,7 +253,7 @@ class OSXDefaults(object):
         value.pop(-1)
 
         # Remove spaces at beginning and comma (,) at the end, unquote and unescape double quotes
-        value = [re.sub('^ *"?|"?,? *$', '', x.replace('\\"', '"')) for x in value]
+        value = [re.sub('^ *"?|"?,? *$', "", x.replace('\\"', '"')) for x in value]
 
         return value
 
@@ -265,7 +261,7 @@ class OSXDefaults(object):
 
     # commands ------------------------------------------------------------ {{{
     def read(self):
-        """ Reads value of this domain & key from defaults """
+        """Reads value of this domain & key from defaults"""
         # First try to find out the type
         rc, out, err = self.module.run_command(self._base_command() + ["read-type", self.domain, self.key])
 
@@ -275,10 +271,10 @@ class OSXDefaults(object):
 
         # If the RC is not 0, then terrible happened! Ooooh nooo!
         if rc != 0:
-            raise OSXDefaultsException("An error occurred while reading key type from defaults: %s" % err)
+            raise OSXDefaultsException(f"An error occurred while reading key type from defaults: {err}")
 
         # Ok, lets parse the type from output
-        data_type = out.strip().replace('Type is ', '')
+        data_type = out.strip().replace("Type is ", "")
 
         # Now get the current value
         rc, out, err = self.module.run_command(self._base_command() + ["read", self.domain, self.key])
@@ -288,7 +284,7 @@ class OSXDefaults(object):
 
         # A non zero RC at this point is kinda strange...
         if rc != 0:
-            raise OSXDefaultsException("An error occurred while reading key value from defaults: %s" % err)
+            raise OSXDefaultsException(f"An error occurred while reading key value from defaults: {err}")
 
         # Convert string to list when type is array
         if data_type == "array":
@@ -298,7 +294,7 @@ class OSXDefaults(object):
         self.current_value = self._convert_type(data_type, out)
 
     def write(self):
-        """ Writes value to this domain & key to defaults """
+        """Writes value to this domain & key to defaults"""
         # We need to convert some values so the defaults commandline understands it
         if isinstance(self.value, bool):
             if self.value:
@@ -310,7 +306,7 @@ class OSXDefaults(object):
         elif self.array_add and self.current_value is not None:
             value = list(set(self.value) - set(self.current_value))
         elif isinstance(self.value, datetime):
-            value = self.value.strftime('%Y-%m-%d %H:%M:%S')
+            value = self.value.strftime("%Y-%m-%d %H:%M:%S")
         else:
             value = self.value
 
@@ -322,17 +318,18 @@ class OSXDefaults(object):
         if not isinstance(value, list):
             value = [value]
 
-        rc, out, err = self.module.run_command(self._base_command() + ['write', self.domain, self.key, '-' + self.type] + value,
-                                               expand_user_and_vars=False)
+        rc, out, err = self.module.run_command(
+            self._base_command() + ["write", self.domain, self.key, f"-{self.type}"] + value, expand_user_and_vars=False
+        )
 
         if rc != 0:
-            raise OSXDefaultsException('An error occurred while writing value to defaults: %s' % err)
+            raise OSXDefaultsException(f"An error occurred while writing value to defaults: {err}")
 
     def delete(self):
-        """ Deletes defaults key from domain """
-        rc, out, err = self.module.run_command(self._base_command() + ['delete', self.domain, self.key])
+        """Deletes defaults key from domain"""
+        rc, out, err = self.module.run_command(self._base_command() + ["delete", self.domain, self.key])
         if rc != 0:
-            raise OSXDefaultsException("An error occurred while deleting key from defaults: %s" % err)
+            raise OSXDefaultsException(f"An error occurred while deleting key from defaults: {err}")
 
     # /commands ----------------------------------------------------------- }}}
 
@@ -340,11 +337,10 @@ class OSXDefaults(object):
     """ Does the magic! :) """
 
     def run(self):
-
         # Get the current value from defaults
         self.read()
 
-        if self.state == 'list':
+        if self.state == "list":
             self.module.exit_json(key=self.key, value=self.current_value)
 
         # Handle absent state
@@ -360,13 +356,22 @@ class OSXDefaults(object):
         if self.check_type:
             value_type = type(self.value)
             if self.current_value is not None and not isinstance(self.current_value, value_type):
-                raise OSXDefaultsException("Type mismatch. Type in defaults: %s" % type(self.current_value).__name__)
+                raise OSXDefaultsException(f"Type mismatch. Type in defaults: {type(self.current_value).__name__}")
 
         # Current value matches the given value. Nothing need to be done. Arrays need extra care
-        if self.type == "array" and self.current_value is not None and not self.array_add and \
-                        set(self.current_value) == set(self.value):
+        if (
+            self.type == "array"
+            and self.current_value is not None
+            and not self.array_add
+            and set(self.current_value) == set(self.value)
+        ):
             return False
-        elif self.type == "array" and self.current_value is not None and self.array_add and len(list(set(self.value) - set(self.current_value))) == 0:
+        elif (
+            self.type == "array"
+            and self.current_value is not None
+            and self.array_add
+            and len(list(set(self.value) - set(self.current_value))) == 0
+        ):
             return False
         elif self.current_value == self.value:
             return False
@@ -388,20 +393,22 @@ class OSXDefaults(object):
 def main():
     module = AnsibleModule(
         argument_spec=dict(
-            domain=dict(type='str', default='NSGlobalDomain'),
-            host=dict(type='str'),
-            key=dict(type='str', no_log=False),
-            check_type=dict(type='bool', default=True),
-            type=dict(type='str', default='string', choices=['array', 'bool', 'boolean', 'date', 'float', 'int', 'integer', 'string']),
-            array_add=dict(type='bool', default=False),
-            value=dict(type='raw'),
-            state=dict(type='str', default='present', choices=['absent', 'list', 'present']),
-            path=dict(type='str', default='/usr/bin:/usr/local/bin'),
+            domain=dict(type="str", default="NSGlobalDomain"),
+            host=dict(type="str"),
+            key=dict(type="str", no_log=False),
+            check_type=dict(type="bool", default=True),
+            type=dict(
+                type="str",
+                default="string",
+                choices=["array", "bool", "boolean", "date", "float", "int", "integer", "string"],
+            ),
+            array_add=dict(type="bool", default=False),
+            value=dict(type="raw"),
+            state=dict(type="str", default="present", choices=["absent", "list", "present"]),
+            path=dict(type="str", default="/usr/bin:/usr/local/bin"),
         ),
         supports_check_mode=True,
-        required_if=(
-            ('state', 'present', ['value']),
-        ),
+        required_if=(("state", "present", ["value"]),),
     )
 
     try:
@@ -413,5 +420,5 @@ def main():
 
 # /main ------------------------------------------------------------------- }}}
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
