@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 #
 # Scaleway Compute management module
 #
@@ -9,9 +8,8 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
+from __future__ import annotations
 
-__metaclass__ = type
 
 DOCUMENTATION = r"""
 module: scaleway_compute
@@ -22,12 +20,15 @@ description:
 extends_documentation_fragment:
   - community.general.scaleway
   - community.general.attributes
+  - community.general.scaleway.actiongroup_scaleway
 
 attributes:
   check_mode:
     support: full
   diff_mode:
     support: none
+  action_group:
+    version_added: 11.3.0
 
 options:
 
@@ -85,7 +86,6 @@ options:
     elements: str
     description:
       - List of tags to apply to the instance (5 max).
-    required: false
     default: []
 
   region:
@@ -124,14 +124,12 @@ options:
     type: int
     description:
       - Time to wait for the server to reach the expected state.
-    required: false
     default: 300
 
   wait_sleep_time:
     type: int
     description:
       - Time to wait before every attempt to check the state of the server.
-    required: false
     default: 3
 
   security_group:
@@ -139,7 +137,6 @@ options:
     description:
       - Security group unique identifier.
       - If no value provided, the default security group or current security group is used.
-    required: false
 """
 
 EXAMPLES = r"""
@@ -186,47 +183,41 @@ import time
 
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.community.general.plugins.module_utils.datetime import now
-from ansible_collections.community.general.plugins.module_utils.scaleway import SCALEWAY_LOCATION, scaleway_argument_spec, Scaleway
-
-SCALEWAY_SERVER_STATES = (
-    'stopped',
-    'stopping',
-    'starting',
-    'running',
-    'locked'
+from ansible_collections.community.general.plugins.module_utils.scaleway import (
+    SCALEWAY_LOCATION,
+    scaleway_argument_spec,
+    Scaleway,
 )
 
-SCALEWAY_TRANSITIONS_STATES = (
-    "stopping",
-    "starting",
-    "pending"
-)
+SCALEWAY_SERVER_STATES = ("stopped", "stopping", "starting", "running", "locked")
+
+SCALEWAY_TRANSITIONS_STATES = ("stopping", "starting", "pending")
 
 
 def check_image_id(compute_api, image_id):
-    response = compute_api.get(path="images/%s" % image_id)
+    response = compute_api.get(path=f"images/{image_id}")
 
     if not response.ok:
-        msg = 'Error in getting image %s on %s : %s' % (image_id, compute_api.module.params.get('api_url'), response.json)
+        msg = f"Error in getting image {image_id} on {compute_api.module.params.get('api_url')} : {response.json}"
         compute_api.module.fail_json(msg=msg)
 
 
 def fetch_state(compute_api, server):
-    compute_api.module.debug("fetch_state of server: %s" % server["id"])
-    response = compute_api.get(path="servers/%s" % server["id"])
+    compute_api.module.debug(f"fetch_state of server: {server['id']}")
+    response = compute_api.get(path=f"servers/{server['id']}")
 
     if response.status_code == 404:
         return "absent"
 
     if not response.ok:
-        msg = 'Error during state fetching: (%s) %s' % (response.status_code, response.json)
+        msg = f"Error during state fetching: ({response.status_code}) {response.json}"
         compute_api.module.fail_json(msg=msg)
 
     try:
-        compute_api.module.debug("Server %s in state: %s" % (server["id"], response.json["server"]["state"]))
+        compute_api.module.debug(f"Server {server['id']} in state: {response.json['server']['state']}")
         return response.json["server"]["state"]
     except KeyError:
-        compute_api.module.fail_json(msg="Could not fetch state in %s" % response.json)
+        compute_api.module.fail_json(msg=f"Could not fetch state in {response.json}")
 
 
 def wait_to_complete_state_transition(compute_api, server, wait=None):
@@ -244,7 +235,7 @@ def wait_to_complete_state_transition(compute_api, server, wait=None):
         compute_api.module.debug("We are going to wait for the server to finish its transition")
         if fetch_state(compute_api, server) not in SCALEWAY_TRANSITIONS_STATES:
             compute_api.module.debug("It seems that the server is not in transition anymore.")
-            compute_api.module.debug("Server in state: %s" % fetch_state(compute_api, server))
+            compute_api.module.debug(f"Server in state: {fetch_state(compute_api, server)}")
             break
         time.sleep(wait_sleep_time)
     else:
@@ -263,14 +254,14 @@ def public_ip_payload(compute_api, public_ip):
     # We check that the IP we want to attach exists, if so its ID is returned
     response = compute_api.get("ips")
     if not response.ok:
-        msg = 'Error during public IP validation: (%s) %s' % (response.status_code, response.json)
+        msg = f"Error during public IP validation: ({response.status_code}) {response.json}"
         compute_api.module.fail_json(msg=msg)
 
     ip_list = []
     try:
         ip_list = response.json["ips"]
     except KeyError:
-        compute_api.module.fail_json(msg="Error in getting the IP information from: %s" % response.json)
+        compute_api.module.fail_json(msg=f"Error in getting the IP information from: {response.json}")
 
     lookup = [ip["id"] for ip in ip_list]
     if public_ip in lookup:
@@ -280,13 +271,14 @@ def public_ip_payload(compute_api, public_ip):
 def create_server(compute_api, server):
     compute_api.module.debug("Starting a create_server")
     target_server = None
-    data = {"enable_ipv6": server["enable_ipv6"],
-            "tags": server["tags"],
-            "commercial_type": server["commercial_type"],
-            "image": server["image"],
-            "dynamic_ip_required": server["dynamic_ip_required"],
-            "name": server["name"]
-            }
+    data = {
+        "enable_ipv6": server["enable_ipv6"],
+        "tags": server["tags"],
+        "commercial_type": server["commercial_type"],
+        "image": server["image"],
+        "dynamic_ip_required": server["dynamic_ip_required"],
+        "name": server["name"],
+    }
 
     if server["project"]:
         data["project"] = server["project"]
@@ -300,13 +292,13 @@ def create_server(compute_api, server):
     response = compute_api.post(path="servers", data=data)
 
     if not response.ok:
-        msg = 'Error during server creation: (%s) %s' % (response.status_code, response.json)
+        msg = f"Error during server creation: ({response.status_code}) {response.json}"
         compute_api.module.fail_json(msg=msg)
 
     try:
         target_server = response.json["server"]
     except KeyError:
-        compute_api.module.fail_json(msg="Error in getting the server information from: %s" % response.json)
+        compute_api.module.fail_json(msg=f"Error in getting the server information from: {response.json}")
 
     wait_to_complete_state_transition(compute_api=compute_api, server=target_server)
 
@@ -326,10 +318,9 @@ def start_server(compute_api, server):
 
 
 def perform_action(compute_api, server, action):
-    response = compute_api.post(path="servers/%s/action" % server["id"],
-                                data={"action": action})
+    response = compute_api.post(path=f"servers/{server['id']}/action", data={"action": action})
     if not response.ok:
-        msg = 'Error during server %s: (%s) %s' % (action, response.status_code, response.json)
+        msg = f"Error during server {action}: ({response.status_code}) {response.json}"
         compute_api.module.fail_json(msg=msg)
 
     wait_to_complete_state_transition(compute_api=compute_api, server=server)
@@ -339,9 +330,9 @@ def perform_action(compute_api, server, action):
 
 def remove_server(compute_api, server):
     compute_api.module.debug("Starting remove server strategy")
-    response = compute_api.delete(path="servers/%s" % server["id"])
+    response = compute_api.delete(path=f"servers/{server['id']}")
     if not response.ok:
-        msg = 'Error during server deletion: (%s) %s' % (response.status_code, response.json)
+        msg = f"Error during server deletion: ({response.status_code}) {response.json}"
         compute_api.module.fail_json(msg=msg)
 
     wait_to_complete_state_transition(compute_api=compute_api, server=server)
@@ -363,14 +354,17 @@ def present_strategy(compute_api, wished_server):
     else:
         target_server = query_results[0]
 
-    if server_attributes_should_be_changed(compute_api=compute_api, target_server=target_server,
-                                           wished_server=wished_server):
+    if server_attributes_should_be_changed(
+        compute_api=compute_api, target_server=target_server, wished_server=wished_server
+    ):
         changed = True
 
         if compute_api.module.check_mode:
-            return changed, {"status": "Server %s attributes would be changed." % target_server["id"]}
+            return changed, {"status": f"Server {target_server['id']} attributes would be changed."}
 
-        target_server = server_change_attributes(compute_api=compute_api, target_server=target_server, wished_server=wished_server)
+        target_server = server_change_attributes(
+            compute_api=compute_api, target_server=target_server, wished_server=wished_server
+        )
 
     return changed, target_server
 
@@ -389,7 +383,7 @@ def absent_strategy(compute_api, wished_server):
     changed = True
 
     if compute_api.module.check_mode:
-        return changed, {"status": "Server %s would be made absent." % target_server["id"]}
+        return changed, {"status": f"Server {target_server['id']} would be made absent."}
 
     # A server MUST be stopped to be deleted.
     while fetch_state(compute_api=compute_api, server=target_server) != "stopped":
@@ -397,8 +391,7 @@ def absent_strategy(compute_api, wished_server):
         response = stop_server(compute_api=compute_api, server=target_server)
 
         if not response.ok:
-            err_msg = 'Error while stopping a server before removing it [{0}: {1}]'.format(response.status_code,
-                                                                                           response.json)
+            err_msg = f"Error while stopping a server before removing it [{response.status_code}: {response.json}]"
             compute_api.module.fail_json(msg=err_msg)
 
         wait_to_complete_state_transition(compute_api=compute_api, server=target_server, wait=True)
@@ -406,10 +399,10 @@ def absent_strategy(compute_api, wished_server):
     response = remove_server(compute_api=compute_api, server=target_server)
 
     if not response.ok:
-        err_msg = 'Error while removing server [{0}: {1}]'.format(response.status_code, response.json)
+        err_msg = f"Error while removing server [{response.status_code}: {response.json}]"
         compute_api.module.fail_json(msg=err_msg)
 
-    return changed, {"status": "Server %s deleted" % target_server["id"]}
+    return changed, {"status": f"Server {target_server['id']} deleted"}
 
 
 def running_strategy(compute_api, wished_server):
@@ -426,26 +419,29 @@ def running_strategy(compute_api, wished_server):
     else:
         target_server = query_results[0]
 
-    if server_attributes_should_be_changed(compute_api=compute_api, target_server=target_server,
-                                           wished_server=wished_server):
+    if server_attributes_should_be_changed(
+        compute_api=compute_api, target_server=target_server, wished_server=wished_server
+    ):
         changed = True
 
         if compute_api.module.check_mode:
-            return changed, {"status": "Server %s attributes would be changed before running it." % target_server["id"]}
+            return changed, {"status": f"Server {target_server['id']} attributes would be changed before running it."}
 
-        target_server = server_change_attributes(compute_api=compute_api, target_server=target_server, wished_server=wished_server)
+        target_server = server_change_attributes(
+            compute_api=compute_api, target_server=target_server, wished_server=wished_server
+        )
 
     current_state = fetch_state(compute_api=compute_api, server=target_server)
     if current_state not in ("running", "starting"):
-        compute_api.module.debug("running_strategy: Server in state: %s" % current_state)
+        compute_api.module.debug(f"running_strategy: Server in state: {current_state}")
         changed = True
 
         if compute_api.module.check_mode:
-            return changed, {"status": "Server %s attributes would be changed." % target_server["id"]}
+            return changed, {"status": f"Server {target_server['id']} attributes would be changed."}
 
         response = start_server(compute_api=compute_api, server=target_server)
         if not response.ok:
-            msg = 'Error while running server [{0}: {1}]'.format(response.status_code, response.json)
+            msg = f"Error while running server [{response.status_code}: {response.json}]"
             compute_api.module.fail_json(msg=msg)
 
     return changed, target_server
@@ -458,7 +454,6 @@ def stop_strategy(compute_api, wished_server):
     changed = False
 
     if not query_results:
-
         if compute_api.module.check_mode:
             return changed, {"status": "A server would be created before being stopped."}
 
@@ -469,33 +464,35 @@ def stop_strategy(compute_api, wished_server):
 
     compute_api.module.debug("stop_strategy: Servers are found.")
 
-    if server_attributes_should_be_changed(compute_api=compute_api, target_server=target_server,
-                                           wished_server=wished_server):
+    if server_attributes_should_be_changed(
+        compute_api=compute_api, target_server=target_server, wished_server=wished_server
+    ):
         changed = True
 
         if compute_api.module.check_mode:
-            return changed, {
-                "status": "Server %s attributes would be changed before stopping it." % target_server["id"]}
+            return changed, {"status": f"Server {target_server['id']} attributes would be changed before stopping it."}
 
-        target_server = server_change_attributes(compute_api=compute_api, target_server=target_server, wished_server=wished_server)
+        target_server = server_change_attributes(
+            compute_api=compute_api, target_server=target_server, wished_server=wished_server
+        )
 
     wait_to_complete_state_transition(compute_api=compute_api, server=target_server)
 
     current_state = fetch_state(compute_api=compute_api, server=target_server)
     if current_state not in ("stopped",):
-        compute_api.module.debug("stop_strategy: Server in state: %s" % current_state)
+        compute_api.module.debug(f"stop_strategy: Server in state: {current_state}")
 
         changed = True
 
         if compute_api.module.check_mode:
-            return changed, {"status": "Server %s would be stopped." % target_server["id"]}
+            return changed, {"status": f"Server {target_server['id']} would be stopped."}
 
         response = stop_server(compute_api=compute_api, server=target_server)
         compute_api.module.debug(response.json)
         compute_api.module.debug(response.ok)
 
         if not response.ok:
-            msg = 'Error while stopping server [{0}: {1}]'.format(response.status_code, response.json)
+            msg = f"Error while stopping server [{response.status_code}: {response.json}]"
             compute_api.module.fail_json(msg=msg)
 
     return changed, target_server
@@ -515,20 +512,21 @@ def restart_strategy(compute_api, wished_server):
     else:
         target_server = query_results[0]
 
-    if server_attributes_should_be_changed(compute_api=compute_api,
-                                           target_server=target_server,
-                                           wished_server=wished_server):
+    if server_attributes_should_be_changed(
+        compute_api=compute_api, target_server=target_server, wished_server=wished_server
+    ):
         changed = True
 
         if compute_api.module.check_mode:
-            return changed, {
-                "status": "Server %s attributes would be changed before rebooting it." % target_server["id"]}
+            return changed, {"status": f"Server {target_server['id']} attributes would be changed before rebooting it."}
 
-        target_server = server_change_attributes(compute_api=compute_api, target_server=target_server, wished_server=wished_server)
+        target_server = server_change_attributes(
+            compute_api=compute_api, target_server=target_server, wished_server=wished_server
+        )
 
     changed = True
     if compute_api.module.check_mode:
-        return changed, {"status": "Server %s would be rebooted." % target_server["id"]}
+        return changed, {"status": f"Server {target_server['id']} would be rebooted."}
 
     wait_to_complete_state_transition(compute_api=compute_api, server=target_server)
 
@@ -536,16 +534,14 @@ def restart_strategy(compute_api, wished_server):
         response = restart_server(compute_api=compute_api, server=target_server)
         wait_to_complete_state_transition(compute_api=compute_api, server=target_server)
         if not response.ok:
-            msg = 'Error while restarting server that was running [{0}: {1}].'.format(response.status_code,
-                                                                                      response.json)
+            msg = f"Error while restarting server that was running [{response.status_code}: {response.json}]."
             compute_api.module.fail_json(msg=msg)
 
     if fetch_state(compute_api=compute_api, server=target_server) in ("stopped",):
         response = restart_server(compute_api=compute_api, server=target_server)
         wait_to_complete_state_transition(compute_api=compute_api, server=target_server)
         if not response.ok:
-            msg = 'Error while restarting server that was stopped [{0}: {1}].'.format(response.status_code,
-                                                                                      response.json)
+            msg = f"Error while restarting server that was stopped [{response.status_code}: {response.json}]."
             compute_api.module.fail_json(msg=msg)
 
     return changed, target_server
@@ -556,18 +552,17 @@ state_strategy = {
     "restarted": restart_strategy,
     "stopped": stop_strategy,
     "running": running_strategy,
-    "absent": absent_strategy
+    "absent": absent_strategy,
 }
 
 
 def find(compute_api, wished_server, per_page=1):
     compute_api.module.debug("Getting inside find")
     # Only the name attribute is accepted in the Compute query API
-    response = compute_api.get("servers", params={"name": wished_server["name"],
-                                                  "per_page": per_page})
+    response = compute_api.get("servers", params={"name": wished_server["name"], "per_page": per_page})
 
     if not response.ok:
-        msg = 'Error during server search: (%s) %s' % (response.status_code, response.json)
+        msg = f"Error during server search: ({response.status_code}) {response.json}"
         compute_api.module.fail_json(msg=msg)
 
     search_results = response.json["servers"]
@@ -586,20 +581,24 @@ PATCH_MUTABLE_SERVER_ATTRIBUTES = (
 
 def server_attributes_should_be_changed(compute_api, target_server, wished_server):
     compute_api.module.debug("Checking if server attributes should be changed")
-    compute_api.module.debug("Current Server: %s" % target_server)
-    compute_api.module.debug("Wished Server: %s" % wished_server)
+    compute_api.module.debug(f"Current Server: {target_server}")
+    compute_api.module.debug(f"Wished Server: {wished_server}")
     debug_dict = {
         x: (target_server[x], wished_server[x])
         for x in PATCH_MUTABLE_SERVER_ATTRIBUTES
         if x in target_server and x in wished_server
     }
-    compute_api.module.debug("Debug dict %s" % debug_dict)
+    compute_api.module.debug(f"Debug dict {debug_dict}")
     try:
         for key in PATCH_MUTABLE_SERVER_ATTRIBUTES:
             if key in target_server and key in wished_server:
                 # When you are working with dict, only ID matter as we ask user to put only the resource ID in the playbook
-                if isinstance(target_server[key], dict) and wished_server[key] and "id" in target_server[key].keys(
-                ) and target_server[key]["id"] != wished_server[key]:
+                if (
+                    isinstance(target_server[key], dict)
+                    and wished_server[key]
+                    and "id" in target_server[key].keys()
+                    and target_server[key]["id"] != wished_server[key]
+                ):
                     return True
                 # Handling other structure compare simply the two objects content
                 elif not isinstance(target_server[key], dict) and target_server[key] != wished_server[key]:
@@ -625,16 +624,15 @@ def server_change_attributes(compute_api, target_server, wished_server):
             elif not isinstance(target_server[key], dict):
                 patch_payload[key] = wished_server[key]
 
-    response = compute_api.patch(path="servers/%s" % target_server["id"],
-                                 data=patch_payload)
+    response = compute_api.patch(path=f"servers/{target_server['id']}", data=patch_payload)
     if not response.ok:
-        msg = 'Error during server attributes patching: (%s) %s' % (response.status_code, response.json)
+        msg = f"Error during server attributes patching: ({response.status_code}) {response.json}"
         compute_api.module.fail_json(msg=msg)
 
     try:
         target_server = response.json["server"]
     except KeyError:
-        compute_api.module.fail_json(msg="Error in getting the server information from: %s" % response.json)
+        compute_api.module.fail_json(msg=f"Error in getting the server information from: {response.json}")
 
     wait_to_complete_state_transition(compute_api=compute_api, server=target_server)
 
@@ -652,9 +650,9 @@ def core(module):
         "tags": module.params["tags"],
         "organization": module.params["organization"],
         "project": module.params["project"],
-        "security_group": module.params["security_group"]
+        "security_group": module.params["security_group"],
     }
-    module.params['api_url'] = SCALEWAY_LOCATION[region]["api_endpoint"]
+    module.params["api_url"] = SCALEWAY_LOCATION[region]["api_endpoint"]
 
     compute_api = Scaleway(module=module)
 
@@ -670,35 +668,37 @@ def core(module):
 
 def main():
     argument_spec = scaleway_argument_spec()
-    argument_spec.update(dict(
-        image=dict(required=True),
-        name=dict(),
-        region=dict(required=True, choices=list(SCALEWAY_LOCATION.keys())),
-        commercial_type=dict(required=True),
-        enable_ipv6=dict(default=False, type="bool"),
-        public_ip=dict(default="absent"),
-        state=dict(choices=list(state_strategy.keys()), default='present'),
-        tags=dict(type="list", elements="str", default=[]),
-        organization=dict(),
-        project=dict(),
-        wait=dict(type="bool", default=False),
-        wait_timeout=dict(type="int", default=300),
-        wait_sleep_time=dict(type="int", default=3),
-        security_group=dict(),
-    ))
+    argument_spec.update(
+        dict(
+            image=dict(required=True),
+            name=dict(),
+            region=dict(required=True, choices=list(SCALEWAY_LOCATION.keys())),
+            commercial_type=dict(required=True),
+            enable_ipv6=dict(default=False, type="bool"),
+            public_ip=dict(default="absent"),
+            state=dict(choices=list(state_strategy.keys()), default="present"),
+            tags=dict(type="list", elements="str", default=[]),
+            organization=dict(),
+            project=dict(),
+            wait=dict(type="bool", default=False),
+            wait_timeout=dict(type="int", default=300),
+            wait_sleep_time=dict(type="int", default=3),
+            security_group=dict(),
+        )
+    )
     module = AnsibleModule(
         argument_spec=argument_spec,
         supports_check_mode=True,
         mutually_exclusive=[
-            ('organization', 'project'),
+            ("organization", "project"),
         ],
         required_one_of=[
-            ('organization', 'project'),
+            ("organization", "project"),
         ],
     )
 
     core(module)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
