@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 #
 # Scaleway Serverless container management module
 #
@@ -7,9 +6,8 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
+from __future__ import annotations
 
-__metaclass__ = type
 
 DOCUMENTATION = r"""
 module: scaleway_container
@@ -22,6 +20,7 @@ extends_documentation_fragment:
   - community.general.scaleway
   - community.general.scaleway_waitable_resource
   - community.general.attributes
+  - community.general.scaleway.actiongroup_scaleway
 requirements:
   - passlib[argon2] >= 1.7.4
 
@@ -30,6 +29,8 @@ attributes:
     support: full
   diff_mode:
     support: none
+  action_group:
+    version_added: 11.3.0
 
 options:
   state:
@@ -89,15 +90,24 @@ options:
   secret_environment_variables:
     description:
       - Secret environment variables of the container namespace.
-      - Updating those values will not output a C(changed) state in Ansible.
+      - Updating those values does not output a C(changed) state in Ansible.
       - Injected in container at runtime.
     type: dict
     default: {}
 
+  cpu_limit:
+    description:
+      - Resources define performance characteristics of your container.
+      - They are allocated to your container at runtime.
+      - Unit is 1/1000 of a VCPU.
+    type: int
+    version_added: 11.3.0
+
   memory_limit:
     description:
       - Resources define performance characteristics of your container.
       - They are allocated to your container at runtime.
+      - Unit is MB of memory.
     type: int
 
   container_timeout:
@@ -125,7 +135,7 @@ options:
   max_concurrency:
     description:
       - Maximum number of connections per container.
-      - This parameter will be used to trigger autoscaling.
+      - This parameter is used to trigger autoscaling.
     type: int
 
   protocol:
@@ -206,23 +216,23 @@ container:
 from copy import deepcopy
 
 from ansible_collections.community.general.plugins.module_utils.scaleway import (
-    SCALEWAY_REGIONS, scaleway_argument_spec, Scaleway,
-    scaleway_waitable_resource_argument_spec, resource_attributes_should_be_changed,
-    SecretVariables
+    SCALEWAY_REGIONS,
+    scaleway_argument_spec,
+    Scaleway,
+    scaleway_waitable_resource_argument_spec,
+    resource_attributes_should_be_changed,
+    SecretVariables,
 )
 from ansible.module_utils.basic import AnsibleModule
 
-STABLE_STATES = (
-    "ready",
-    "created",
-    "absent"
-)
+STABLE_STATES = ("ready", "created", "absent")
 
 MUTABLE_ATTRIBUTES = (
     "description",
     "min_scale",
     "max_scale",
     "environment_variables",
+    "cpu_limit",
     "memory_limit",
     "timeout",
     "privacy",
@@ -230,7 +240,7 @@ MUTABLE_ATTRIBUTES = (
     "max_concurrency",
     "protocol",
     "port",
-    "secret_environment_variables"
+    "secret_environment_variables",
 )
 
 
@@ -243,6 +253,7 @@ def payload_from_wished_cn(wished_cn):
         "max_scale": wished_cn["max_scale"],
         "environment_variables": wished_cn["environment_variables"],
         "secret_environment_variables": SecretVariables.dict_to_list(wished_cn["secret_environment_variables"]),
+        "cpu_limit": wished_cn["cpu_limit"],
         "memory_limit": wished_cn["memory_limit"],
         "timeout": wished_cn["timeout"],
         "privacy": wished_cn["privacy"],
@@ -250,7 +261,7 @@ def payload_from_wished_cn(wished_cn):
         "max_concurrency": wished_cn["max_concurrency"],
         "protocol": wished_cn["protocol"],
         "port": wished_cn["port"],
-        "redeploy": wished_cn["redeploy"]
+        "redeploy": wished_cn["redeploy"],
     }
 
     return payload
@@ -271,10 +282,9 @@ def absent_strategy(api, wished_cn):
         return changed, {"status": "Container would be destroyed"}
 
     api.wait_to_complete_state_transition(resource=target_cn, stable_states=STABLE_STATES, force_wait=True)
-    response = api.delete(path=api.api_path + "/%s" % target_cn["id"])
+    response = api.delete(path=f"{api.api_path}/{target_cn['id']}")
     if not response.ok:
-        api.module.fail_json(msg='Error deleting container [{0}: {1}]'.format(
-            response.status_code, response.json))
+        api.module.fail_json(msg=f"Error deleting container [{response.status_code}: {response.json}]")
 
     api.wait_to_complete_state_transition(resource=target_cn, stable_states=STABLE_STATES)
     return changed, response.json
@@ -298,27 +308,27 @@ def present_strategy(api, wished_cn):
 
         # Create container
         api.warn(payload_cn)
-        creation_response = api.post(path=api.api_path,
-                                     data=payload_cn)
+        creation_response = api.post(path=api.api_path, data=payload_cn)
 
         if not creation_response.ok:
-            msg = "Error during container creation: %s: '%s' (%s)" % (creation_response.info['msg'],
-                                                                      creation_response.json['message'],
-                                                                      creation_response.json)
+            msg = f"Error during container creation: {creation_response.info['msg']}: '{creation_response.json['message']}' ({creation_response.json})"
             api.module.fail_json(msg=msg)
 
         api.wait_to_complete_state_transition(resource=creation_response.json, stable_states=STABLE_STATES)
-        response = api.get(path=api.api_path + "/%s" % creation_response.json["id"])
+        response = api.get(path=f"{api.api_path}/{creation_response.json['id']}")
         return changed, response.json
 
     target_cn = cn_lookup[wished_cn["name"]]
     decoded_target_cn = deepcopy(target_cn)
-    decoded_target_cn["secret_environment_variables"] = SecretVariables.decode(decoded_target_cn["secret_environment_variables"],
-                                                                               payload_cn["secret_environment_variables"])
-    patch_payload = resource_attributes_should_be_changed(target=decoded_target_cn,
-                                                          wished=payload_cn,
-                                                          verifiable_mutable_attributes=MUTABLE_ATTRIBUTES,
-                                                          mutable_attributes=MUTABLE_ATTRIBUTES)
+    decoded_target_cn["secret_environment_variables"] = SecretVariables.decode(
+        decoded_target_cn["secret_environment_variables"], payload_cn["secret_environment_variables"]
+    )
+    patch_payload = resource_attributes_should_be_changed(
+        target=decoded_target_cn,
+        wished=payload_cn,
+        verifiable_mutable_attributes=MUTABLE_ATTRIBUTES,
+        mutable_attributes=MUTABLE_ATTRIBUTES,
+    )
 
     if not patch_payload:
         return changed, target_cn
@@ -327,22 +337,19 @@ def present_strategy(api, wished_cn):
     if api.module.check_mode:
         return changed, {"status": "Container attributes would be changed."}
 
-    cn_patch_response = api.patch(path=api.api_path + "/%s" % target_cn["id"],
-                                  data=patch_payload)
+    cn_patch_response = api.patch(path=f"{api.api_path}/{target_cn['id']}", data=patch_payload)
 
     if not cn_patch_response.ok:
-        api.module.fail_json(msg='Error during container attributes update: [{0}: {1}]'.format(
-            cn_patch_response.status_code, cn_patch_response.json['message']))
+        api.module.fail_json(
+            msg=f"Error during container attributes update: [{cn_patch_response.status_code}: {cn_patch_response.json['message']}]"
+        )
 
     api.wait_to_complete_state_transition(resource=target_cn, stable_states=STABLE_STATES)
-    response = api.get(path=api.api_path + "/%s" % target_cn["id"])
+    response = api.get(path=f"{api.api_path}/{target_cn['id']}")
     return changed, response.json
 
 
-state_strategy = {
-    "present": present_strategy,
-    "absent": absent_strategy
-}
+state_strategy = {"present": present_strategy, "absent": absent_strategy}
 
 
 def core(module):
@@ -353,11 +360,12 @@ def core(module):
         "state": module.params["state"],
         "namespace_id": module.params["namespace_id"],
         "name": module.params["name"],
-        "description": module.params['description'],
+        "description": module.params["description"],
         "min_scale": module.params["min_scale"],
         "max_scale": module.params["max_scale"],
-        "environment_variables": module.params['environment_variables'],
-        "secret_environment_variables": module.params['secret_environment_variables'],
+        "environment_variables": module.params["environment_variables"],
+        "secret_environment_variables": module.params["secret_environment_variables"],
+        "cpu_limit": module.params["cpu_limit"],
         "memory_limit": module.params["memory_limit"],
         "timeout": module.params["container_timeout"],
         "privacy": module.params["privacy"],
@@ -365,11 +373,11 @@ def core(module):
         "max_concurrency": module.params["max_concurrency"],
         "protocol": module.params["protocol"],
         "port": module.params["port"],
-        "redeploy": module.params["redeploy"]
+        "redeploy": module.params["redeploy"],
     }
 
     api = Scaleway(module=module)
-    api.api_path = "containers/v1beta1/regions/%s/containers" % region
+    api.api_path = f"containers/v1beta1/regions/{region}/containers"
 
     changed, summary = state_strategy[wished_container["state"]](api=api, wished_cn=wished_container)
 
@@ -379,25 +387,28 @@ def core(module):
 def main():
     argument_spec = scaleway_argument_spec()
     argument_spec.update(scaleway_waitable_resource_argument_spec())
-    argument_spec.update(dict(
-        state=dict(type='str', default='present', choices=['absent', 'present']),
-        namespace_id=dict(type='str', required=True),
-        region=dict(type='str', required=True, choices=SCALEWAY_REGIONS),
-        name=dict(type='str', required=True),
-        description=dict(type='str', default=''),
-        min_scale=dict(type='int'),
-        max_scale=dict(type='int'),
-        memory_limit=dict(type='int'),
-        container_timeout=dict(type='str'),
-        privacy=dict(type='str', default='public', choices=['public', 'private']),
-        registry_image=dict(type='str', required=True),
-        max_concurrency=dict(type='int'),
-        protocol=dict(type='str', default='http1', choices=['http1', 'h2c']),
-        port=dict(type='int'),
-        redeploy=dict(type='bool', default=False),
-        environment_variables=dict(type='dict', default={}),
-        secret_environment_variables=dict(type='dict', default={}, no_log=True)
-    ))
+    argument_spec.update(
+        dict(
+            state=dict(type="str", default="present", choices=["absent", "present"]),
+            namespace_id=dict(type="str", required=True),
+            region=dict(type="str", required=True, choices=SCALEWAY_REGIONS),
+            name=dict(type="str", required=True),
+            description=dict(type="str", default=""),
+            min_scale=dict(type="int"),
+            max_scale=dict(type="int"),
+            cpu_limit=dict(type="int"),
+            memory_limit=dict(type="int"),
+            container_timeout=dict(type="str"),
+            privacy=dict(type="str", default="public", choices=["public", "private"]),
+            registry_image=dict(type="str", required=True),
+            max_concurrency=dict(type="int"),
+            protocol=dict(type="str", default="http1", choices=["http1", "h2c"]),
+            port=dict(type="int"),
+            redeploy=dict(type="bool", default=False),
+            environment_variables=dict(type="dict", default={}),
+            secret_environment_variables=dict(type="dict", default={}, no_log=True),
+        )
+    )
     module = AnsibleModule(
         argument_spec=argument_spec,
         supports_check_mode=True,
@@ -406,5 +417,5 @@ def main():
     core(module)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
