@@ -2,10 +2,9 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
-DOCUMENTATION = '''
+DOCUMENTATION = """
 name: ansible_type
 short_description: Validate input type
 version_added: "9.2.0"
@@ -24,9 +23,9 @@ options:
     description: Data type aliases.
     default: {}
     type: dictionary
-'''
+"""
 
-EXAMPLES = '''
+EXAMPLES = """
 # Substitution converts str to AnsibleUnicode or _AnsibleTaggedStr
 # ----------------------------------------------------------------
 
@@ -215,13 +214,13 @@ dtype: number
 data: 123.45
 result: '{{ data is community.general.ansible_type(dtype, alias) }}'
 # result => true
-'''
+"""
 
-RETURN = '''
+RETURN = """
 _value:
   description: Whether the data type is valid.
   type: bool
-'''
+"""
 
 from collections.abc import Sequence
 
@@ -245,9 +244,6 @@ def ansible_type(data, dtype, alias=None):
     return _ansible_type(data, alias) in data_types
 
 
-class TestModule(object):
-
+class TestModule:
     def tests(self):
-        return {
-            'ansible_type': ansible_type
-        }
+        return {"ansible_type": ansible_type}
