@@ -17,13 +17,10 @@ description:
   ("cluster" in PostgreSQL terminology) and, optionally,
   grants the user access to an existing database or tables.
 - A user is a role with login privilege.
-- You can also use it to grant or revoke user's privileges in a particular database.
 - You cannot remove a user while it still has any privileges granted to it in any database.
 - Set I(fail_on_user) to C(false) to make the module ignore failures when trying to remove a user.
   In this case, the module reports if changes happened as usual and separately reports
   whether the user has been removed or not.
-- B(WARNING) The I(priv) option has been B(deprecated) and will be removed in community.postgresql 4.0.0. Please use the
-  M(community.postgresql.postgresql_privs) module instead.
 options:
   name:
     description:
@@ -49,6 +46,7 @@ options:
   login_db:
     description:
     - Name of database to connect to and where user's permissions are granted.
+    - The V(db) alias is deprecated and will be removed in version 5.0.0.
     type: str
     default: ''
     aliases:
@@ -60,22 +58,6 @@ options:
     type: bool
     aliases:
     - fail_on_role
-  priv:
-    description:
-    - This option has been B(deprecated) and will be removed in
-      community.postgresql 4.0.0. Please use the M(community.postgresql.postgresql_privs) module to
-      GRANT/REVOKE permissions instead.
-    - "Slash-separated PostgreSQL privileges string: C(priv1/priv2), where
-      you can define the user's privileges for the database ( allowed options - 'CREATE',
-      'CONNECT', 'TEMPORARY', 'TEMP', 'ALL'. For example C(CONNECT) ) or
-      for table ( allowed options - 'SELECT', 'INSERT', 'UPDATE', 'DELETE',
-      'TRUNCATE', 'REFERENCES', 'TRIGGER', 'ALL'. For example
-      C(table:SELECT) ). Mixed example of this string:
-      C(CONNECT/CREATE/table1:SELECT/table2:INSERT)."
-    - When I(priv) contains tables, the module uses the schema C(public) by default.
-      If you need to specify a different schema, use the C(schema_name.table_name) notation,
-      for example, C(pg_catalog.pg_stat_database:SELECT).
-    type: str
   role_attr_flags:
     description:
     - "PostgreSQL user attributes string in the format: CREATEDB,CREATEROLE,SUPERUSER."
@@ -148,7 +130,7 @@ options:
     version_added: '0.2.0'
   trust_input:
     description:
-    - If C(false), checks whether values of options I(name), I(password), I(privs), I(expires),
+    - If C(false), checks whether values of options I(name), I(password), I(expires),
       I(role_attr_flags), I(comment), I(session_role) are potentially dangerous.
     - It makes sense to use C(false) only when SQL injections through the options are possible.
     type: bool
@@ -228,14 +210,11 @@ extends_documentation_fragment:
 '''
 
 EXAMPLES = r'''
-# This example uses the 'priv' argument which is deprecated.
-# You should use the 'postgresql_privs' module instead.
-- name: Connect to acme database, create django user, and grant access to database and products table
+- name: Connect to acme database, create django user
   community.postgresql.postgresql_user:
     login_db: acme
     name: django
     password: ceec4eif7ya
-    priv: "CONNECT/products:ALL"
     expires: "Jan 31 2020"
 
 - name: Add a comment on django user
@@ -245,9 +224,10 @@ EXAMPLES = r'''
     comment: This is a test user
 
 # Connect to default database, create rails user, set its password (MD5- or SHA256-hashed),
-# and grant privilege to create other databases and demote rails from super user status if user exists
+# and set flags to allow the user to create databases
+# and demote rails from super user status if user exists
 # the hash from the corresponding pg_authid entry.
-- name: Create rails user, set MD5-hashed password, grant privs
+- name: Create rails user, set MD5-hashed password, set flags
   community.postgresql.postgresql_user:
     name: rails
     password: md59543f1d82624df2b31672ec0f7050460
@@ -257,38 +237,19 @@ EXAMPLES = r'''
   # environment:
   #   PGOPTIONS: "-c password_encryption=scram-sha-256"
 
-# This example uses the 'priv' argument which is deprecated.
-# You should use the 'postgresql_privs' module instead.
-- name: Connect to acme database and remove test user privileges from there
-  community.postgresql.postgresql_user:
-    login_db: acme
-    name: test
-    priv: "ALL/products:ALL"
-    state: absent
-    fail_on_user: false
-
-# This example uses the 'priv' argument which is deprecated.
-# You should use the 'postgresql_privs' module instead.
 - name: Connect to test database, remove test user from cluster
   community.postgresql.postgresql_user:
     login_db: test
     name: test
-    priv: ALL
     state: absent
 
-# This example uses the 'priv' argument which is deprecated.
-# You should use the 'postgresql_privs' module instead.
 - name: Connect to acme database and set user's password with no expire date
   community.postgresql.postgresql_user:
     login_db: acme
     name: django
     password: mysupersecretword
-    priv: "CONNECT/products:ALL"
     expires: infinity
 
-# Example privileges string format
-# INSERT,UPDATE/table:SELECT/anothertable:ALL
-
 - name: Connect to test database and remove an existing user's password
   community.postgresql.postgresql_user:
     login_db: test
@@ -304,13 +265,6 @@ EXAMPLES = r'''
   environment:
     PGOPTIONS: "-c password_encryption=scram-sha-256"
 
-# This example uses the 'priv' argument which is deprecated.
-# You should use the 'postgresql_privs' module instead.
-- name: Create a user, grant SELECT on pg_catalog.pg_stat_database
-  community.postgresql.postgresql_user:
-    name: monitoring
-    priv: 'pg_catalog.pg_stat_database:SELECT'
-
 # Create a user and set a default-configuration that is active when they start a session
 - name: Create a user with config-parameter
   community.postgresql.postgresql_user:
@@ -353,7 +307,6 @@ from hashlib import md5, sha256
 
 from ansible.module_utils._text import to_bytes, to_native, to_text
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils.six import iteritems
 from ansible_collections.community.postgresql.plugins.module_utils import \
     saslprep
 from ansible_collections.community.postgresql.plugins.module_utils.database import (
@@ -395,12 +348,6 @@ FLAGS_BY_VERSION = {'BYPASSRLS': 90500}
 
 SCRAM_SHA256_REGEX = r'^SCRAM-SHA-256\$(\d+):([A-Za-z0-9+\/=]+)\$([A-Za-z0-9+\/=]+):([A-Za-z0-9+\/=]+)$'
 
-# WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-VALID_PRIVS = dict(table=frozenset(('SELECT', 'INSERT', 'UPDATE', 'DELETE', 'TRUNCATE', 'REFERENCES', 'TRIGGER', 'ALL')),
-                   database=frozenset(
-                       ('CREATE', 'CONNECT', 'TEMPORARY', 'TEMP', 'ALL')),
-                   )
-
 # map to cope with idiosyncrasies of SUPERUSER and LOGIN
 PRIV_TO_AUTHID_COLUMN = dict(SUPERUSER='rolsuper', CREATEROLE='rolcreaterole',
                              CREATEDB='rolcreatedb', INHERIT='rolinherit', LOGIN='rolcanlogin',
@@ -743,176 +690,13 @@ def user_delete(cursor, user, module):
         query = 'DROP USER %s' % _pg_quote_user(user, module)
         executed_queries.append(query)
         cursor.execute(query)
-    except Exception:
+    except Exception as e:
         cursor.execute("ROLLBACK TO SAVEPOINT ansible_pgsql_user_delete")
         cursor.execute("RELEASE SAVEPOINT ansible_pgsql_user_delete")
-        return False
+        return False, e
 
     cursor.execute("RELEASE SAVEPOINT ansible_pgsql_user_delete")
-    return True
-
-
-# WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-def has_table_privileges(cursor, user, table, privs):
-    """
-    Return the difference between the privileges that a user already has and
-    the privileges that they desire to have.
-
-    :returns: tuple of:
-        * privileges that they have and were requested
-        * privileges they currently hold but were not requested
-        * privileges requested that they do not hold
-    """
-    cur_privs = get_table_privileges(cursor, user, table)
-    have_currently = cur_privs.intersection(privs)
-    other_current = cur_privs.difference(privs)
-    desired = privs.difference(cur_privs)
-    return (have_currently, other_current, desired)
-
-
-# WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-def get_table_privileges(cursor, user, table):
-    if '.' in table:
-        schema, table = table.split('.', 1)
-    else:
-        schema = 'public'
-    query = ("SELECT privilege_type FROM information_schema.role_table_grants "
-             "WHERE grantee=%(user)s AND table_name=%(table)s AND table_schema=%(schema)s")
-    cursor.execute(query, {'user': user, 'table': table, 'schema': schema})
-    return frozenset([x["privilege_type"] for x in cursor.fetchall()])
-
-
-# WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-def grant_table_privileges(cursor, user, table, privs):
-    # Note: priv escaped by parse_privs
-    privs = ', '.join(privs)
-    query = 'GRANT %s ON TABLE %s TO "%s"' % (
-        privs, pg_quote_identifier(table, 'table'), user)
-    executed_queries.append(query)
-    cursor.execute(query)
-
-
-# WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-def revoke_table_privileges(cursor, user, table, privs):
-    # Note: priv escaped by parse_privs
-    privs = ', '.join(privs)
-    query = 'REVOKE %s ON TABLE %s FROM "%s"' % (
-        privs, pg_quote_identifier(table, 'table'), user)
-    executed_queries.append(query)
-    cursor.execute(query)
-
-
-# WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-def get_database_privileges(cursor, user, db):
-    priv_map = {
-        'C': 'CREATE',
-        'T': 'TEMPORARY',
-        'c': 'CONNECT',
-    }
-    query = 'SELECT datacl::text FROM pg_database WHERE datname = %s'
-    cursor.execute(query, (db,))
-    datacl = cursor.fetchone()["datacl"]
-    if datacl is None:
-        return set()
-    r = re.search(r'%s\\?"?=(C?T?c?)/[^,]+,?' % user, datacl)
-    if r is None:
-        return set()
-    o = set()
-    for v in r.group(1):
-        o.add(priv_map[v])
-    return normalize_privileges(o, 'database')
-
-
-# WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-def has_database_privileges(cursor, user, db, privs):
-    """
-    Return the difference between the privileges that a user already has and
-    the privileges that they desire to have.
-
-    :returns: tuple of:
-        * privileges that they have and were requested
-        * privileges they currently hold but were not requested
-        * privileges requested that they do not hold
-    """
-    cur_privs = get_database_privileges(cursor, user, db)
-    have_currently = cur_privs.intersection(privs)
-    other_current = cur_privs.difference(privs)
-    desired = privs.difference(cur_privs)
-    return (have_currently, other_current, desired)
-
-
-# WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-def grant_database_privileges(cursor, user, db, privs):
-    # Note: priv escaped by parse_privs
-    privs = ', '.join(privs)
-    if user == "PUBLIC":
-        query = 'GRANT %s ON DATABASE %s TO PUBLIC' % (
-                privs, pg_quote_identifier(db, 'database'))
-    else:
-        query = 'GRANT %s ON DATABASE %s TO "%s"' % (
-                privs, pg_quote_identifier(db, 'database'), user)
-
-    executed_queries.append(query)
-    cursor.execute(query)
-
-
-# WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-def revoke_database_privileges(cursor, user, db, privs):
-    # Note: priv escaped by parse_privs
-    privs = ', '.join(privs)
-    if user == "PUBLIC":
-        query = 'REVOKE %s ON DATABASE %s FROM PUBLIC' % (
-                privs, pg_quote_identifier(db, 'database'))
-    else:
-        query = 'REVOKE %s ON DATABASE %s FROM "%s"' % (
-                privs, pg_quote_identifier(db, 'database'), user)
-
-    executed_queries.append(query)
-    cursor.execute(query)
-
-
-# WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-def revoke_privileges(cursor, user, privs):
-    if privs is None:
-        return False
-
-    revoke_funcs = dict(table=revoke_table_privileges,
-                        database=revoke_database_privileges)
-    check_funcs = dict(table=has_table_privileges,
-                       database=has_database_privileges)
-
-    changed = False
-    for type_ in privs:
-        for name, privileges in iteritems(privs[type_]):
-            # Check that any of the privileges requested to be removed are
-            # currently granted to the user
-            differences = check_funcs[type_](cursor, user, name, privileges)
-            if differences[0]:
-                revoke_funcs[type_](cursor, user, name, privileges)
-                changed = True
-    return changed
-
-
-# WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-def grant_privileges(cursor, user, privs):
-    if privs is None:
-        return False
-
-    grant_funcs = dict(table=grant_table_privileges,
-                       database=grant_database_privileges)
-    check_funcs = dict(table=has_table_privileges,
-                       database=has_database_privileges)
-
-    changed = False
-    for type_ in privs:
-        for name, privileges in iteritems(privs[type_]):
-            # Check that any of the privileges requested for the user are
-            # currently missing
-            differences = check_funcs[type_](cursor, user, name, privileges)
-            if differences[2]:
-                grant_funcs[type_](cursor, user, name, privileges)
-                changed = True
-    return changed
+    return True, None
 
 
 def parse_role_attrs(role_attr_flags, srv_version):
@@ -945,61 +729,6 @@ def parse_role_attrs(role_attr_flags, srv_version):
     return ' '.join(flags)
 
 
-# WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-def normalize_privileges(privs, type_):
-    new_privs = set(privs)
-    if 'ALL' in new_privs:
-        new_privs.update(VALID_PRIVS[type_])
-        new_privs.remove('ALL')
-    if 'TEMP' in new_privs:
-        new_privs.add('TEMPORARY')
-        new_privs.remove('TEMP')
-
-    return new_privs
-
-
-# WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-def parse_privs(privs, db):
-    """
-    Parse privilege string to determine permissions for database db.
-    Format:
-
-        privileges[/privileges/...]
-
-    Where:
-
-        privileges := DATABASE_PRIVILEGES[,DATABASE_PRIVILEGES,...] |
-            TABLE_NAME:TABLE_PRIVILEGES[,TABLE_PRIVILEGES,...]
-    """
-    if privs is None:
-        return privs
-
-    o_privs = {
-        'database': {},
-        'table': {}
-    }
-    for token in privs.split('/'):
-        if ':' not in token:
-            type_ = 'database'
-            name = db
-            priv_set = frozenset(x.strip().upper()
-                                 for x in token.split(',') if x.strip())
-        else:
-            type_ = 'table'
-            name, privileges = token.split(':', 1)
-            priv_set = frozenset(x.strip().upper()
-                                 for x in privileges.split(',') if x.strip())
-
-        if not priv_set.issubset(VALID_PRIVS[type_]):
-            raise InvalidPrivsError('Invalid privs specified for %s: %s' %
-                                    (type_, ' '.join(priv_set.difference(VALID_PRIVS[type_]))))
-
-        priv_set = normalize_privileges(priv_set, type_)
-        o_privs[type_][name] = priv_set
-
-    return o_privs
-
-
 def get_valid_flags_by_version(srv_version):
     """
     Some role attributes were introduced after certain versions. We want to
@@ -1118,11 +847,10 @@ def main():
         user=dict(type='str', required=True, aliases=['name']),
         password=dict(type='str', default=None, no_log=True),
         state=dict(type='str', default='present', choices=['absent', 'present']),
-        priv=dict(type='str', default=None, removed_in_version='4.0.0', removed_from_collection='community.postgreql'),
         login_db=dict(type='str', default="", aliases=['db'], deprecated_aliases=[
             {
                 'name': 'db',
-                'version': '4.0.0',
+                'version': '5.0.0',
                 'collection_name': 'community.postgresql',
             }],
         ),
@@ -1148,11 +876,6 @@ def main():
     password = module.params["password"]
     state = module.params["state"]
     fail_on_user = module.params["fail_on_user"]
-    # WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-    if module.params['login_db'] == '' and module.params["priv"] is not None:
-        module.fail_json(msg="privileges require a database to be specified")
-    # WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-    privs = parse_privs(module.params["priv"], module.params["login_db"])
     no_password_changes = module.params["no_password_changes"]
     if module.params["encrypted"]:
         encrypted = "ENCRYPTED"
@@ -1170,7 +893,7 @@ def main():
     trust_input = module.params['trust_input']
     if not trust_input:
         # Check input for potentially dangerous elements:
-        check_input(module, user, password, privs, expires,
+        check_input(module, user, password, expires,
                     role_attr_flags, comment, session_role, comment, configuration)
 
     # Ensure psycopg libraries are available before connecting to DB:
@@ -1195,7 +918,6 @@ def main():
 
     kw = dict(user=user)
     changed = False
-    user_removed = False
 
     if state == "present":
         if user_exists(cursor, user):
@@ -1214,11 +936,6 @@ def main():
                                  exception=traceback.format_exc())
             except SQLParseError as e:
                 module.fail_json(msg=to_native(e), exception=traceback.format_exc())
-        # WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
-        try:
-            changed = grant_privileges(cursor, user, privs) or changed
-        except SQLParseError as e:
-            module.fail_json(msg=to_native(e), exception=traceback.format_exc())
 
         if comment is not None:
             try:
@@ -1237,17 +954,15 @@ def main():
                 changed = True
                 kw['user_removed'] = True
             else:
-                # WARNING: privs are deprecated and will  be removed in community.postgresql 4.0.0
                 try:
-                    changed = revoke_privileges(cursor, user, privs)
-                    user_removed = user_delete(cursor, user, module)
+                    changed, err = user_delete(cursor, user, module)
                 except SQLParseError as e:
                     module.fail_json(msg=to_native(e), exception=traceback.format_exc())
-                changed = changed or user_removed
-                if fail_on_user and not user_removed:
-                    msg = "Unable to remove user"
+
+                if fail_on_user and not changed:
+                    msg = "Unable to remove user: %s" % err
                     module.fail_json(msg=msg)
-                kw['user_removed'] = user_removed
+                kw['user_removed'] = changed
 
     if module.check_mode:
         db_connection.rollback()
