@@ -19,7 +19,7 @@ options:
     description:
       - Name of the user connecting to the mysqld or ProxySQL instance.
     type: str
-    required: True
+    required: true
   password:
     description:
       - Password of the user connecting to the mysqld or ProxySQL instance.
@@ -28,14 +28,21 @@ options:
     description:
       - Encrypt a cleartext password passed in the I(password) option, using
         the method defined in I(encryption_method).
-    default: False
+    default: false
     type: bool
   encryption_method:
     description:
       - Encryption method used when I(encrypt_password) is set to C(True).
     type: str
-    choices: [ "mysql_native_password" ]
+    choices: [ "mysql_native_password", "caching_sha2_password" ]
     default: mysql_native_password
+  salt:
+    description:
+      - Salt used when I(encryption_method) is set to C(caching_sha2_password).
+        If omitted the I(salt) is a randomly generated string and will change
+        value in ProxySQL database on each execution.
+    type: str
+    version_added: 1.7.0
   active:
     description:
       - A user with I(active) set to C(False) will be tracked in the database,
@@ -78,13 +85,13 @@ options:
     description:
       -  If I(backend) is set to C(True), this (username, password) pair is
          used for authenticating to the ProxySQL instance.
-    default: True
+    default: true
     type: bool
   frontend:
     description:
       - If I(frontend) is set to C(True), this (username, password) pair is
         used for authenticating to the mysqld servers against any hostgroup.
-    default: True
+    default: true
     type: bool
   max_connections:
     description:
@@ -119,8 +126,9 @@ EXAMPLES = '''
     login_user: 'admin'
     login_password: 'admin'
     username: 'productiondba'
+    salt: 'secrets_of_20_chars_'
     state: present
-    load_to_runtime: False
+    load_to_runtime: false
 
 # This example removes a user, saves the mysql user config to disk, and
 # dynamically loads the mysql user config to runtime.  It uses credentials
@@ -166,8 +174,9 @@ from ansible_collections.community.proxysql.plugins.module_utils.mysql import (
     proxysql_common_argument_spec,
     save_config_to_disk,
     load_config_to_runtime,
+    mysql_sha256_password_hash,
+    generate_random_salt,
 )
-from ansible.module_utils.six import iteritems
 from ansible.module_utils._text import to_native, to_bytes
 from hashlib import sha1
 
@@ -176,18 +185,27 @@ from hashlib import sha1
 #
 
 
-def _mysql_native_password(cleartext_password):
+def _mysql_native_password(cleartext_password, salt=None):
     mysql_native_encrypted_password = "*" + sha1(sha1(to_bytes(cleartext_password)).digest()).hexdigest().upper()
     return mysql_native_encrypted_password
 
 
-def encrypt_cleartext_password(password_to_encrypt, encryption_method):
-    encrypted_password = encryption_method(password_to_encrypt)
+def _caching_sha2_password(cleartext_password, salt):
+    if salt is None:
+        salt = generate_random_salt()
+
+    mysql_caching_sha2_password = mysql_sha256_password_hash(password=cleartext_password, salt=salt)
+    return mysql_caching_sha2_password
+
+
+def encrypt_cleartext_password(password_to_encrypt, encryption_method, salt):
+    encrypted_password = encryption_method(password_to_encrypt, salt)
     return encrypted_password
 
 
 encryption_method_map = {
-    'mysql_native_password': _mysql_native_password
+    'mysql_native_password': _mysql_native_password,
+    'caching_sha2_password': _caching_sha2_password
 }
 
 
@@ -201,6 +219,7 @@ class ProxySQLUser(object):
         self.username = module.params["username"]
         self.backend = module.params["backend"]
         self.frontend = module.params["frontend"]
+        self.salt = module.params["salt"]
 
         config_data_keys = ["password",
                             "active",
@@ -209,14 +228,16 @@ class ProxySQLUser(object):
                             "default_schema",
                             "transaction_persistent",
                             "fast_forward",
-                            "max_connections"]
+                            "max_connections"
+                            ]
 
         self.config_data = dict((k, module.params[k])
                                 for k in config_data_keys)
 
         if module.params["password"] is not None and module.params["encrypt_password"]:
             encryption_method = encryption_method_map[module.params["encryption_method"]]
-            encrypted_password = encrypt_cleartext_password(module.params["password"], encryption_method)
+            salt = module.params["salt"]
+            encrypted_password = encrypt_cleartext_password(module.params["password"], encryption_method, salt)
             self.config_data["password"] = encrypted_password
 
     def check_user_config_exists(self, cursor):
@@ -249,7 +270,7 @@ class ProxySQLUser(object):
              self.backend,
              self.frontend]
 
-        for col, val in iteritems(self.config_data):
+        for col, val in self.config_data.items():
             if val is not None:
                 query_data.append(val)
                 query_string += "\n  AND " + col + " = %s"
@@ -288,7 +309,7 @@ class ProxySQLUser(object):
              self.backend,
              self.frontend]
 
-        for col, val in iteritems(self.config_data):
+        for col, val in self.config_data.items():
             if val is not None:
                 cols += 1
                 query_data.append(val)
@@ -311,7 +332,7 @@ class ProxySQLUser(object):
         cols = 0
         query_data = []
 
-        for col, val in iteritems(self.config_data):
+        for col, val in self.config_data.items():
             if val is not None:
                 cols += 1
                 query_data.append(val)
@@ -408,6 +429,7 @@ def main():
     argument_spec.update(
         username=dict(required=True, type='str'),
         password=dict(no_log=True, type='str'),
+        salt=dict(no_log=True, type='str'),
         encrypt_password=dict(default=False, type='bool', no_log=False),
         encryption_method=dict(default='mysql_native_password', choices=list(encryption_method_map.keys())),
         active=dict(type='bool'),
