@@ -148,6 +148,11 @@ DOCUMENTATION = r"""
           required: false
           env:
             - name: VMWARE_PROXY_PORT
+        enable_backward_compatibility:
+          description:
+          - Flatten the host properties for backward compatibility.
+          type: bool
+          default: true
 """
 
 EXAMPLES = r"""
@@ -197,9 +202,8 @@ except ImportError:
     pass
 
 from ansible.errors import AnsibleError
-from ansible.module_utils._text import to_text, to_native
+from ansible.module_utils.common.text.converters import to_text, to_native
 from ansible.module_utils.common.dict_transformations import camel_dict_to_snake_dict
-from ansible.module_utils.six import text_type
 from ansible_collections.community.vmware.plugins.plugin_utils.inventory import (
     to_nested_dict,
     to_flatten_dict,
@@ -498,7 +502,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         if with_path:
             parents = host_properties["path"].split("/")
             if parents:
-                if isinstance(with_path, text_type):
+                if isinstance(with_path, str):
                     parents = [with_path] + parents
 
                 c_name = self._sanitize_group_name("/".join(parents))
@@ -527,7 +531,9 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
                 self.inventory.set_variable(host, k, v)
 
         # For backward compatability
-        host_properties = to_flatten_dict(host_properties)
-        for k, v in host_properties.items():
-            k = self._sanitize_group_name(k) if can_sanitize else k
-            self.inventory.set_variable(host, k, v)
+        backward_compatibility = self.get_option("enable_backward_compatibility")
+        if backward_compatibility:
+            host_properties = to_flatten_dict(host_properties)
+            for k, v in host_properties.items():
+                k = self._sanitize_group_name(k) if can_sanitize else k
+                self.inventory.set_variable(host, k, v)
