@@ -26,7 +26,7 @@ options:
       - The I(search_string) is a string to be specified searching.
       - Specify the domain user or group name to be searched.
     type: str
-    required: True
+    required: true
   belongs_to_group:
     description:
       -  If a group existing, returned contains only users or groups that directly belong to the specified group.
@@ -37,21 +37,21 @@ options:
     type: str
   exact_match:
     description:
-      - If I(exact_match) is C(True), it indicates the I(search_string) passed should match a user or group name exactly.
+      - If V(true), it indicates the O(search_string) passed should match a user or group name exactly.
     type: bool
-    default: False
+    default: false
   find_users:
     description:
-      - If I(find_users) is C(True), domain users will be included in the result.
+      - If V(true), domain users will be included in the result.
     type: bool
-    default: True
+    default: true
   find_groups:
     description:
-      - If I(find_groups) is C(True), domain groups will be included in the result.
+      - If V(true), domain groups will be included in the result.
     type: bool
-    default: True
+    default: true
 extends_documentation_fragment:
-  - community.vmware.vmware.documentation
+  - vmware.vmware.base_options
 '''
 
 EXAMPLES = r'''
@@ -120,8 +120,9 @@ except ImportError:
     pass
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_native
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, vmware_argument_spec
+from ansible.module_utils.common.text.converters import to_native
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 
 
 class VcenterDomainUserGroupInfo(PyVmomi):
@@ -169,7 +170,7 @@ class VcenterDomainUserGroupInfo(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         domain=dict(type='str', default='vsphere.local'),
         search_string=dict(type='str', required=True),
