@@ -66,7 +66,7 @@ options:
     choices: [ present, absent ]
     type: str
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
 '''
 
@@ -140,8 +140,9 @@ except ImportError:
     pass
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.vmware.plugins.module_utils.vmware import vmware_argument_spec, PyVmomi, find_datacenter_by_name, wait_for_task, get_all_objs
-from ansible.module_utils._text import to_native
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, find_datacenter_by_name, wait_for_task, get_all_objs
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
+from ansible.module_utils.common.text.converters import to_native
 
 
 class VmwareFolderManager(PyVmomi):
@@ -333,7 +334,7 @@ class VmwareFolderManager(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         datacenter=dict(type='str', required=True, aliases=['datacenter_name']),
         folder_name=dict(type='str', required=True),
