@@ -201,7 +201,7 @@ options:
       default: 'warning'
       choices: [ 'disabled', 'warning', 'restartAggressive' ]
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
 '''
 
@@ -259,7 +259,7 @@ from ansible_collections.community.vmware.plugins.module_utils.vmware import (
     wait_for_task,
     option_diff,
 )
-from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 from ansible.module_utils.common.text.converters import to_native
 
 
