@@ -10,7 +10,7 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-DOCUMENTATION = r'''
+DOCUMENTATION = r"""
 ---
 module: vmware_dvs_portgroup
 short_description: Create or remove a Distributed vSwitch portgroup.
@@ -25,6 +25,12 @@ options:
             - The name of the portgroup that is to be created or deleted.
         required: true
         type: str
+    portgroup_description:
+        description:
+            - Description of the portgroup
+        required: false
+        type: str
+        aliases: ['description']
     switch_name:
         description:
             - The name of the distributed vSwitch the port group should be created on.
@@ -86,7 +92,11 @@ options:
         type: bool
     mac_learning:
         description:
+            - This option is deprecated in favour of O(network_policy.mac_learning) and will be removed in 7.0.0.
             - Dictionary which configures MAC learning for portgroup.
+            - Ignored if O(network_policy.inherited=true).
+            - Ignored if O(network_policy.mac_learning) is defined.
+            - Beware that setting this to enabled might disable the inheritance of promiscuous mode and so on!
         suboptions:
             allow_unicast_flooding:
                 type: bool
@@ -114,7 +124,9 @@ options:
         suboptions:
             inherited:
                 type: bool
-                description: Inherit the settings from the switch or not.
+                description:
+                    - Inherit the settings from the switch or not.
+                    - Beware that setting this to enabled will also inherit MAC learning configuration (O(mac_learning)) from the switch!
                 required: true
             promiscuous:
                 type: bool
@@ -125,6 +137,32 @@ options:
             mac_changes:
                 type: bool
                 description: Indicates whether mac changes are allowed. Ignored if O(network_policy.inherited=true).
+            mac_learning:
+                description:
+                    - Configure MAC learning for portgroup.
+                    - Ignored if O(network_policy.inherited=true).
+                type: dict
+                version_added: 5.6.0
+                suboptions:
+                    allow_unicast_flooding:
+                        type: bool
+                        description: The flag to allow flooding of unlearned MAC for ingress traffic.
+                        required: false
+                    enabled:
+                        type: bool
+                        description: The flag to indicate if source MAC address learning is allowed.
+                        required: false
+                    limit:
+                        type: int
+                        description: The maximum number of MAC addresses that can be learned.
+                        required: false
+                    limit_policy:
+                        type: str
+                        description: The default switching policy after MAC limit is exceeded.
+                        required: false
+                        choices:
+                            - 'allow'
+                            - 'drop'
         required: false
         type: dict
     teaming_policy:
@@ -321,9 +359,9 @@ options:
         required: false
         type: dict
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
-'''
+"""
 
 EXAMPLES = r'''
 - name: Create vlan portgroup
@@ -345,6 +383,7 @@ EXAMPLES = r'''
     username: '{{ vcenter_username }}'
     password: '{{ vcenter_password }}'
     portgroup_name: vlan-trunk-portrgoup
+    portgroup_description: 'Trunk 1-1000, 1005, 1100-1200'
     switch_name: dvSwitch
     vlan_id: 1-1000, 1005, 1100-1200
     vlan_trunk: true
@@ -423,8 +462,8 @@ from ansible_collections.community.vmware.plugins.module_utils.vmware import (
     find_dvspg_by_name,
     is_boolean,
     is_truthy,
-    vmware_argument_spec,
     wait_for_task)
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 
 
 class VMwareDvsPortgroup(PyVmomi):
@@ -433,6 +472,8 @@ class VMwareDvsPortgroup(PyVmomi):
         self.dvs_portgroup = None
         self.dv_switch = None
 
+        self.networkPolicy = self.module.params['network_policy']
+
         self.port_allocation = self.module.params['port_allocation']
         if self.port_allocation is None:
             if self.module.params['port_binding'] == 'ephemeral':
@@ -480,6 +521,7 @@ class VMwareDvsPortgroup(PyVmomi):
 
         # Basic config
         config.name = self.module.params['portgroup_name']
+        config.description = self.module.params['portgroup_description']
 
         if self.module.params['port_allocation'] != 'elastic' and self.module.params['port_binding'] != 'ephemeral':
             config.numPorts = self.module.params['num_ports']
@@ -505,28 +547,37 @@ class VMwareDvsPortgroup(PyVmomi):
 
         config.defaultPortConfig.vlan.inherited = False
 
-        if self.module.params['network_policy'] is not None:
+        if self.networkPolicy is not None:
             config.defaultPortConfig.macManagementPolicy = vim.dvs.VmwareDistributedVirtualSwitch.MacManagementPolicy()
-            config.defaultPortConfig.macManagementPolicy.inherited = self.module.params['network_policy']['inherited']
-            if not self.module.params['network_policy']['inherited']:
-                config.defaultPortConfig.macManagementPolicy.allowPromiscuous = self.module.params['network_policy']['promiscuous']
-                config.defaultPortConfig.macManagementPolicy.forgedTransmits = self.module.params['network_policy']['forged_transmits']
-                config.defaultPortConfig.macManagementPolicy.macChanges = self.module.params['network_policy']['mac_changes']
+            config.defaultPortConfig.macManagementPolicy.inherited = self.networkPolicy['inherited']
+            if not self.networkPolicy['inherited']:
+                config.defaultPortConfig.macManagementPolicy.allowPromiscuous = self.networkPolicy['promiscuous']
+                config.defaultPortConfig.macManagementPolicy.forgedTransmits = self.networkPolicy['forged_transmits']
+                config.defaultPortConfig.macManagementPolicy.macChanges = self.networkPolicy['mac_changes']
+                macLearning = self.networkPolicy['mac_learning']
+                if macLearning:
+                    macLearningPolicy = vim.dvs.VmwareDistributedVirtualSwitch.MacLearningPolicy()
+                    macLearningPolicy.allowUnicastFlooding = macLearning['allow_unicast_flooding']
+                    macLearningPolicy.enabled = macLearning['enabled']
+                    macLearningPolicy.limit = macLearning['limit']
+                    macLearningPolicy.limitPolicy = macLearning['limit_policy']
+                    config.defaultPortConfig.macManagementPolicy.macLearningPolicy = macLearningPolicy
 
-        macLearning = self.module.params['mac_learning']
-        if macLearning:
-            if config.defaultPortConfig.macManagementPolicy is None:
-                config.defaultPortConfig.macManagementPolicy = vim.dvs.VmwareDistributedVirtualSwitch.MacManagementPolicy()
-            macLearningPolicy = vim.dvs.VmwareDistributedVirtualSwitch.MacLearningPolicy()
-            if macLearning['allow_unicast_flooding'] is not None:
-                macLearningPolicy.allowUnicastFlooding = macLearning['allow_unicast_flooding']
-            if macLearning['enabled'] is not None:
-                macLearningPolicy.enabled = macLearning['enabled']
-            if macLearning['limit'] is not None:
-                macLearningPolicy.limit = macLearning['limit']
-            if macLearning['limit_policy']:
-                macLearningPolicy.limitPolicy = macLearning['limit_policy']
-            config.defaultPortConfig.macManagementPolicy.macLearningPolicy = macLearningPolicy
+        if not self.networkPolicy or (not self.networkPolicy['inherited'] and not self.networkPolicy['mac_learning']):
+            macLearning = self.module.params['mac_learning']
+            if macLearning:
+                if config.defaultPortConfig.macManagementPolicy is None:
+                    config.defaultPortConfig.macManagementPolicy = vim.dvs.VmwareDistributedVirtualSwitch.MacManagementPolicy()
+                macLearningPolicy = vim.dvs.VmwareDistributedVirtualSwitch.MacLearningPolicy()
+                if macLearning['allow_unicast_flooding'] is not None:
+                    macLearningPolicy.allowUnicastFlooding = macLearning['allow_unicast_flooding']
+                if macLearning['enabled'] is not None:
+                    macLearningPolicy.enabled = macLearning['enabled']
+                if macLearning['limit'] is not None:
+                    macLearningPolicy.limit = macLearning['limit']
+                if macLearning['limit_policy']:
+                    macLearningPolicy.limitPolicy = macLearning['limit_policy']
+                config.defaultPortConfig.macManagementPolicy.macLearningPolicy = macLearningPolicy
 
         # Teaming Policy
         teamingPolicy = vim.dvs.VmwareDistributedVirtualSwitch.UplinkPortTeamingPolicy()
@@ -731,6 +782,10 @@ class VMwareDvsPortgroup(PyVmomi):
         if self.dvs_portgroup is None:
             return 'absent'
 
+        # description property in DVPortgroupConfigInfo stored in config property
+        if self.module.params['portgroup_description'] is not None and self.dvs_portgroup.config.description != self.module.params['portgroup_description']:
+            return 'update'
+
         # Check config
         if self.module.params['port_allocation'] != 'elastic' and self.module.params['port_binding'] != 'ephemeral':
             if self.module.params['num_ports'] is not None and self.dvs_portgroup.config.numPorts != self.module.params['num_ports']:
@@ -754,26 +809,38 @@ class VMwareDvsPortgroup(PyVmomi):
             if defaultPortConfig.vlan.vlanId != int(self.module.params['vlan_id']):
                 return 'update'
 
-        if self.module.params['network_policy'] is not None:
-            if defaultPortConfig.macManagementPolicy.inherited != self.module.params['network_policy']['inherited']:
+        if self.networkPolicy is not None:
+            if defaultPortConfig.macManagementPolicy.inherited != self.networkPolicy['inherited']:
                 return 'update'
-            if not self.module.params['network_policy']['inherited']:
-                if defaultPortConfig.macManagementPolicy.allowPromiscuous != self.module.params['network_policy']['promiscuous'] or \
-                        defaultPortConfig.macManagementPolicy.forgedTransmits != self.module.params['network_policy']['forged_transmits'] or \
-                        defaultPortConfig.macManagementPolicy.macChanges != self.module.params['network_policy']['mac_changes']:
+            if not self.networkPolicy['inherited']:
+                if defaultPortConfig.macManagementPolicy.allowPromiscuous != self.networkPolicy['promiscuous'] or \
+                        defaultPortConfig.macManagementPolicy.forgedTransmits != self.networkPolicy['forged_transmits'] or \
+                        defaultPortConfig.macManagementPolicy.macChanges != self.networkPolicy['mac_changes']:
                     return 'update'
+                macLearning = self.networkPolicy['mac_learning']
+                if macLearning:
+                    macLearningPolicy = defaultPortConfig.macManagementPolicy.macLearningPolicy
+                    if macLearning['allow_unicast_flooding'] is not None and macLearningPolicy.allowUnicastFlooding != macLearning['allow_unicast_flooding']:
+                        return 'update'
+                    if macLearning['enabled'] is not None and macLearningPolicy.enabled != macLearning['enabled']:
+                        return 'update'
+                    if macLearning['limit'] is not None and macLearningPolicy.limit != macLearning['limit']:
+                        return 'update'
+                    if macLearning['limit_policy'] and macLearningPolicy.limitPolicy != macLearning['limit_policy']:
+                        return 'update'
 
-        macLearning = self.module.params['mac_learning']
-        if macLearning:
-            macLearningPolicy = defaultPortConfig.macManagementPolicy.macLearningPolicy
-            if macLearning['allow_unicast_flooding'] is not None and macLearningPolicy.allowUnicastFlooding != macLearning['allow_unicast_flooding']:
-                return 'update'
-            if macLearning['enabled'] is not None and macLearningPolicy.enabled != macLearning['enabled']:
-                return 'update'
-            if macLearning['limit'] is not None and macLearningPolicy.limit != macLearning['limit']:
-                return 'update'
-            if macLearning['limit_policy'] and macLearningPolicy.limitPolicy != macLearning['limit_policy']:
-                return 'update'
+        if not self.networkPolicy or (not self.networkPolicy['inherited'] and not self.networkPolicy['mac_learning']):
+            macLearning = self.module.params['mac_learning']
+            if macLearning:
+                macLearningPolicy = defaultPortConfig.macManagementPolicy.macLearningPolicy
+                if macLearning['allow_unicast_flooding'] is not None and macLearningPolicy.allowUnicastFlooding != macLearning['allow_unicast_flooding']:
+                    return 'update'
+                if macLearning['enabled'] is not None and macLearningPolicy.enabled != macLearning['enabled']:
+                    return 'update'
+                if macLearning['limit'] is not None and macLearningPolicy.limit != macLearning['limit']:
+                    return 'update'
+                if macLearning['limit_policy'] and macLearningPolicy.limitPolicy != macLearning['limit_policy']:
+                    return 'update'
 
         # Teaming Policy
         teamingPolicy = self.dvs_portgroup.config.defaultPortConfig.uplinkTeamingPolicy
@@ -882,10 +949,11 @@ class VMwareDvsPortgroup(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         dict(
             portgroup_name=dict(required=True, type='str'),
+            portgroup_description=dict(required=False, type='str', aliases=['description']),
             switch_name=dict(required=True, type='str'),
             vlan_id=dict(required=True, type='str'),
             num_ports=dict(type='int'),
@@ -900,7 +968,16 @@ def main():
                     inherited=dict(type='bool', required=True),
                     promiscuous=dict(type='bool'),
                     forged_transmits=dict(type='bool'),
-                    mac_changes=dict(type='bool')
+                    mac_changes=dict(type='bool'),
+                    mac_learning=dict(
+                        type='dict',
+                        options=dict(
+                            allow_unicast_flooding=dict(type='bool'),
+                            enabled=dict(type='bool'),
+                            limit=dict(type='int'),
+                            limit_policy=dict(type='str', choices=['allow', 'drop']),
+                        ),
+                    )
                 ),
                 required_if=[
                     ('inherited', False, ('promiscuous', 'forged_transmits', 'mac_changes'))
@@ -1000,6 +1077,8 @@ def main():
             ),
             mac_learning=dict(
                 type='dict',
+                removed_in_version='7.0.0',
+                removed_from_collection='community.vmware',
                 options=dict(
                     allow_unicast_flooding=dict(type='bool'),
                     enabled=dict(type='bool'),
