@@ -231,7 +231,7 @@ options:
             'internal_flows_only': false
         }
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
 '''
 
@@ -336,10 +336,11 @@ except ImportError:
     pass
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 from ansible_collections.community.vmware.plugins.module_utils.vmware import (
-    PyVmomi, TaskError, find_dvs_by_name, vmware_argument_spec, wait_for_task
+    PyVmomi, TaskError, find_dvs_by_name, wait_for_task
 )
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 
 
 class VMwareDvSwitch(PyVmomi):
@@ -906,6 +907,7 @@ class VMwareDvSwitch(PyVmomi):
                 config_spec.defaultPortConfig.macManagementPolicy = policy
 
         # Check switch version
+        spec_product = None
         if self.switch_version:
             results['version'] = self.switch_version
             if self.dvs.config.productInfo.version != self.switch_version:
@@ -991,7 +993,7 @@ class VMwareDvSwitch(PyVmomi):
 
 def main():
     """Main"""
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         dict(
             datacenter_name=dict(aliases=['datacenter']),
