@@ -18,7 +18,6 @@ short_description: Instant Clone VM
 
 description:
 - This module can be used for Creating a powered-on Instant Clone of a virtual machine.
-- All variables and VMware object names are case sensitive.
 - M(community.vmware.vmware_guest) module is needed for creating a VM with poweredon state which would be used as a parent VM.
 - M(community.vmware.vmware_guest_powerstate) module is also needed to poweroff the instant cloned module.
 - The powered off VM would in turn be deleted by again using M(community.vmware.vmware_guest) module.
@@ -32,21 +31,21 @@ options:
       - Name of the Cloned virtual machine.
     type: str
     aliases: ['vm_name']
-    required: True
+    required: true
   parent_vm:
     description:
       - Name of the parent virtual machine.
-      - This is a required parameter, if parameter C(uuid) or C(moid) is not supplied.
+      - This is a required parameter, if parameter O(uuid) or O(moid) is not supplied.
     type: str
   uuid:
     description:
       - UUID of the vm instance to clone from, this is VMware's unique identifier.
-      - This is a required parameter, if parameter C(parent_vm) or C(moid) is not supplied.
+      - This is a required parameter, if parameter O(parent_vm) or O(moid) is not supplied.
     type: str
   moid:
     description:
       - Managed Object ID of the vm instance to manage if known, this is a unique identifier only within a single vCenter instance.
-      - This is required if C(parent_vm) or C(uuid) is not supplied.
+      - This is required if O(parent_vm) or O(uuid) is not supplied.
     type: str
   use_instance_uuid:
     description:
@@ -57,25 +56,24 @@ options:
     description:
       - Name of the ESX Host in datacenter in which to place cloned VM.
       - The host has to be a member of the cluster that contains the resource pool.
-      - Required with I(resource_pool) to find resource pool details. This will be used as additional information when there are resource pools with same name.
+      - Required with O(resource_pool) to find resource pool details. This will be used as additional information when there are resource pools with same name.
     type: str
     aliases: ['esxi_hostname']
-    required: True
+    required: true
   datastore:
     description:
       - The name of the datastore or the datastore cluster.
       - If datastore cluster name is specified, module will find the Storage DRS recommended datastore in that cluster.
     type: str
-    required: True
+    required: true
   datacenter:
     description:
       - Name of the datacenter, where VM to be deployed.
     type: str
-    required: True
+    required: true
   folder:
     description:
       - Destination folder, absolute path to deploy the cloned vm.
-      - This parameter is case sensitive.
       - 'Examples:'
       - 'folder: ha-datacenter/vm'
       - 'folder: /datacenter1/vm'
@@ -83,22 +81,20 @@ options:
   resource_pool:
     description:
       - Name of the resource pool in datacenter in which to place deployed VM.
-      - Required if I(cluster) is not specified.
-      - For default or non-unique resource pool names, specify I(host) and I(cluster).
       - C(Resources) is the default name of resource pool.
     type: str
-    required: False
+    required: false
   vm_username:
     description:
       - The user to login-in to the virtual machine.
       - Only required when using guest customization feature.
-    required: False
+    required: false
     type: str
   vm_password:
     description:
       - The password used to login-in to the virtual machine.
       - Only required when using guest customization feature.
-    required: False
+    required: false
     type: str
   guestinfo_vars:
     description:
@@ -136,14 +132,14 @@ options:
     description:
       - Whether waiting until vm tools start after rebooting an instant clone vm.
     type: bool
-    default: True
+    default: true
   wait_vm_tools_timeout:
     description:
-      - Define a timeout (in seconds) for I(the wait_vm_tools) parameter.
+      - Define a timeout (in seconds) for the O(wait_vm_tools) parameter.
     type: int
     default: 300
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
 author:
 - Anant Chopra (@Anant99-sys)
@@ -156,7 +152,7 @@ EXAMPLES = r'''
     hostname: "{{ vcenter_hostname }}"
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
-    validate_certs: False
+    validate_certs: false
     folder: "{{ f0 }}"
     datastore: "{{ rw_datastore }}"
     datacenter: "{{ dc1 }}"
@@ -199,7 +195,7 @@ EXAMPLES = r'''
     password: "{{ vcenter_password }}"
     vm_username: "root"
     vm_password: "SuperSecret"
-    validate_certs: False
+    validate_certs: false
     folder: "{{ f0 }}"
     datastore: "{{ rw_datastore }}"
     datacenter: "{{ dc1 }}"
@@ -222,7 +218,7 @@ EXAMPLES = r'''
     hostname: "{{ vcenter_hostname }}"
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
-    validate_certs: False
+    validate_certs: false
     name: "{{ Clone_vm }}"
     parent_vm: "{{ testvm_1 }}"
     datacenter: "{{ dc1 }}"
@@ -236,7 +232,7 @@ EXAMPLES = r'''
     hostname: "{{ vcenter_hostname }}"
     username: "{{ vcenter_username }}"
     password: "{{ vcenter_password }}"
-    validate_certs: False
+    validate_certs: false
     folder: "{{ f0 }}"
     datastore: "{{ rw_datastore }}"
     datacenter: "{{ dc1 }}"
@@ -256,7 +252,6 @@ RETURN = r'''
 vm_info:
     description:
       - metadata about the virtual machine
-      - added instance_uuid from version 1.12.0
     returned: always
     type: dict
     sample: {
@@ -270,7 +265,7 @@ vm_info:
 '''
 
 import time
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 from ansible.module_utils.basic import AnsibleModule
 
 from ansible_collections.community.vmware.plugins.module_utils.vmware import (
@@ -278,12 +273,12 @@ from ansible_collections.community.vmware.plugins.module_utils.vmware import (
     TaskError,
     find_vm_by_name,
     find_vm_by_id,
-    connect_to_api,
-    vmware_argument_spec,
     find_obj,
     wait_for_task,
     set_vm_power_state
 )
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
+from ansible_collections.vmware.vmware.plugins.module_utils.clients.pyvmomi import PyvmomiClient
 
 try:
     from pyVmomi import vim
@@ -335,7 +330,7 @@ class VmwareGuestInstantClone(PyVmomi):
         return info
 
     def Instant_clone(self):
-        # clone the vm on  VC
+        # clone the vm on VC
         if self.vm_obj is None:
             vm_id = self.parent_vm or self.uuid or self.moid
             self.module.fail_json(msg="Failed to find the VM/template with %s" % vm_id)
@@ -347,14 +342,15 @@ class VmwareGuestInstantClone(PyVmomi):
         except TaskError as task_e:
             self.module.fail_json(msg=to_native(task_e))
 
-        self.destination_content = connect_to_api(
-            self.module,
+        pyvmomi_client = PyvmomiClient(
             hostname=self.hostname,
             username=self.username,
             password=self.password,
             port=self.port,
             validate_certs=self.validate_certs)
 
+        self.destination_content = pyvmomi_client.content
+
         vm_IC = find_vm_by_name(content=self.destination_content, vm_name=self.params['name'])
         if vm_IC and self.params.get('guestinfo_vars'):
             guest_custom_mng = self.destination_content.guestCustomizationManager
@@ -425,14 +421,15 @@ class VmwareGuestInstantClone(PyVmomi):
         Verify user-provided parameters
         '''
         # connect to host/VC
-        self.destination_content = connect_to_api(
-            self.module,
+        pyvmomi_client = PyvmomiClient(
             hostname=self.hostname,
             username=self.username,
             password=self.password,
             port=self.port,
             validate_certs=self.validate_certs)
 
+        self.destination_content = pyvmomi_client.content
+
         use_instance_uuid = self.params.get('use_instance_uuid') or False
 
         if 'parent_vm' in self.params and self.params['parent_vm']:
@@ -522,7 +519,7 @@ class VmwareGuestInstantClone(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         name=dict(type='str', required=True, aliases=['vm_name']),
         uuid=dict(type='str'),
