@@ -34,7 +34,7 @@ options:
     - If O(cluster_name) is not given, this parameter is required.
     type: str
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
 '''
 
@@ -64,8 +64,8 @@ except ImportError:
     pass
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi
-from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
-from ansible.module_utils._text import to_native
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
+from ansible.module_utils.common.text.converters import to_native
 
 
 class VMwareAccpetanceManager(PyVmomi):
