@@ -22,15 +22,18 @@ options:
     description:
         - AD Domain to join.
     type: str
+    default: ''
     aliases: [ domain, domain_name ]
   ad_user:
     description:
         - Username for AD domain join.
     type: str
+    default: ''
   ad_password:
     description:
         - Password for AD domain join.
     type: str
+    default: ''
   ad_state:
      description:
         - Whether the ESXi host is joined to an AD domain or not.
@@ -41,15 +44,15 @@ options:
   esxi_hostname:
     description:
     - Name of the host system to work with.
-    - This parameter is required if C(cluster_name) is not specified.
+    - This parameter is required if O(cluster_name) is not specified.
     type: str
   cluster_name:
     description:
     - Name of the cluster from which all host systems will be used.
-    - This parameter is required if C(esxi_hostname) is not specified.
+    - This parameter is required if O(esxi_hostname) is not specified.
     type: str
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
 '''
 
@@ -100,8 +103,9 @@ except ImportError:
     pass
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, TaskError, vmware_argument_spec, wait_for_task
-from ansible.module_utils._text import to_native
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, TaskError, wait_for_task
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
+from ansible.module_utils.common.text.converters import to_native
 
 
 class VmwareHostAdAuthentication(PyVmomi):
@@ -328,7 +332,7 @@ class VmwareHostAdAuthentication(PyVmomi):
 
 def main():
     """Main"""
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         ad_domain=dict(type='str', default='', aliases=['domain', 'domain_name']),
         ad_user=dict(type='str', default=''),
