@@ -13,19 +13,19 @@ __metaclass__ = type
 DOCUMENTATION = r'''
 ---
 module: vmware_local_role_manager
-short_description: Manage local roles on an ESXi host
+short_description: Manage local roles on an ESXi host or vCenter
 description:
-    - This module can be used to manage local roles on an ESXi host.
+    - This module can be used to manage local roles on an ESXi host or vCenter.
 author:
 - Abhijeet Kasurde (@Akasurde)
 - Christian Kotte (@ckotte)
 notes:
-    - Be sure that the ESXi user used for login, has the appropriate rights to create / delete / edit roles
+    - Be sure that the user used for login, has the appropriate rights to create / delete / edit roles
 options:
   local_role_name:
     description:
     - The local role name to be managed.
-    required: True
+    required: true
     type: str
   local_privilege_ids:
     description:
@@ -37,26 +37,26 @@ options:
   state:
     description:
     - Indicate desired state of the role.
-    - If the role already exists when C(state=present), the role info is updated.
+    - If the role already exists when V(present), the role info is updated.
     choices: ['present', 'absent']
     default: present
     type: str
   force_remove:
     description:
-    - If set to C(False) then prevents the role from being removed if any permissions are using it.
-    default: False
+    - If set to V(false) then prevents the role from being removed if any permissions are using it.
+    default: false
     type: bool
   action:
     description:
     - This parameter is only valid while updating an existing role with privileges.
-    - C(add) will add the privileges to the existing privilege list.
-    - C(remove) will remove the privileges from the existing privilege list.
-    - C(set) will replace the privileges of the existing privileges with user defined list of privileges.
+    - V(add) will add the privileges to the existing privilege list.
+    - V(remove) will remove the privileges from the existing privilege list.
+    - V(set) will replace the privileges of the existing privileges with user defined list of privileges.
     default: set
     choices: [ add, remove, set ]
     type: str
 extends_documentation_fragment:
-- community.vmware.vmware.documentation
+- vmware.vmware.base_options
 
 '''
 
@@ -70,11 +70,11 @@ EXAMPLES = r'''
     state: present
   delegate_to: localhost
 
-- name: Add local role with privileges to ESXi
+- name: Add local role with privileges to vCenter
   community.vmware.vmware_local_role_manager:
-    hostname: '{{ esxi_hostname }}'
-    username: '{{ esxi_username }}'
-    password: '{{ esxi_password }}'
+    hostname: '{{ vcenter_hostname }}'
+    username: '{{ vcenter_username }}'
+    password: '{{ vcenter_password }}'
     local_role_name: vmware_qa
     local_privilege_ids: [ 'Folder.Create', 'Folder.Delete']
     state: present
@@ -91,9 +91,9 @@ EXAMPLES = r'''
 
 - name: Add a privilege to an existing local role
   community.vmware.vmware_local_role_manager:
-    hostname: '{{ esxi_hostname }}'
-    username: '{{ esxi_username }}'
-    password: '{{ esxi_password }}'
+    hostname: '{{ vcenter_hostname }}'
+    username: '{{ vcenter_username }}'
+    password: '{{ vcenter_password }}'
     local_role_name: vmware_qa
     local_privilege_ids: [ 'Folder.Create' ]
     action: add
@@ -111,9 +111,9 @@ EXAMPLES = r'''
 
 - name: Set a privilege to an existing local role
   community.vmware.vmware_local_role_manager:
-    hostname: '{{ esxi_hostname }}'
-    username: '{{ esxi_username }}'
-    password: '{{ esxi_password }}'
+    hostname: '{{ vcenter_hostname }}'
+    username: '{{ vcenter_username }}'
+    password: '{{ vcenter_password }}'
     local_role_name: vmware_qa
     local_privilege_ids: [ 'Folder.Create' ]
     action: set
@@ -126,7 +126,7 @@ role_name:
     returned: always
     type: str
 role_id:
-    description: ESXi generated local role id
+    description: Generated local role id
     returned: always
     type: int
 privileges:
@@ -158,7 +158,8 @@ except ImportError:
     pass
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, vmware_argument_spec
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import base_argument_spec
 
 
 class VMwareLocalRoleManager(PyVmomi):
@@ -178,7 +179,7 @@ class VMwareLocalRoleManager(PyVmomi):
         if self.content.authorizationManager is None:
             self.module.fail_json(
                 msg="Failed to get local authorization manager settings.",
-                details="It seems that '%s' is a vCenter server instead of an ESXi server" % self.params['hostname']
+                details="It seems that '%s' does not support this functionality" % self.params['hostname']
             )
 
     def process_state(self):
@@ -381,7 +382,7 @@ class VMwareLocalRoleManager(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(dict(local_role_name=dict(required=True, type='str'),
                               local_privilege_ids=dict(default=[], type='list', elements='str'),
                               force_remove=dict(default=False, type='bool'),
