@@ -13,12 +13,16 @@ __metaclass__ = type
 import re
 import json
 import ast
-from ansible.module_utils.six import iteritems
+from copy import copy
+from itertools import (count, groupby)
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.utils import (
-    is_masklen,
-    to_netmask,
     remove_empties
 )
+from ansible.module_utils.common.network import (
+    is_masklen,
+    to_netmask,
+)
+from ansible.module_utils.common.validation import check_required_arguments
 from ansible_collections.dellemc.enterprise_sonic.plugins.module_utils.network.sonic.sonic import (
     to_request,
     edit_config
@@ -31,6 +35,35 @@ GET = 'get'
 intf_naming_mode = ""
 
 
+def remove_matching_defaults(root, default_entry):
+    if isinstance(root, list):
+        for list_item in root:
+            remove_matching_defaults(list_item, default_entry)
+    elif isinstance(root, dict):
+        nextobj = root.get(default_entry[0]['name'])
+        if nextobj is not None:
+            if len(default_entry) > 1:
+                remove_matching_defaults(nextobj, default_entry[1:])
+            else:
+                # Leaf
+                if nextobj == default_entry[0]['default']:
+                    root.pop(default_entry[0]['name'])
+
+
+def add_config_defaults(root, default_entry):
+    if isinstance(root, list):
+        for list_item in root:
+            add_config_defaults(list_item, default_entry)
+    elif isinstance(root, dict):
+        nextobj = root.get(default_entry[0]['name'])
+        if nextobj is not None:
+            if len(default_entry) > 1:
+                add_config_defaults(nextobj, default_entry[1:])
+        else:
+            if len(default_entry) == 1:
+                root[default_entry[0]['name']] = default_entry[0]['default']
+
+
 def get_diff(base_data, compare_with_data, test_keys=None, is_skeleton=None):
     diff = []
     if is_skeleton is None:
@@ -216,28 +249,28 @@ def dict_to_set(sample_dict):
     # Generate a set with passed dictionary for comparison
     test_dict = dict()
     if isinstance(sample_dict, dict):
-        for k, v in iteritems(sample_dict):
+        for k, v in sample_dict.items():
             if v is not None:
                 if isinstance(v, list):
                     if isinstance(v[0], dict):
                         li = []
                         for each in v:
-                            for key, value in iteritems(each):
+                            for key, value in each.items():
                                 if isinstance(value, list):
                                     each[key] = tuple(value)
-                            li.append(tuple(iteritems(each)))
+                            li.append(tuple(each.items()))
                         v = tuple(li)
                     else:
                         v = tuple(v)
                 elif isinstance(v, dict):
                     li = []
-                    for key, value in iteritems(v):
+                    for key, value in v.items():
                         if isinstance(value, list):
                             v[key] = tuple(value)
-                    li.extend(tuple(iteritems(v)))
+                    li.extend(tuple(v.items()))
                     v = tuple(li)
                 test_dict.update({k: v})
-        return_set = set(tuple(iteritems(test_dict)))
+        return_set = set(tuple(test_dict.items()))
     else:
         return_set = set(sample_dict)
     return return_set
@@ -319,13 +352,38 @@ def netmask_to_cidr(netmask):
 
 def remove_empties_from_list(config_list):
     ret_config = []
-    if not config_list:
+    if not config_list or not isinstance(config_list, list):
         return ret_config
     for config in config_list:
-        ret_config.append(remove_empties(config))
+        if isinstance(config, dict):
+            ret_config.append(remove_empties(config))
+        else:
+            ret_config.append(copy(config))
     return ret_config
 
 
+def remove_none(config):
+    '''goes through nested dictionary items and removes any keys that have None as value.
+    enables using empty list/dict to specify clear everything for that section and differentiate this
+    'clear everything' case from when no value was given
+    Note: This function is provided as an alternative to the "remove_empties" function in
+    ansible utils because the Ansible 'remove_empties' function will remove empty lists
+    and dicts as well as None'''
+    if isinstance(config, dict):
+        for k, v in list(config.items()):
+            if v is not None:
+                remove_none(v)
+            if v is None:
+                del config[k]
+    elif isinstance(config, list):
+        for item in list(config):
+            if item is not None:
+                remove_none(item)
+            if item is None:
+                config.remove(item)
+    return config
+
+
 def get_device_interface_naming_mode(module):
     intf_naming_mode = ""
     request = {"path": "data/sonic-device-metadata:sonic-device-metadata/DEVICE_METADATA/DEVICE_METADATA_LIST=localhost", "method": GET}
@@ -359,12 +417,18 @@ def find_intf_naming_mode(intf_name):
 
 def validate_intf_naming_mode(intf_name, module):
     global intf_naming_mode
+    compatible_input_naming_modes = {
+        'native': [NATIVE_MODE],
+        'standard': [STANDARD_MODE],
+        'standard-ext': [STANDARD_MODE]
+    }
+
     if intf_naming_mode == "":
         intf_naming_mode = get_device_interface_naming_mode(module)
 
     if intf_naming_mode != "":
         ansible_intf_naming_mode = find_intf_naming_mode(intf_name)
-        if intf_naming_mode != ansible_intf_naming_mode:
+        if ansible_intf_naming_mode not in compatible_input_naming_modes[intf_naming_mode]:
             err = "Interface naming mode configured on switch {naming_mode}, {intf_name} is not valid".format(naming_mode=intf_naming_mode, intf_name=intf_name)
             module.fail_json(msg=err, code=400)
 
@@ -379,13 +443,23 @@ def normalize_interface_name(configs, module, namekey=None):
                 conf[namekey] = get_normalize_interface_name(conf[namekey], module)
 
 
+def normalize_interface_name_list(configs, module):
+    norm_configs = []
+    if configs:
+        for conf in configs:
+            conf = get_normalize_interface_name(conf, module)
+            norm_configs.append(conf)
+
+    return norm_configs
+
+
 def get_normalize_interface_name(intf_name, module):
     change_flag = False
     # remove the space in the given string
     ret_intf_name = re.sub(r"\s+", "", intf_name, flags=re.UNICODE)
     ret_intf_name = ret_intf_name.capitalize()
 
-    # serach the numeric charecter(digit)
+    # search the numeric character(digit)
     match = re.search(r"\d", ret_intf_name)
     if match:
         change_flag = True
@@ -422,14 +496,7 @@ def get_normalize_interface_name(intf_name, module):
 
 
 def get_speed_from_breakout_mode(breakout_mode):
-    speed = None
-    speed_breakout_mode_map = {
-        "4x10G": "SPEED_10GB", "1x100G": "SPEED_100GB", "1x40G": "SPEED_40GB", "4x25G": "SPEED_25GB", "2x50G": "SPEED_50GB",
-        "1x400G": "SPEED_400GB", "4x100G": "SPEED_100GB", "4x50G": "SPEED_50GB", "2x100G": "SPEED_100GB", "2x200G": "SPEED_200GB"
-    }
-    if breakout_mode in speed_breakout_mode_map:
-        speed = speed_breakout_mode_map[breakout_mode]
-    return speed
+    return 'SPEED_' + breakout_mode.split('x')[1].replace('G', 'GB')
 
 
 def get_breakout_mode(module, name):
@@ -445,7 +512,7 @@ def get_breakout_mode(module, name):
     except ConnectionError as exc:
         try:
             json_obj = json.loads(str(exc).replace("'", '"'))
-            if json_obj and type(json_obj) is dict and 404 == json_obj['code']:
+            if json_obj and isinstance(json_obj, dict) and 404 == json_obj['code']:
                 response = None
             else:
                 module.fail_json(msg=str(exc), code=exc.code)
@@ -457,14 +524,16 @@ def get_breakout_mode(module, name):
         port_name = raw_port_breakout.get('name', None)
         port_data = raw_port_breakout.get('port', None)
         if port_name and port_data and 'openconfig-platform-port:breakout-mode' in port_data:
-            if 'config' in port_data['openconfig-platform-port:breakout-mode']:
-                cfg = port_data['openconfig-platform-port:breakout-mode']['config']
-                channel_speed = cfg.get('channel-speed', None)
-                num_channels = cfg.get('num-channels', None)
-                if channel_speed and num_channels:
-                    speed = channel_speed.replace('openconfig-if-ethernet:SPEED_', '')
-                    speed = speed.replace('GB', 'G')
-                    mode = str(num_channels) + 'x' + speed
+            if 'groups' in port_data['openconfig-platform-port:breakout-mode']:
+                group = port_data['openconfig-platform-port:breakout-mode']['groups']['group'][0]
+                if 'config' in group:
+                    cfg = group.get('config', None)
+                    breakout_speed = cfg.get('breakout-speed', None)
+                    num_breakouts = cfg.get('num-breakouts', None)
+                    if breakout_speed and num_breakouts:
+                        speed = breakout_speed.replace('openconfig-if-ethernet:SPEED_', '')
+                        speed = speed.replace('GB', 'G')
+                        mode = str(num_breakouts) + 'x' + speed
     return mode
 
 
@@ -497,3 +566,219 @@ def command_list_str_to_dict(module, warnings, cmd_list_in, exec_cmd=False):
             cmd_list_out.append(cmd_out)
 
     return cmd_list_out
+
+
+def send_requests(module, requests):
+
+    reply = dict()
+    response = []
+    if not module.check_mode and requests:
+        try:
+            response = edit_config(module, to_request(module, requests))
+        except ConnectionError as exc:
+            module.fail_json(msg=str(exc), code=exc.code)
+
+        reply = response[0][1]
+
+    return reply
+
+
+def get_replaced_config(new_conf, exist_conf, test_keys=None):
+
+    replace_conf = []
+    if not new_conf or not exist_conf:
+        return replace_conf
+
+    if isinstance(new_conf, list) and isinstance(exist_conf, list):
+
+        replace_conf_dict = get_replaced_config_dict({"config": new_conf},
+                                                     {"config": exist_conf},
+                                                     test_keys)
+        replaced_conf = replace_conf_dict.get("config", [])
+    else:
+        replaced_conf = get_replaced_config_dict(new_conf, exist_conf, test_keys)
+
+    return replaced_conf
+
+
+def get_replaced_config_dict(new_conf, exist_conf, test_keys=None, key_set=None):
+
+    replaced_conf = dict()
+
+    if test_keys is None:
+        test_keys = []
+    if key_set is None:
+        key_set = []
+
+    if not new_conf:
+        return replaced_conf
+
+    new_key_set = set(new_conf.keys())
+    exist_key_set = set(exist_conf.keys())
+
+    trival_new_key_set = set()
+    dict_list_new_key_set = set()
+    for key in new_key_set:
+        if new_conf[key] not in [None, [], {}]:
+            if isinstance(new_conf[key], (list, dict)):
+                dict_list_new_key_set.add(key)
+            else:
+                trival_new_key_set.add(key)
+
+    trival_exist_key_set = set()
+    dict_list_exist_key_set = set()
+    for key in exist_key_set:
+        if exist_conf[key] not in [None, [], {}]:
+            if isinstance(exist_conf[key], (list, dict)):
+                dict_list_exist_key_set.add(key)
+            else:
+                trival_exist_key_set.add(key)
+
+    common_trival_key_set = trival_new_key_set.intersection(trival_exist_key_set)
+    common_dict_list_key_set = dict_list_new_key_set.intersection(dict_list_exist_key_set)
+
+    key_matched_cnt = 0
+    common_trival_key_matched = True
+    for key in common_trival_key_set:
+        if new_conf[key] == exist_conf[key]:
+            if key in key_set:
+                key_matched_cnt += 1
+        else:
+            if key not in key_set:
+                common_trival_key_matched = False
+
+    for key in common_dict_list_key_set:
+        if new_conf[key] == exist_conf[key]:
+            if key in key_set:
+                key_matched_cnt += 1
+
+    key_matched = (key_matched_cnt == len(key_set))
+    if key_matched:
+        extra_trival_new_key_set = trival_new_key_set - common_trival_key_set
+        extra_trival_exist_key_set = trival_exist_key_set - common_trival_key_set
+        if extra_trival_new_key_set or extra_trival_exist_key_set or \
+           not common_trival_key_matched:
+            # Replace whole dict.
+            replaced_conf = exist_conf
+            return replaced_conf
+    else:
+        replaced_conf = []
+        return replaced_conf
+
+    for key in key_set:
+        common_dict_list_key_set.discard(key)
+
+    replace_whole_dict = False
+    replace_some_list = False
+    replace_some_dict = False
+    for key in common_dict_list_key_set:
+
+        new_value = new_conf[key]
+        exist_value = exist_conf[key]
+
+        if (isinstance(new_value, list) and isinstance(exist_value, list)):
+            n_list = new_value
+            e_list = exist_value
+            t_keys = next((t_key_item[key] for t_key_item in test_keys if key in t_key_item), None)
+            t_key_set = set()
+            if t_keys:
+                t_key_set = set(t_keys.keys())
+
+            replaced_list = list()
+            not_dict_item = False
+            dict_no_key_item = False
+            for n_item in n_list:
+                for e_item in e_list:
+                    if (isinstance(n_item, dict) and isinstance(e_item, dict)):
+                        if t_keys:
+                            remaining_keys = [t_key_item for t_key_item in test_keys if key not in t_key_item]
+                            replaced_dict = get_replaced_config_dict(n_item, e_item,
+                                                                     remaining_keys, t_key_set)
+                        else:
+                            dict_no_key_item = True
+                            break
+
+                        if replaced_dict:
+                            replaced_list.append(replaced_dict)
+                            break
+                    else:
+                        not_dict_item = True
+                        break
+
+                if not_dict_item or dict_no_key_item:
+                    break
+
+            if dict_no_key_item:
+                replaced_list = e_list
+
+            if not_dict_item:
+                n_set = set(n_list)
+                e_set = set(e_list)
+                diff_set = n_set.symmetric_difference(e_set)
+                if diff_set:
+                    replaced_conf[key] = e_list
+                    replace_some_list = True
+
+            elif replaced_list:
+                replaced_conf[key] = replaced_list
+                replace_some_list = True
+
+        elif (isinstance(new_value, dict) and isinstance(exist_value, dict)):
+            replaced_dict = get_replaced_config_dict(new_conf[key], exist_conf[key], test_keys)
+            if replaced_dict:
+                replaced_conf[key] = replaced_dict
+                replace_some_dict = True
+
+        elif (isinstance(new_value, (list, dict)) or isinstance(exist_value, (list, dict))):
+            # Replace whole dict.
+            replaced_conf = exist_conf
+            replace_whole_dict = True
+            break
+
+        else:
+            continue
+
+    if ((replace_some_dict or replace_some_list) and (not replace_whole_dict)):
+        for key in key_set:
+            replaced_conf[key] = exist_conf[key]
+
+    return replaced_conf
+
+
+def check_required(module, required_parameters, parameters, options_context=None):
+    '''This utility is a wrapper for the Ansible "check_required_arguments"
+    function. The "required_parameters" input list provides a list of
+    key names that are required in the dictionary specified by "parameters".
+    The optional "options_context" parameter specifies the context/path
+    from the top level parent dict to the dict being checked.'''
+    if required_parameters:
+        spec = {}
+        for parameter in required_parameters:
+            spec[parameter] = {'required': True}
+
+        try:
+            check_required_arguments(spec, parameters, options_context)
+        except TypeError as exc:
+            module.fail_json(msg=str(exc))
+
+
+def get_ranges_in_list(num_list):
+    """Returns a generator for list(s) of consecutive numbers
+    present in the given sorted list of numbers
+    """
+    for key, group in groupby(num_list, lambda num, i=count(): num - next(i)):
+        yield list(group)
+
+
+def sort_lists_by_interface_name(conf_list, key):
+    """
+    Sorts a list of dictionaries based on the value of a specified key.
+    """
+
+    def retrieve_sort_keys(name):
+        group = re.match(r"(.*)(\d+)$", name)
+        if group:
+            return group[1], int(group[2])
+        return name, name
+
+    conf_list.sort(key=lambda x: retrieve_sort_keys(x[key]))
