@@ -3,8 +3,8 @@
 
 #
 # Dell OpenManage Ansible Modules
-# Version 7.0.0
-# Copyright (C) 2020-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 10.0.1
+# Copyright (C) 2020-2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -182,9 +182,10 @@ options:
       - This option is not mandatory.
     type: int
 requirements:
-    - "python >= 3.8.6"
+    - "python >= 3.9.6"
 author:
     - "Jagadeesh N V(@jagadeeshnv)"
+    - "Sapana Gupta(@sapana05)"
 '''
 
 EXAMPLES = r'''
@@ -426,8 +427,7 @@ error_info:
 import json
 import socket
 from ssl import SSLError
-from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.dellemc.openmanage.plugins.module_utils.ome import RestOME, ome_auth_params
+from ansible_collections.dellemc.openmanage.plugins.module_utils.ome import RestOME, OmeAnsibleModule
 from ansible.module_utils.urls import ConnectionError, SSLValidationError
 from ansible.module_utils.six.moves.urllib.error import URLError, HTTPError
 
@@ -593,7 +593,7 @@ def get_network_config_data(rest_obj, module):
                 if adp.get("PrimaryInterface"):
                     pri_adp = adp
         if interface and int_adp is None:
-            module.fail_json(msg="The 'interface_name' value provided {0} is invalid".format(interface))
+            module.exit_json(msg="The 'interface_name' value provided {0} is invalid".format(interface), failed=True)
         elif int_adp:
             return int_adp, "POST", POST_IP_CONFIG
         else:
@@ -642,7 +642,7 @@ def validate_ipaddress(module, ip_type, config, var_list, ip_func):
         for ipname in var_list:
             val = ipv_input.get(ipname)
             if val and not ip_func(val):
-                module.fail_json(msg="Invalid {0} address provided for the {1}".format(ip_type, ipname))
+                module.exit_json(msg="Invalid {0} address provided for the {1}".format(ip_type, ipname), failed=True)
 
 
 def validate_input(module):
@@ -652,7 +652,7 @@ def validate_input(module):
     validate_ipaddress(module, "IPv4", "ipv4_configuration", ip_addr, validate_ip_address)
     delay = module.params.get("reboot_delay")
     if delay and delay < 0:
-        module.fail_json(msg="Invalid value provided for 'reboot_delay'")
+        module.exit_json(msg="Invalid value provided for 'reboot_delay'", failed=True)
 
 
 def main():
@@ -716,8 +716,8 @@ def main():
              },
         "reboot_delay": {"required": False, "type": "int"}
     }
-    specs.update(ome_auth_params)
-    module = AnsibleModule(
+
+    module = OmeAnsibleModule(
         argument_spec=specs,
         required_if=[
             ["enable_nic", True,
@@ -738,13 +738,11 @@ def main():
             module.exit_json(msg="Successfully triggered task to update network address configuration.",
                              network_configuration=resp.json_data, changed=True)
     except HTTPError as err:
-        module.fail_json(msg=str(err), error_info=json.load(err))
+        module.exit_json(msg=str(err), error_info=json.load(err), failed=True)
     except URLError as err:
         module.exit_json(msg=str(err), unreachable=True)
     except (IOError, ValueError, SSLError, TypeError, ConnectionError, SSLValidationError, OSError) as err:
-        module.fail_json(msg=str(err))
-    except Exception as err:
-        module.fail_json(msg=str(err))
+        module.exit_json(msg=str(err), failed=True)
 
 
 if __name__ == "__main__":
