@@ -17,6 +17,7 @@ import socket
 
 from datetime import datetime
 from ssl import SSLError
+from http.client import RemoteDisconnected
 from time import time
 
 from ansible.module_utils.urls import open_url
@@ -82,7 +83,7 @@ class TeemClient(object):
                 data=payload
             )
         # we need to ensure that any connection errors to TEEM do not cause failure of module to run.
-        except (HTTPError, URLError, SSLError):
+        except (HTTPError, URLError, SSLError, RemoteDisconnected):
             return None
 
         ok = re.search(r'20[01-4]', str(response.code))
