@@ -44,7 +44,7 @@ options:
           - The port of the server.
           - When creating a new application and specifying a server, if this parameter
             is not provided, the default is C(8000).
-        type: str
+        type: int
         default: 8000
   inbound_virtual:
     description:
@@ -69,7 +69,7 @@ options:
           - The port on which the virtual listens for connections.
           - When creating a new application, if this parameter is not specified, the
             default value is C(8080).
-        type: str
+        type: int
         default: 8080
   service_environment:
     description:
@@ -114,7 +114,7 @@ author:
 '''
 
 EXAMPLES = r'''
-- name: Load balance a TCP-based application with a FastL4 profile
+- name: BIG-IQ CM a TCP-based application with a FastL4 profile
   bigiq_application_fastl4_tcp:
     name: my-app
     description: My description
@@ -131,7 +131,7 @@ EXAMPLES = r'''
       port: 443
     provider:
       password: secret
-      server: lb.mydomain.com
+      server: cm.mydomain.com
       user: admin
     state: present
   delegate_to: localhost
@@ -661,7 +661,7 @@ class ArgumentSpec(object):
                 elements='dict',
                 options=dict(
                     address=dict(required=True),
-                    port=dict(default=8000)
+                    port=dict(type='int', default=8000)
                 )
             ),
             inbound_virtual=dict(
@@ -669,7 +669,7 @@ class ArgumentSpec(object):
                 options=dict(
                     address=dict(required=True),
                     netmask=dict(required=True),
-                    port=dict(default=8080)
+                    port=dict(type='int', default=8080)
                 )
             ),
             service_environment=dict(),
