@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -99,20 +102,23 @@ options:
                 type: int
                 description: Disable entry ID.
                 required: true
-            ip-range:
+            ip_range:
+                aliases: ['ip-range']
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to ip_range. Ip range.
+                description: Ip range.
                 suboptions:
-                    end-ip:
+                    end_ip:
+                        aliases: ['end-ip']
                         type: str
-                        description: Deprecated, please rename it to end_ip. End IP address.
+                        description: End IP address.
                     id:
                         type: int
                         description: Disable entry range ID.
-                    start-ip:
+                    start_ip:
+                        aliases: ['start-ip']
                         type: str
-                        description: Deprecated, please rename it to start_ip. Start IP address.
+                        description: Start IP address.
             port:
                 type: raw
                 description: (list) Port.
@@ -125,6 +131,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -133,22 +140,21 @@ EXAMPLES = '''
     - name: Disable entries in the Internet service database.
       fortinet.fortimanager.fmgr_application_internetservicecustom_disableentry:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         internet_service_custom: <your own value>
         state: present # <value in [present, absent]>
         application_internetservicecustom_disableentry:
-          id: <integer>
-          ip_range:
-            -
-              end_ip: <string>
-              id: <integer>
-              start_ip: <string>
-          port: <list or integer>
-          protocol: <integer>
+          id: 0 # Required variable, integer
+          # ip_range:
+          #   - end_ip: <string>
+          #     id: <integer>
+          #     start_ip: <string>
+          # port: <list or integer>
+          # protocol: <integer>
 '''
 
 RETURN = '''
@@ -192,48 +198,40 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/application/internet-service-custom/{internet-service-custom}/disable-entry',
         '/pm/config/global/obj/application/internet-service-custom/{internet-service-custom}/disable-entry'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/application/internet-service-custom/{internet-service-custom}/disable-entry/{disable-entry}',
-        '/pm/config/global/obj/application/internet-service-custom/{internet-service-custom}/disable-entry/{disable-entry}'
-    ]
-
     url_params = ['adom', 'internet-service-custom']
     module_primary_key = 'id'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'internet-service-custom': {'type': 'str', 'api_name': 'internet_service_custom'},
         'internet_service_custom': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'application_internetservicecustom_disableentry': {
             'type': 'dict',
-            'v_range': [['6.2.0', '6.2.12']],
+            'v_range': [['6.2.0', '6.2.13']],
             'options': {
-                'id': {'v_range': [['6.2.0', '6.2.12']], 'required': True, 'type': 'int'},
+                'id': {'v_range': [['6.2.0', '6.2.13']], 'required': True, 'type': 'int'},
                 'ip-range': {
-                    'v_range': [['6.2.0', '6.2.12']],
+                    'v_range': [['6.2.0', '6.2.13']],
                     'type': 'list',
                     'options': {
-                        'end-ip': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'},
-                        'id': {'v_range': [['6.2.0', '6.2.12']], 'type': 'int'},
-                        'start-ip': {'v_range': [['6.2.0', '6.2.12']], 'type': 'str'}
+                        'end-ip': {'v_range': [['6.2.0', '6.2.13']], 'type': 'str'},
+                        'id': {'v_range': [['6.2.0', '6.2.13']], 'type': 'int'},
+                        'start-ip': {'v_range': [['6.2.0', '6.2.13']], 'type': 'str'}
                     },
                     'elements': 'dict'
                 },
-                'port': {'v_range': [['6.2.0', '6.2.12']], 'type': 'raw'},
-                'protocol': {'v_range': [['6.2.0', '6.2.12']], 'type': 'int'}
+                'port': {'v_range': [['6.2.0', '6.2.13']], 'type': 'raw'},
+                'protocol': {'v_range': [['6.2.0', '6.2.13']], 'type': 'int'}
             }
-
         }
     }
 
@@ -247,9 +245,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
