@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -128,8 +131,8 @@ EXAMPLES = '''
     - name: IP ranges in the disable entry.
       fortinet.fortimanager.fmgr_application_internetservicecustom_disableentry_iprange:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -200,6 +203,7 @@ def main():
         'internet_service_custom': {'type': 'str'},
         'disable-entry': {'type': 'str', 'api_name': 'disable_entry'},
         'disable_entry': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'application_internetservicecustom_disableentry_iprange': {
             'type': 'dict',
             'v_range': [['6.2.0', '6.2.13']],
