@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -123,8 +126,8 @@ EXAMPLES = '''
     - name: Dynamic vpntunnel dynamic mapping
       fortinet.fortimanager.fmgr_dynamic_vpntunnel_dynamicmapping:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -192,6 +195,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'vpntunnel': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'dynamic_vpntunnel_dynamicmapping': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
