@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -262,6 +265,13 @@ options:
                         choices:
                             - 'disable'
                             - 'enable'
+                    verify_cert:
+                        aliases: ['verify-cert']
+                        type: str
+                        description: Enable/disable certificate verification of the real server.
+                        choices:
+                            - 'disable'
+                            - 'enable'
             saml_server:
                 aliases: ['saml-server']
                 type: str
@@ -506,6 +516,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -514,8 +525,8 @@ EXAMPLES = '''
     - name: Set API Gateway.
       fortinet.fortimanager.fmgr_firewall_accessproxy_apigateway:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -553,6 +564,7 @@ EXAMPLES = '''
           #     translate_host: <value in [disable, enable]>
           #     external_auth: <value in [disable, enable]>
           #     tunnel_encryption: <value in [disable, enable]>
+          #     verify_cert: <value in [disable, enable]>
           # saml_server: <string>
           # service: <value in [http, https, tcp-forwarding, ...]>
           # ssl_algorithm: <value in [high, medium, low, ...]>
@@ -643,6 +655,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'access-proxy': {'type': 'str', 'api_name': 'access_proxy'},
         'access_proxy': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_accessproxy_apigateway': {
             'type': 'dict',
             'v_range': [['7.0.0', '']],
@@ -684,7 +697,8 @@ def main():
                         'type': {'v_range': [['7.0.1', '']], 'choices': ['tcp-forwarding', 'ssh'], 'type': 'str'},
                         'translate-host': {'v_range': [['7.2.2', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                         'external-auth': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                        'tunnel-encryption': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                        'tunnel-encryption': {'v_range': [['7.4.0', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                        'verify-cert': {'v_range': [['7.6.3', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
                     },
                     'elements': 'dict'
                 },
