@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -131,8 +134,8 @@ EXAMPLES = '''
     - name: Firewall casb profile saas application custom control option
       fortinet.fortimanager.fmgr_firewall_casbprofile_saasapplication_customcontrol_option:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -205,6 +208,7 @@ def main():
         'saas_application': {'type': 'str'},
         'custom-control': {'type': 'str', 'api_name': 'custom_control'},
         'custom_control': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_casbprofile_saasapplication_customcontrol_option': {
             'type': 'dict',
             'v_range': [['7.4.1', '7.4.1']],
