@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -209,6 +212,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -217,8 +221,8 @@ EXAMPLES = '''
     - name: Configure DNS over TLS options.
       fortinet.fortimanager.fmgr_firewall_sslsshprofile_dot:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -297,6 +301,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'ssl-ssh-profile': {'type': 'str', 'api_name': 'ssl_ssh_profile'},
         'ssl_ssh_profile': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_sslsshprofile_dot': {
             'type': 'dict',
             'v_range': [['7.0.0', '']],
