@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -96,9 +99,10 @@ options:
             count:
                 type: int
                 description: Count.
-            extension-type:
+            extension_type:
+                aliases: ['extension-type']
                 type: str
-                description: Deprecated, please rename it to extension_type. Extension type.
+                description: Extension type.
                 choices:
                     - 'wan-extension'
                     - 'lan-extension'
@@ -121,6 +125,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -129,19 +134,19 @@ EXAMPLES = '''
     - name: Fmg fabric authorization template platforms
       fortinet.fortimanager.fmgr_fmg_fabric_authorization_template_platforms:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         template: <your own value>
         state: present # <value in [present, absent]>
         fmg_fabric_authorization_template_platforms:
-          count: <integer>
-          extension_type: <value in [wan-extension, lan-extension]>
-          fortilink: <string>
-          prefix: <string>
-          type: <value in [ap, extender, switch]>
+          # count: <integer>
+          # extension_type: <value in [wan-extension, lan-extension]>
+          # fortilink: <string>
+          # prefix: <string>
+          # type: <value in [ap, extender, switch]>
 '''
 
 RETURN = '''
@@ -185,28 +190,21 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/obj/fmg/fabric/authorization/template/{template}/platforms',
         '/pm/config/global/obj/fmg/fabric/authorization/template/{template}/platforms'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/obj/fmg/fabric/authorization/template/{template}/platforms/{platforms}',
-        '/pm/config/global/obj/fmg/fabric/authorization/template/{template}/platforms/{platforms}'
-    ]
-
     url_params = ['adom', 'template']
     module_primary_key = None
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'template': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'fmg_fabric_authorization_template_platforms': {
             'type': 'dict',
             'v_range': [['7.2.1', '']],
@@ -217,7 +215,6 @@ def main():
                 'prefix': {'v_range': [['7.2.1', '']], 'type': 'str'},
                 'type': {'v_range': [['7.2.1', '']], 'choices': ['ap', 'extender', 'switch'], 'type': 'str'}
             }
-
         }
     }
 
@@ -231,9 +228,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
