@@ -94,8 +94,8 @@ EXAMPLES = '''
     - name: Configure disk space available for use by the Upgrade Manager.
       fortinet.fortimanager.fmgr_fmupdate_diskquota:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         fmupdate_diskquota:
