@@ -97,6 +97,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -105,8 +106,8 @@ EXAMPLES = '''
     - name: Enable/disable push updates, and override the default IP address and port used by FortiGuard to send antivirus and IPS push messages...
       fortinet.fortimanager.fmgr_fmupdate_fdssetting_pushoverride:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         fmupdate_fdssetting_pushoverride:
