@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -293,12 +296,20 @@ options:
                     - 'forwarding'
                     - 'local-in'
                     - 'local-out'
+            http_response_match:
+                aliases: ['http-response-match']
+                type: str
+                description: Http response match.
+                choices:
+                    - 'disable'
+                    - 'enable'
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -307,8 +318,8 @@ EXAMPLES = '''
     - name: Configure shaping policies.
       fortinet.fortimanager.fmgr_pkg_footer_shapingpolicy:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         pkg: <your own value>
@@ -362,6 +373,7 @@ EXAMPLES = '''
           # cos: <string>
           # cos_mask: <string>
           # traffic_type: <value in [forwarding, local-in, local-out]>
+          # http_response_match: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -417,6 +429,7 @@ def main():
     module_primary_key = 'id'
     module_arg_spec = {
         'pkg': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'pkg_footer_shapingpolicy': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
@@ -468,7 +481,8 @@ def main():
                 'uuid-idx': {'v_range': [['7.2.1', '']], 'type': 'int'},
                 'cos': {'v_range': [['7.4.0', '']], 'type': 'str'},
                 'cos-mask': {'v_range': [['7.4.0', '']], 'type': 'str'},
-                'traffic-type': {'v_range': [['7.4.0', '']], 'choices': ['forwarding', 'local-in', 'local-out'], 'type': 'str'}
+                'traffic-type': {'v_range': [['7.4.0', '']], 'choices': ['forwarding', 'local-in', 'local-out'], 'type': 'str'},
+                'http-response-match': {'v_range': [['7.4.7', '7.4.7']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
         }
     }
