@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -939,6 +942,7 @@ def main():
     module_primary_key = 'policyid'
     module_arg_spec = {
         'pkg': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'pkg_header_policy6': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
