@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -123,6 +126,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -131,8 +135,8 @@ EXAMPLES = '''
     - name: IPv6 prefix list rule.
       fortinet.fortimanager.fmgr_router_prefixlist6_rule:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -203,6 +207,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'prefix-list6': {'type': 'str', 'api_name': 'prefix_list6'},
         'prefix_list6': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'router_prefixlist6_rule': {
             'type': 'dict',
             'v_range': [['7.0.2', '']],
