@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -140,8 +143,8 @@ EXAMPLES = '''
     - name: Configure VLAN policy to be applied on the managed FortiSwitch ports through dynamic-port-policy.
       fortinet.fortimanager.fmgr_switchcontroller_vlanpolicy:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -211,6 +214,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'switchcontroller_vlanpolicy': {
             'type': 'dict',
             'v_range': [['7.2.1', '']],
@@ -222,7 +226,7 @@ def main():
                 'name': {'v_range': [['7.2.1', '']], 'required': True, 'type': 'str'},
                 'untagged-vlans': {'v_range': [['7.2.1', '']], 'type': 'raw'},
                 'vlan': {'v_range': [['7.2.1', '']], 'type': 'str'},
-                'fortilink': {'v_range': [['7.2.6', '7.2.9'], ['7.4.3', '']], 'type': 'raw'}
+                'fortilink': {'v_range': [['7.2.6', '7.2.11'], ['7.4.3', '']], 'type': 'raw'}
             }
         }
     }
