@@ -88,10 +88,10 @@ options:
             accprofile:
                 type: str
                 description: Override access profile.
-            configuration-write-access:
+            configuration_write_access:
+                aliases: ['configuration-write-access']
                 type: str
                 description:
-                    - Deprecated, please rename it to configuration_write_access.
                     - Enable/disable downstream device write access to configuration.
                     - disable - Disable downstream device write access to configuration.
                     - enable - Enable downstream device write access to configuration.
@@ -107,6 +107,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -115,15 +116,15 @@ EXAMPLES = '''
     - name: Fabric connector configuration.
       fortinet.fortimanager.fmgr_system_csf_fabricconnector:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         state: present # <value in [present, absent]>
         system_csf_fabricconnector:
-          accprofile: <string>
-          configuration_write_access: <value in [disable, enable]>
-          serial: <string>
+          # accprofile: <string>
+          # configuration_write_access: <value in [disable, enable]>
+          # serial: <string>
 '''
 
 RETURN = '''
@@ -167,21 +168,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/cli/global/system/csf/fabric-connector'
     ]
-
-    perobject_jrpc_urls = [
-        '/cli/global/system/csf/fabric-connector/{fabric-connector}'
-    ]
-
     url_params = []
     module_primary_key = None
     module_arg_spec = {
@@ -193,7 +187,6 @@ def main():
                 'configuration-write-access': {'v_range': [['7.4.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
                 'serial': {'v_range': [['7.4.1', '']], 'type': 'str'}
             }
-
         }
     }
 
@@ -207,9 +200,10 @@ def main():
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
