@@ -209,8 +209,8 @@ EXAMPLES = '''
     - name: Settings for remote syslog server.
       fortinet.fortimanager.fmgr_system_locallog_syslogd2_setting:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_locallog_syslogd2_setting:
