@@ -133,7 +133,7 @@ EXAMPLES = '''
         facts:
           selector: "system_log_maildomain"
           params:
-            mail-domain: "your_value"
+            mail_domain: "your_value"
 '''
 
 RETURN = '''
