@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -120,6 +123,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -137,7 +141,7 @@ EXAMPLES = '''
       fortinet.fortimanager.fmgr_user_devicegroup_dynamicmapping:
         bypass_validation: false
         adom: ansible
-        device-group: ansible-test # name
+        device_group: ansible-test # name
         state: present
         user_devicegroup_dynamicmapping:
           _if_unmanaged: 10
@@ -162,7 +166,7 @@ EXAMPLES = '''
           selector: "user_devicegroup_dynamicmapping"
           params:
             adom: "ansible"
-            device-group: "ansible-test" # name
+            device_group: "ansible-test" # name
             dynamic_mapping: "your_value"
 '''
 
@@ -222,6 +226,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'device-group': {'type': 'str', 'api_name': 'device_group'},
         'device_group': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'user_devicegroup_dynamicmapping': {
             'type': 'dict',
             'v_range': [['6.0.0', '7.2.1']],
