@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -149,6 +152,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -157,25 +161,25 @@ EXAMPLES = '''
     - name: Configure HTTP forwarded requests headers.
       fortinet.fortimanager.fmgr_webproxy_profile_headers:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         profile: <your own value>
         state: present # <value in [present, absent]>
         webproxy_profile_headers:
-          action: <value in [add-to-request, add-to-response, remove-from-request, ...]>
-          content: <string>
-          id: <integer>
-          name: <string>
-          add_option: <value in [append, new-on-not-found, new, ...]>
-          base64_encoding: <value in [disable, enable]>
-          dstaddr: <list or string>
-          dstaddr6: <list or string>
-          protocol:
-            - "https"
-            - "http"
+          id: 0 # Required variable, integer
+          # action: <value in [add-to-request, add-to-response, remove-from-request, ...]>
+          # content: <string>
+          # name: <string>
+          # add_option: <value in [append, new-on-not-found, new, ...]>
+          # base64_encoding: <value in [disable, enable]>
+          # dstaddr: <list or string>
+          # dstaddr6: <list or string>
+          # protocol:
+          #   - "https"
+          #   - "http"
 '''
 
 RETURN = '''
@@ -233,6 +237,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'profile': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'webproxy_profile_headers': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
