@@ -138,7 +138,7 @@ hcloud_network_info:
                     description: Name of the server type of the server
                     returned: always
                     type: str
-                    sample: cx22
+                    sample: cpx22
                 ipv4_address:
                     description: Public IPv4 address of the server, None if not existing
                     returned: always
@@ -221,7 +221,7 @@ class AnsibleHCloudNetworkInfo(AnsibleHCloud):
             servers = []
             for server in network.servers:
                 prepared_server = {
-                    "id": str(server.id),
+                    "id": server.id,
                     "name": server.name,
                     "ipv4_address": server.public_net.ipv4.ip if server.public_net.ipv4 is not None else None,
                     "ipv6": server.public_net.ipv6.ip if server.public_net.ipv6 is not None else None,
@@ -238,7 +238,7 @@ class AnsibleHCloudNetworkInfo(AnsibleHCloud):
 
             tmp.append(
                 {
-                    "id": str(network.id),
+                    "id": network.id,
                     "name": network.name,
                     "ip_range": network.ip_range,
                     "subnetworks": subnets,
