@@ -36,6 +36,7 @@ attributes:
     support: none
 extends_documentation_fragment:
 - hitachivantara.vspone_block.common.gateway_note
+- hitachivantara.vspone_block.common.connection_with_type
 notes:
   - The output parameters C(entitlement_status), C(subscriber_id) and C(partner_id) were removed in version 3.4.0.
     They were also deprecated due to internal API simplification and are no longer supported.
@@ -57,33 +58,6 @@ options:
         description: The serial number of the storage system.
         type: str
         required: false
-  connection_info:
-    description: Information required to establish a connection to the storage system.
-    type: dict
-    required: true
-    suboptions:
-      address:
-        description: IP address or hostname of the storage system.
-        type: str
-        required: true
-      username:
-        description: Username for authentication. This is a required field if api_token is not provided.
-        type: str
-        required: false
-      password:
-        description: Password for authentication. This is a required field if api_token is not provided..
-        type: str
-        required: false
-      api_token:
-        description: This field is used to pass the value of the lock token to operate on locked resources.
-        type: str
-        required: false
-      connection_type:
-        description: Type of connection to the storage system.
-        type: str
-        required: false
-        choices: ['direct']
-        default: 'direct'
   spec:
     description: Specification for hostgroup operation.
     type: dict
@@ -98,33 +72,43 @@ options:
       name:
         description: Name of the host group. If not given,
           it will create the name with prefix "smrha-" and add 10 digit random number at the end, for example "smrha-0806262996".
+          Optional for the Create a host group task. Required for the Update host mode and host mode options/Add WWNs to a host group
+          /Remove WWNs from a host group/Present LDEVS/Unpresent LDEVS/Delete/Change or unset nick name of a WWN tasks.
         type: str
         required: false
       port:
-        description: FC Port.
+        description: FC Port. Required for the Create a host group/Update host mode and host mode options/Add WWNs to a host group
+          /Remove WWNs from a host group/Present LDEVS/Unpresent LDEVS/Delete/Change or unset nick name of a WWN
+          /Asymmetric access priority level for ALUA host group/Release the host reservation status by specifying a host group
+          /Release the host reservation status by specifying the LU path tasks.
         type: str
         required: true
       wwns:
-        description: List of host WWN to add or remove.
+        description: List of host WWN to add or remove. Required for the Create a host group/Add WWNs to a host group
+          /Remove WWNs from a host group tasks.
         type: list
         elements: dict
         suboptions:
           wwn:
-            description: WWN of the host.
+            description: WWN of the host. Required for the Create a host group/Add WWNs to a host group
+              /Remove WWNs from a host group/Change or unset nick name of a WWN tasks.
             type: str
             required: true
           nick_name:
-            description: Nickname of the host.
+            description: Nickname of the host. Optional for the Create a host group/Add WWNs to a host group
+              /Remove WWNs from a host group tasks. Required for the Change or unset nick name of a WWN task.
             type: str
             required: false
         required: false
       ldevs:
         description: LDEVs to be mapped/unmapped with the host group. Supported format can be decimal or HEX.
+           Optional for the Create a host group task. Required for the Present LDEVS/Unpresent LDEVS tasks.
         type: list
         elements: str
         required: false
       host_mode:
-        description: Host mode of host group.
+        description: Host mode of host group. Optional for the Create a host group task.
+          Required for the Update host mode and host mode options task.
         type: str
         required: false
         choices: ['LINUX', 'VMWARE', 'HP', 'OPEN_VMS', 'TRU64', 'SOLARIS',
@@ -132,7 +116,8 @@ options:
           'WINDOWS_EXTENSION', 'UVM', 'HP_XP', 'DYNIX']
       host_mode_options:
         description:
-          - List of host group host mode option numbers.
+          - List of host group host mode option numbers. Optional for the Create a host group task.
+            Required for the Update host mode and host mode options task.
           - '0 # RESERVED'
           - '2 # VERITAS_DB_EDITION_ADV_CLUSTER'
           - '6 # TPRLO'
@@ -189,26 +174,32 @@ options:
         required: false
         type: bool
       host_group_number:
-        description: The host group number.
+        description: The host group number. Required for the Asymmetric access priority level for ALUA host group
+          /Release the host reservation status by specifying a host group
+          /Release the host reservation status by specifying the LU path tasks.
         type: int
         required: false
       should_release_host_reserve:
         description: If the value is true, release the host reserve.
+          Required for the Release the host reservation status by specifying a host group
+          /Release the host reservation status by specifying the LU path tasks.
         type: bool
         required: false
       lun:
         description: LUN ID to be releases the host reservation status of the LU mapped to a specified LU path.
+          Required for the Release the host reservation status by specifying the LU path task.
         type: int
         required: false
       asymmetric_access_priority:
         description: Asymmetric access priority level for ALUA host group.
+          Required for the Asymmetric access priority level for ALUA host group task.
         type: str
         required: false
         choices: ['low', 'high']
 """
 
 EXAMPLES = """
-- name: Create host group with LUN in decimal
+- name: Create host group with LDEVs and WWNs
   hitachivantara.vspone_block.vsp.hv_hg:
     state: present
     connection_info:
@@ -227,25 +218,6 @@ EXAMPLES = """
           nick_name: 'test2'
       ldevs: [393, 851]
 
-- name: Create host group with LUN in HEX
-  hitachivantara.vspone_block.vsp.hv_hg:
-    state: present
-    connection_info:
-      address: storage1.company.com
-      username: "dummy_user"
-      password: "dummy_password"
-    host_group_info:
-      name: 'testhg26dec'
-      port: 'CL1-A'
-      host_mode: 'VMWARE_EXTENSION'
-      host_mode_options: [54, 63]
-      wwns:
-        - wwn: '200000109B3C0FD3'
-          nick_name: 'test1'
-        - wwn: '200000109B3C0FD4'
-          nick_name: 'test2'
-      ldevs: ['00:23:A4']
-
 - name: Delete host group
   hitachivantara.vspone_block.vsp.hv_hg:
     state: absent
@@ -257,7 +229,7 @@ EXAMPLES = """
       name: 'testhg26dec'
       port: 'CL1-A'
 
-- name: Present LUN
+- name: Present LDEVs to hostgroup
   hitachivantara.vspone_block.vsp.hv_hg:
     state: present
     connection_info:
@@ -268,9 +240,9 @@ EXAMPLES = """
       state: present_ldev
       name: 'testhg26dec'
       port: 'CL1-A'
-      ldevs: ['00:05:77', '00:05:7D']
+      ldevs: [300, 400]
 
-- name: Unpresent LUN
+- name: Unpresent LDEVs from hostgroup
   hitachivantara.vspone_block.vsp.hv_hg:
     state: present
     connection_info:
@@ -283,7 +255,7 @@ EXAMPLES = """
       port: 'CL1-A'
       ldevs: [800, 801]
 
-- name: Add WWN
+- name: Add WWNs to hostgroup
   hitachivantara.vspone_block.vsp.hv_hg:
     state: present
     connection_info:
@@ -300,7 +272,7 @@ EXAMPLES = """
         - wwn: '200000109B3C0FD4'
         - wwn: '200000109B3C0FD5'
 
-- name: Remove WWN
+- name: Remove WWNs from hostgroup
   hitachivantara.vspone_block.vsp.hv_hg:
     state: present
     connection_info:
@@ -340,7 +312,7 @@ EXAMPLES = """
       port: 'CL1-A'
       asymmetric_access_priority: 'high'
 
-- name: Release host reserve status of the LU mapped to a specified LU path.
+- name: Release the host reservation status by specifying the LU path.
   hitachivantara.vspone_block.vsp.hv_hg:
     state: present
     connection_info:
