@@ -12,30 +12,34 @@ DOCUMENTATION = """
 module: hv_remote_copy_group
 short_description: Manages Remote Copy Group on Hitachi VSP storage systems.
 description: >
-  - This module allows for the splitting, swap-splitting, re-syncing, swap-resyncing and deletion of Remote Copy Group on Hitachi VSP storage systems.
+  - This module allows for the splitting, swap-splitting, re-syncing, swap-resyncing, takeover and deletion of Remote Copy Group on Hitachi VSP storage systems.
   - It supports various remote copy pairs operations based on the specified task level.
   - The module supports the following replication types: HUR, TC, GAD.
-  - This module is supported only for C(direct) connection type.
   - For examples go to URL
     U(https://github.com/hitachi-vantara/vspone-block-ansible/blob/main/playbooks/vsp_direct/remote_copy_group.yml)
 version_added: '3.2.0'
 author:
   - Hitachi Vantara, LTD. (@hitachi-vantara)
 requirements:
-  - python >= 3.8
+  - python >= 3.9
 attributes:
   check_mode:
     description: Determines if the module should run in check mode.
     support: none
+extends_documentation_fragment:
+- hitachivantara.vspone_block.common.gateway_note
+- hitachivantara.vspone_block.common.connection_info
 options:
   state:
-    description: The level of the Remote Copy Group pairs task. Choices are C(present), C(absent), C(split), C(resync), C(swap_split), C(swap_resync).
+    description: >
+      - The level of the Remote Copy Group pairs task.
+      - Choices are C(present), C(absent), C(split), C(resync), C(swap_split), C(swap_resync), C(takeover).
     type: str
     required: false
-    choices: ['present', 'absent', 'split', 'resync', 'swap_split', 'swap_resync']
+    choices: ['present', 'absent', 'split', 'resync', 'swap_split', 'swap_resync', 'takeover']
     default: 'present'
   storage_system_info:
-    description: Information about the storage system.
+    description: Information about the storage system. This field is an optional field.
     type: dict
     required: false
     suboptions:
@@ -43,42 +47,21 @@ options:
         description: The serial number of the storage system.
         type: str
         required: false
-  connection_info:
-    description: Information required to establish a connection to the storage system.
-    required: true
-    type: dict
-    suboptions:
-      address:
-        description: IP address or hostname of the Hitachi storage system .
-        type: str
-        required: true
-      username:
-        description: Username for authentication. This field is valid for C(direct) connection type only, and it is a required field.
-        type: str
-        required: false
-      password:
-        description: Password for authentication. This field is valid for C(direct) connection type only, and it is a required field.
-        type: str
-        required: false
-      api_token:
-        description: Value of the lock token to operate on locked resources.
-        type: str
-        required: false
   secondary_connection_info:
-    description: Information required to establish a connection to the secondary storage system. Required for C(direct) connection only.
+    description: Information required to establish a connection to the secondary storage system.
     required: true
     type: dict
     suboptions:
       address:
-        description: IP address or hostname of the UAI gateway.
+        description: IP address or hostname of the secondary storage system.
         type: str
         required: true
       username:
-        description: Username for authentication.
+        description: Username for authentication for secondary storage. This is a required field if api_token is not provided.
         type: str
         required: false
       password:
-        description: Password for authentication.
+        description: Password for authentication for secondary storage. This is a required field if api_token is not provided.
         type: str
         required: false
       api_token:
@@ -92,27 +75,66 @@ options:
     suboptions:
       copy_group_name:
         description: Copy group name, required for all operations.
+          Required for the Split remote copy group for HUR
+          /Split remote copy group for TC
+          /Split Remote Copy Group for GAD
+          /Resync Remote Copy Group for HUR
+          /Resync Remote Copy Group for TC
+          /Resync Remote Copy Group for GAD
+          /Swap-Split Remote Copy Group for all replication types [HUR, TC, GAD]
+          /Swap-Resync Remote Copy Group for HUR
+          /Swap-Resync Remote Copy Group for TC
+          /Swap-Resync Remote Copy Group for GAD
+          /Delete remote copy group
+          /Takeover Remote Copy Group for HUR replication type tasks.
         type: str
         required: true
       replication_type:
         description: Replication type, either C(UR), C(TC) or C(GAD).
+          Optional for the Split remote copy group for HUR
+          /Split remote copy group for TC
+          /Resync Remote Copy Group for HUR
+          /Resync Remote Copy Group for TC
+          /Swap-Split Remote Copy Group for all replication types [HUR, TC, GAD]
+          /Swap-Resync Remote Copy Group for HUR
+          /Swap-Resync Remote Copy Group for TC
+          /Takeover Remote Copy Group for HUR replication type tasks.
+          Required for the Split Remote Copy Group for GAD
+          /Resync Remote Copy Group for GAD
+          /Swap-Resync Remote Copy Group for GAD tasks.
         type: str
         required: false
-        choices: ['UR', 'TC', 'GAD']
+        choices: ['TC', 'UR', 'GAD', 'HUR']
       is_svol_writable:
         description: Whether svol is writable or not.
+          Optional for the Split remote copy group for HUR
+          /Split remote copy group for TC tasks.
         type: bool
         required: false
       do_pvol_write_protect:
         description: For TC, specify whether to forcibly disable write operations for the P-VOL.
+          Optional for the Split remote copy group for HUR
+          /Split remote copy group for TC tasks.
         type: bool
         required: false
       do_data_suspend:
         description: For UR, specify whether to forcibly stop operations on a journal when the amount of access to the journal increases.
+          Optional for the Split remote copy group for HUR task.
         type: bool
         required: false
       local_device_group_name:
         description: Device group name in the local storage system.
+          Optional for the Split remote copy group for HUR
+          /Split Remote Copy Group for GAD
+          /Resync Remote Copy Group for HUR
+          /Resync Remote Copy Group for TC
+          /Resync Remote Copy Group for GAD
+          /Swap-Split Remote Copy Group for all replication types [HUR, TC, GAD]
+          /Swap-Resync Remote Copy Group for HUR
+          /Swap-Resync Remote Copy Group for TC
+          /Swap-Resync Remote Copy Group for GAD
+          /Delete remote copy group tasks.
+          Required for the Split remote copy group for TC task.
         type: str
         required: false
       svol_operation_mode:
@@ -122,6 +144,18 @@ options:
         required: false
       remote_device_group_name:
         description: Device group name in the remote storage system.
+          Optional for the Split remote copy group for HUR
+          /Split remote copy group for TC
+          /Split Remote Copy Group for GAD
+          /Resync Remote Copy Group for HUR
+          /Resync Remote Copy Group for TC
+          /Resync Remote Copy Group for GAD
+          /Swap-Split Remote Copy Group for all replication types [HUR, TC, GAD]
+          /Swap-Resync Remote Copy Group for HUR
+          /Swap-Resync Remote Copy Group for TC
+          /Swap-Resync Remote Copy Group for GAD
+          /Delete remote copy group tasks.
+          Required for the Takeover Remote Copy Group for HUR replication type task.
         type: str
         required: false
       is_consistency_group:
@@ -133,21 +167,32 @@ options:
           - If the pair is registered in a consistency group
           - true - Leaves the pair registered in a consistency group.
           - false - Cancels the registration of the pair in a consistency group, and places it in an unregistered state.
+          - Optional for the Resync Remote Copy Group for TC
+          - /Resync Remote Copy Group for GAD
+          - /Swap-Resync Remote Copy Group for TC
+          - /Swap-Resync Remote Copy Group for GAD tasks.
         type: bool
         required: false
       consistency_group_id:
         description: For TC, specify the consistency group ID by using a decimal number in the range from 0 to 255.
+          Optional for the Resync Remote Copy Group for TC
+          /Resync Remote Copy Group for GAD
+          /Swap-Resync Remote Copy Group for TC
+          /Swap-Resync Remote Copy Group for GAD tasks.
         type: int
         required: false
       fence_level:
         description: Specifies the primary volume fence level setting and determines if the host is denied access or continues to access
             the primary volume when the pair is suspended because of an error.
+            Optional for the Resync Remote Copy Group for TC task.
         type: str
         required: false
         choices: ['NEVER', 'DATA', 'STATUS']
       copy_pace:
         description: For TC, specify a decimal number in the range from 1 to 15 for the size of tracks to be copied.
           The larger the value you specify, the faster the copy speed.
+          Optional for the Resync Remote Copy Group for TC
+          /Swap-Resync Remote Copy Group for TC tasks.
         type: int
         required: false
       do_failback:
@@ -165,13 +210,12 @@ options:
 """
 
 EXAMPLES = """
-- name: Split remote copy group for HUR for direct connection type
+- name: Split remote copy group for HUR
   hitachivantara.vspone_block.vsp.hv_remote_copy_group:
     connection_info:
       address: storage1.company.com
       username: "admin"
       password: "password"
-      connection_type: "direct"
     state: split
     spec:
       local_device_group_name: remote_copy_group_local_device_group_name_1
@@ -181,13 +225,12 @@ EXAMPLES = """
       is_svol_writable: false
       do_data_suspend: false
 
-- name: Resync remote copy group for HUR for direct connection type
+- name: Resync remote copy group for HUR
   hitachivantara.vspone_block.vsp.hv_remote_copy_group:
     connection_info:
       address: storage1.company.com
       username: "admin"
       password: "password"
-      connection_type: "direct"
     state: resync
     spec:
       local_device_group_name: remote_copy_group_local_device_group_name_1
@@ -195,13 +238,12 @@ EXAMPLES = """
       copy_group_name: remote_copy_group_copy_group_name_1
       replication_type: hur
 
-- name: Swap split remote copy group for HUR for direct connection type
+- name: Swap split remote copy group for HUR
   hitachivantara.vspone_block.vsp.hv_remote_copy_group:
     connection_info:
       address: storage1.company.com
       username: "admin"
       password: "password"
-      connection_type: "direct"
     state: swap_split
     spec:
       local_device_group_name: remote_copy_group_local_device_group_name_1
@@ -209,13 +251,12 @@ EXAMPLES = """
       copy_group_name: remote_copy_group_copy_group_name_1
       replication_type: hur
 
-- name: Swap resync remote copy group for HUR for direct connection type
+- name: Swap resync remote copy group for HUR
   hitachivantara.vspone_block.vsp.hv_remote_copy_group:
     connection_info:
       address: storage1.company.com
       username: "admin"
       password: "password"
-      connection_type: "direct"
     state: swap_resync
     spec:
       local_device_group_name: remote_copy_group_local_device_group_name_1
@@ -223,24 +264,22 @@ EXAMPLES = """
       copy_group_name: remote_copy_group_copy_group_name_1
       replication_type: hur
 
-- name: Delete remote copy group for HUR for direct connection type
+- name: Delete remote copy group for HUR
   hitachivantara.vspone_block.vsp.hv_remote_copy_group:
     connection_info:
       address: storage1.company.com
       username: "admin"
       password: "password"
-      connection_type: "direct"
     state: absent
     spec:
       copy_group_name: remote_copy_group_copy_group_name_1
 
-- name: Split remote copy group for TrueCopy for direct connection type
+- name: Split remote copy group for TrueCopy
   hitachivantara.vspone_block.vsp.hv_remote_copy_group:
     connection_info:
       address: storage1.company.com
       username: "admin"
       password: "password"
-      connection_type: "direct"
     state: split
     spec:
       local_device_group_name: remote_copy_group_local_device_group_name_1
@@ -250,13 +289,12 @@ EXAMPLES = """
       is_svol_writable: false
       do_pvol_write_protect: false
 
-- name: Resync remote copy group for TrueCopy for direct connection type
+- name: Resync remote copy group for TrueCopy
   hitachivantara.vspone_block.vsp.hv_remote_copy_group:
     connection_info:
       address: storage1.company.com
       username: "admin"
       password: "password"
-      connection_type: "direct"
     state: resync
     spec:
       local_device_group_name: remote_copy_group_local_device_group_name_1
@@ -268,13 +306,12 @@ EXAMPLES = """
       fence_level: NEVER
       copy_pace: 3
 
-- name: Swap split remote copy group for TrueCopy for direct connection type
+- name: Swap split remote copy group for TrueCopy
   hitachivantara.vspone_block.vsp.hv_remote_copy_group:
     connection_info:
       address: storage1.company.com
       username: "admin"
       password: "password"
-      connection_type: "direct"
     state: swap_split
     spec:
       local_device_group_name: remote_copy_group_local_device_group_name_1
@@ -282,13 +319,12 @@ EXAMPLES = """
       copy_group_name: remote_copy_group_copy_group_name_1
       replication_type: TC
 
-- name: Swap resync remote copy group for TrueCopy for direct connection type
+- name: Swap resync remote copy group for TrueCopy
   hitachivantara.vspone_block.vsp.hv_remote_copy_group:
     connection_info:
       address: storage1.company.com
       username: "admin"
       password: "password"
-      connection_type: "direct"
     state: swap_resync
     spec:
       local_device_group_name: remote_copy_group_local_device_group_name_1
@@ -296,24 +332,22 @@ EXAMPLES = """
       copy_group_name: remote_copy_group_copy_group_name_1
       replication_type: TC
 
-- name: Delete remote copy group for TrueCopy for direct connection type
+- name: Delete remote copy group for TrueCopy
   hitachivantara.vspone_block.vsp.hv_remote_copy_group:
     connection_info:
       address: storage1.company.com
       username: "admin"
       password: "password"
-      connection_type: "direct"
     state: absent
     spec:
       copy_group_name: remote_copy_group_copy_group_name_1
 
-- name: Split remote copy group for GAD for direct connection type
+- name: Split remote copy group for GAD
   hitachivantara.vspone_block.vsp.hv_remote_copy_group:
     connection_info:
       address: storage1.company.com
       username: "admin"
       password: "password"
-      connection_type: "direct"
     state: split
     spec:
       local_device_group_name: remote_copy_group_local_device_group_name_1
@@ -321,13 +355,12 @@ EXAMPLES = """
       copy_group_name: remote_copy_group_copy_group_name_1
       replication_type: GAD
 
-- name: Resync remote copy group for GAD for direct connection type
+- name: Resync remote copy group for GAD
   hitachivantara.vspone_block.vsp.hv_remote_copy_group:
     connection_info:
       address: storage1.company.com
       username: "admin"
       password: "password"
-      connection_type: "direct"
     state: resync
     spec:
       local_device_group_name: remote_copy_group_local_device_group_name_1
@@ -337,13 +370,12 @@ EXAMPLES = """
       is_consistency_group: true
       consistency_group_id: 47
 
-- name: Swap split remote copy group for GAD for direct connection type
+- name: Swap split remote copy group for GAD
   hitachivantara.vspone_block.vsp.hv_remote_copy_group:
     connection_info:
       address: storage1.company.com
       username: "admin"
       password: "password"
-      connection_type: "direct"
     state: swap_split
     spec:
       local_device_group_name: remote_copy_group_local_device_group_name_1
@@ -351,13 +383,12 @@ EXAMPLES = """
       copy_group_name: remote_copy_group_copy_group_name_1
       replication_type: GAD
 
-- name: Swap resync remote copy group for GAD for direct connection type
+- name: Swap resync remote copy group for GAD
   hitachivantara.vspone_block.vsp.hv_remote_copy_group:
     connection_info:
       address: storage1.company.com
       username: "admin"
       password: "password"
-      connection_type: "direct"
     state: swap_resync
     spec:
       local_device_group_name: remote_copy_group_local_device_group_name_1
@@ -365,16 +396,27 @@ EXAMPLES = """
       copy_group_name: remote_copy_group_copy_group_name_1
       replication_type: GAD
 
-- name: Delete remote copy group for GAD for direct connection type
+- name: Delete remote copy group for GAD
   hitachivantara.vspone_block.vsp.hv_remote_copy_group:
     connection_info:
       address: storage1.company.com
       username: "admin"
       password: "password"
-      connection_type: "direct"
     state: absent
     spec:
       copy_group_name: remote_copy_group_copy_group_name_1
+
+- name: Takeover remote copy group for HUR
+  hitachivantara.vspone_block.vsp.hv_remote_copy_group:
+    connection_info:
+      address: storage1.company.com
+      username: "admin"
+      password: "password"
+    state: takeover
+    spec:
+      local_device_group_name: remote_copy_group_local_device_group_name_1
+      copy_group_name: remote_copy_group_copy_group_name_1
+      replication_type: hur
 """
 
 RETURN = """
@@ -499,9 +541,6 @@ from ansible_collections.hitachivantara.vspone_block.plugins.module_utils.common
     VSPRemoteCopyGroupArguments,
     VSPParametersManager,
 )
-from ansible_collections.hitachivantara.vspone_block.plugins.module_utils.common.hv_constants import (
-    ConnectionTypes,
-)
 from ansible_collections.hitachivantara.vspone_block.plugins.module_utils.reconciler.vsp_copy_groups import (
     VSPCopyGroupsReconciler,
 )
@@ -517,9 +556,6 @@ from ansible_collections.hitachivantara.vspone_block.plugins.module_utils.common
 from ansible_collections.hitachivantara.vspone_block.plugins.module_utils.common.ansible_common import (
     validate_ansible_product_registration,
 )
-from ansible_collections.hitachivantara.vspone_block.plugins.module_utils.message.module_msgs import (
-    ModuleMessage,
-)
 
 
 @LogDecorator.debug_methods
@@ -601,10 +637,6 @@ class VSPCopyGroupManager:
             self.state,
             self.secondary_connection_info,
         )
-        if self.connection_info.connection_type == ConnectionTypes.GATEWAY:
-            found = reconciler.check_storage_in_ucpsystem()
-            if not found:
-                raise ValueError(ModuleMessage.STORAGE_SYSTEM_ONBOARDING.value)
 
         result = reconciler.copy_group_reconcile_direct(
             self.state, self.spec, self.secondary_connection_info
@@ -628,6 +660,8 @@ class VSPCopyGroupManager:
             return "Copy Group  swapped split successfully."
         elif self.state == "swap_resync":
             return "Copy Group  swapped resynced successfully"
+        elif self.state == "takeover":
+            return "HUR Copy Group takeover done successfully."
         else:
             return "Unknown state provided."
 
