@@ -29,6 +29,7 @@ attributes:
     support: none
 extends_documentation_fragment:
 - hitachivantara.vspone_block.common.gateway_note
+- hitachivantara.vspone_block.common.connection_with_type
 notes:
   - The output parameters C(entitlement_status), C(subscriber_id), and C(partner_id) were removed in version 3.4.0.
     They were also deprecated due to internal API simplification and are no longer supported.
@@ -78,33 +79,6 @@ options:
         description: This field is used to pass the value of the lock token of the secondary storage to operate on locked resources.
         type: str
         required: false
-  connection_info:
-    description: Information required to establish a connection to the storage system.
-    type: dict
-    required: true
-    suboptions:
-      address:
-        description: IP address or hostname of the storage system.
-        type: str
-        required: true
-      username:
-        description: Username for authentication for secondary storage. This is a required field if api_token is not provided.
-        type: str
-        required: false
-      password:
-        description: Password for authentication for secondary storage. This is a required field if api_token is not provided.
-        type: str
-        required: false
-      api_token:
-        description: This field is used to pass the value of the lock token to operate on locked resources.
-        type: str
-        required: false
-      connection_type:
-        description: Type of connection to the storage system.
-        type: str
-        required: false
-        choices: ['direct']
-        default: 'direct'
   spec:
     description: Specification for the TrueCopy pairs task.
     type: dict
@@ -130,7 +104,7 @@ options:
         required: false
       primary_volume_id:
         description: Primary volume ID. This is a required field for create operation.
-        type: int
+        type: str
         required: false
       consistency_group_id:
         description: Consistency Group ID, 0 to 255. This is an optional field.
@@ -149,7 +123,7 @@ options:
         required: false
       provisioned_secondary_volume_id:
         description: ID of the provisioned secondary volume that you want to use for the true copy creation.
-        type: int
+        type: str
         required: false
       begin_secondary_volume_id:
         description: >
@@ -158,7 +132,7 @@ options:
           If this field is not specified, Ansible modules will try to create SVOL ID same as the PVOL ID if available,
           otherwise it will use the first available LDEV ID.
         required: false
-        type: int
+        type: str
       end_secondary_volume_id:
         description: >
           Specify end ldev id for LDEV range for svol. This is an optional field during create operation.
@@ -166,7 +140,7 @@ options:
           If this field is not specified, Ansible modules will try to create SVOL ID same as PVOL ID iff available,
           otherwise it will use the first available LDEV ID.
         required: false
-        type: int
+        type: str
       copy_pace:
         description: Copy speed.
         type: str
@@ -271,10 +245,6 @@ options:
         description: Required only for resize or expand operation. Value should be grater than the current volume size.
         type: str
         required: false
-      secondary_volume_id:
-        description: Secondary volume id.
-        type: int
-        required: false
       is_consistency_group:
         description: >
           This is an optional field during create operation.
@@ -436,10 +406,6 @@ data:
       description: Primary hex volume ID.
       type: str
       sample: "00:02:77"
-    primary_or_secondary:
-      description: Primary or secondary.
-      type: str
-      sample: ""
     primary_volume_id:
       description: Primary volume ID.
       type: int
@@ -464,18 +430,10 @@ data:
       description: Secondary volume ID.
       type: int
       sample: 202
-    status:
-      description: Status.
-      type: str
-      sample: ""
     storage_serial_number:
       description: Storage serial number.
       type: str
       sample: "810050"
-    svol_access_mode:
-      description: SVOL access mode.
-      type: str
-      sample: ""
     svol_status:
       description: SVOL status.
       type: str
