@@ -27,9 +27,7 @@ DOCUMENTATION = '''
 module: ovirt_vmpool_info
 short_description: Retrieve information about one or more oVirt/RHV vmpools
 version_added: "1.0.0"
-author:
-- "Ondra Machacek (@machacekondra)"
-- "Martin Necas (@mnecas)"
+author: "oVirt Developers (@oVirt)"
 description:
     - "Retrieve information about one or more oVirt/RHV vmpools."
     - This module was called C(ovirt_vmpool_facts) before Ansible 2.9, returning C(ansible_facts).
@@ -44,6 +42,17 @@ options:
             - "Search term which is accepted by oVirt/RHV search backend."
             - "For example to search vmpool X: name=X"
         type: str
+        default: ''
+    follow:
+        description:
+            - List of linked entities, which should be fetched along with the main entity.
+            - This parameter replaces usage of C(fetch_nested) and C(nested_attributes).
+            - "All follow parameters can be found at following url: https://ovirt.github.io/ovirt-engine-api-model/master/#types/vm_pool/links_summary"
+        type: list
+        version_added: 1.5.0
+        elements: str
+        aliases: ['follows']
+        default: []
 extends_documentation_fragment: ovirt.ovirt.ovirt_info
 '''
 
@@ -82,12 +91,15 @@ def main():
     argument_spec = ovirt_info_full_argument_spec(
         pattern=dict(default='', required=False),
     )
-    module = AnsibleModule(argument_spec)
+    module = AnsibleModule(
+        argument_spec,
+        supports_check_mode=True,
+    )
     check_sdk(module)
     if module.params['fetch_nested'] or module.params['nested_attributes']:
         module.deprecate(
             "The 'fetch_nested' and 'nested_attributes' are deprecated please use 'follow' parameter",
-            version='3.0.0',
+            version='4.0.0',
             collection_name='ovirt.ovirt'
         )
 
