@@ -112,6 +112,14 @@ EXAMPLES = r'''
 '''
 
 RETURN = r'''
+cluster:
+    description:
+        - Information about the target cluster
+    returned: On success
+    type: dict
+    sample:
+        moid: cluster-79828,
+        name: test-cluster
 result:
     description:
         - Information about the DRS config update task, if something changed
@@ -138,18 +146,18 @@ from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.vmware.vmware.plugins.module_utils._module_pyvmomi_base import (
     ModulePyvmomiBase
 )
-from ansible_collections.vmware.vmware.plugins.module_utils._vmware_argument_spec import (
+from ansible_collections.vmware.vmware.plugins.module_utils.argument_spec import (
     base_argument_spec
 )
-from ansible_collections.vmware.vmware.plugins.module_utils._vmware_tasks import (
+from ansible_collections.vmware.vmware.plugins.module_utils._vsphere_tasks import (
     TaskError,
     RunningTaskMonitor
 )
-from ansible_collections.vmware.vmware.plugins.module_utils._vmware_facts import (
+from ansible_collections.vmware.vmware.plugins.module_utils._facts import (
     ClusterFacts
 )
-from ansible_collections.vmware.vmware.plugins.module_utils._vmware_type_utils import (
-    diff_dict_and_vmodl_options_set
+from ansible_collections.vmware.vmware.plugins.module_utils._advanced_settings import (
+    AdvancedSettings
 )
 from ansible.module_utils._text import to_native
 
@@ -166,10 +174,9 @@ class VMwareCluster(ModulePyvmomiBase):
         self.drs_default_vm_behavior = self.params.get('drs_default_vm_behavior')
         self.predictive_drs = self.params.get('predictive_drs')
 
-        self.changed_advanced_settings = diff_dict_and_vmodl_options_set(
-            self.params.get('advanced_settings'),
-            self.cluster.configurationEx.drsConfig.option
-        )
+        _user_settings = AdvancedSettings.from_py_dict(self.params.get('advanced_settings'), cast_all_values_to_str=True)
+        _live_settings = AdvancedSettings.from_vsphere_config(self.cluster.configurationEx.drsConfig.option)
+        self.changed_advanced_settings = _user_settings.difference(_live_settings)
 
     @property
     def drs_vmotion_rate(self):
@@ -203,7 +210,7 @@ class VMwareCluster(ModulePyvmomiBase):
         except AttributeError:
             return True
 
-        if self.changed_advanced_settings:
+        if not self.changed_advanced_settings.is_empty():
             return True
 
         return False
@@ -221,8 +228,8 @@ class VMwareCluster(ModulePyvmomiBase):
         cluster_config_spec.drsConfig.vmotionRate = self.drs_vmotion_rate
         cluster_config_spec.proactiveDrsConfig.enabled = self.predictive_drs
 
-        if self.changed_advanced_settings:
-            cluster_config_spec.drsConfig.option = self.changed_advanced_settings
+        if not self.changed_advanced_settings.is_empty():
+            cluster_config_spec.drsConfig.option = self.changed_advanced_settings.to_vsphere_config()
 
         return cluster_config_spec
 
@@ -268,10 +275,16 @@ def main():
 
     result = dict(
         changed=False,
-        result={}
+        result={},
+        cluster=dict(
+            name="",
+            moid=""
+        )
     )
 
     cluster_drs = VMwareCluster(module)
+    result['cluster']['name'] = cluster_drs.cluster.name
+    result['cluster']['moid'] = cluster_drs.cluster._GetMoId()
 
     config_is_different = cluster_drs.check_drs_config_diff()
     if config_is_different:
